;+
; NAME:
;       MAKE_X_COUNTER_CH_TREE
;
; PURPOSE:
;       This procedure makes the ch(pixel) number branches in each
;       pix_flag node in the X data selector of the FISv.
;       This procedure is called by FISv.
;
; AUTHOR:
;       ASTRO-F Data Reduction team
;       Web Page: http://www.ir.isas.ac.jp/ASTRO-F/iris_data/
;
; CATEGORY:
;       FIS Data Visualizer
;
; CALLING SEQUENCE:
;       make_x_counter_ch_tree, widgetID, counter_type
;         'counter_type' is counter type (QUAL_RC_PARAM, QUAL_DF_EQ, etc.)
;
; MODIFICATION HISTORY:
;        Written by: Makiuti,S.
;-
pro make_x_counter_ch_tree, widgetID, counter_type
Common Share

  parentID = widgetID
  WHILE Widget_Info(parentID, /Parent) NE 0 DO BEGIN
     parentID = Widget_Info(parentID, /Parent)
  ENDWHILE

  Widget_Control, parentID, UPDATE=0

  counter_type_member = ['CNT_SAA', 'CNT_GLITCH_GP', 'CNT_GLITCH_MT']
  counter_type_header_member = ['CSAA', 'CGGP', 'CGMT']
  counter_type_header = counter_type_header_member[where(counter_type EQ counter_type_member)]
  ; convert one-element array to scalar
  counter_type_header = counter_type_header[0]

  ; Parent branch ID in which child leaves are made
  temp_str1 = 'X_COUNTER_'+counter_type_header
  X_TREE_COUNTER_ID = widget_info(parentID, find_by_uname=temp_str1)

  ; Get detector type (SW or LW)
  pixmax = (STRMATCH(tsd->Get_Datatype(), '*SW*', /FOLD_CASE) EQ 1) ? 100:75

  FOR i = 1, pixmax DO BEGIN

    IF (i LE 9) THEN BEGIN
      pix_str = string(i, format='(I1)')
    ENDIF ELSE IF ((i GE 10) AND (i LE 99)) THEN BEGIN
      pix_str = string(i, format='(I2)')
    ENDIF ELSE IF (i EQ 100) THEN BEGIN
      pix_str = string(i, format='(I3)')
    ENDIF

      temp_str1 = counter_type_header + pix_str
      temp_id1  = Widget_Tree(X_TREE_COUNTER_ID, UNAME='X_COUNTER_'+pix_str $
        ,VALUE=pix_str, UVALUE=temp_str1)

  ENDFOR

  Widget_Control, parentID, /UPDATE

end