;+
; NAME:
;       MAKE_Y_VDET_TREE
;
; PURPOSE:
;       This procedure makes the VDET branches
;       in the Y data selector of the FISv.
;       This procedure is called by FISv.
;
; AUTHOR:
;       ASTRO-F Data Reduction team
;       Web Page: http://www.ir.isas.ac.jp/ASTRO-F/iris_data/
;
; CATEGORY:
;       FIS Data Visualizer
;
; CALLING SEQUENCE:
;       make_y_vdet_tree, widgetID
;
; MODIFICATION HISTORY:
;        Written by: Makiuti,S.
;-
pro make_y_vdet_tree, widgetID
Common Share

  parentID = widgetID
  WHILE Widget_Info(parentID, /Parent) NE 0 DO BEGIN
     parentID = Widget_Info(parentID, /Parent)
  ENDWHILE

  Widget_Control, parentID, UPDATE=0

  Y_TREENODE_48 = widget_info(parentID, find_by_uname='Y_TREENODE_48')

  ; Get detector type (SW or LW)
  pixmax = (STRMATCH(tsd->Get_Datatype(), '*SW*', /FOLD_CASE) EQ 1) ? 100:75

  FOR i = 1, pixmax DO BEGIN

    IF (i LE 9) THEN BEGIN
      pix_str = string(i, format='(I1)')
    ENDIF ELSE IF ((i GE 10) AND (i LE 99)) THEN BEGIN
      pix_str = string(i, format='(I2)')
    ENDIF ELSE IF (i EQ 100) THEN BEGIN
      pix_str = string(i, format='(I3)')
    ENDIF

    temp_str1 = 'Y_TREE_VDET'+pix_str
    temp_str1 = Widget_Tree(Y_TREENODE_48, UNAME='Y_TREE_VDET'+pix_str $
      , VALUE=pix_str, UVALUE='VDET'+pix_str)

  ENDFOR

  Widget_Control, parentID, /UPDATE

end
