; $Id: setbad_plot.pro,v 1.2 2007/01/30 05:07:34 makiuti Exp $
;+
; NAME:
;       SETBAD_PLOT
;
; PURPOSE:
;       The purpose of this program is to set bad pixel flags for a FIS data.
;
; AUTHOR:
;       ASTRO-F Data Reduction team
;       Web Page: http://www.ir.isas.jaxa.jp/ASTRO-F/iris_data/
;
; CATEGORY:
;       FIS Data Visualizer
;       Widgets program
;
; CALLING SEQUENCE:
;       This program is usually called from fisv_eventcb.pro
;
; OTHER PROGRAMS NEEDED:
;
;   The following programs are required to run this one:
;
;    getcolor.pro(in ./lib)
;
; MODIFY
;       Alternate version of ZPLOT by Makiuti,S.
;       The last version of zplot_alt
;       -> 06/09/27 Context menu (Convert temperature unit) was added
;
;       This procedure is based on zplot_alt.pro of the above version.
;       The first version of setbad_plot was written at 06/11/02
;
;       07/01/29 Last modified
;

;-----------------------------------------------------------------
PRO ZPLOT_CLEANUP, tlb

   ; The purpose of this module is to delete the pixmap window
   ; and perform other cleanup chores when the program ZPLOT is
   ; destroyed.

Widget_Control, tlb, Get_UValue=info
IF N_Elements(info) NE 0 THEN BEGIN
   WDelete, info.pixIndex
   Ptr_Free, info.extraKeywords
ENDIF
END ; of ZPLOT_CLEANUP

;-----------------------------------------------------------------
pro sbClsBtn, Event, info
Common Share, tsd

  msg = 'Do you set BAD flags for pixel #'+strtrim(string(info.pixno+1), 1)+'?'
  ret = dialog_message(msg, /CENTER, /CANCEL, DIALOG_PARENT=Event.top, $
                       /QUESTION, /DEFAULT_NO, Title='BAD pixel-flags setting')

  IF (ret EQ 'Yes') THEN BEGIN

    org_bad = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'BAD', PixNo=info.pixno)
    org_bad = reform(org_bad)

    new_bad = (org_bad OR info.to_be_bad)
    r = tsd->Set_Pix_Flag_TSD('FIS_OBS', 'BAD', PixNo=info.pixno, new_bad)

    WIDGET_CONTROL, Event.top, /DESTROY
  ENDIF ELSE IF (ret EQ 'Cancel') THEN BEGIN
    Widget_Control, event.top, Set_UValue=info, /No_Copy
  ENDIF ELSE BEGIN
    WIDGET_CONTROL, Event.top, /DESTROY
  ENDELSE
end

;-----------------------------------------------------------------
pro get_prop_plot, info, PSYMS=psyms
; This procedure returns an array 'psyms' which contains psym settings

psyms=make_array(5, /integer) ; for maximum five data

IF (info.psym NE 0) THEN BEGIN
  IF (info.line EQ 0) THEN BEGIN ; with symbol witout line
    psyms[0]=7
    psyms[1]=1
    psyms[2]=4
    psyms[3]=2
    psyms[4]=6
  ENDIF ELSE BEGIN ; with both symbol and line
    psyms[0]=-7
    psyms[1]=-1
    psyms[2]=-4
    psyms[3]=-2
    psyms[4]=-6
  ENDELSE
ENDIF ELSE BEGIN ; line witout symbol
  psyms[*]=0
ENDELSE

end

;-----------------------------------------------------------------
pro sbNewPlot, Event, info

  ; ## DISPLAY START##
  ; Destroy old pixmap and create a new one.
  WDelete, info.pixIndex
  Window, XSize=info.zxsize, YSize=info.zysize, /Free, /Pixmap
  info.pixIndex = !D. Window

  ;  Set up colors for line plot.
  backColor = GetColor('navy', !D.Table_Size-2)
  dataColor = GetColor('yellow', !D.Table_Size-3)
  axisColor = GetColor('green', !D.Table_Size-4)


  ;  Set up properties (line and symbol) of line plot.
  get_prop_plot, info, PSYMS=psyms

  ; ## Draw the plot in both windows. ##

;#
  Plot, info.indep, info.dep, $
     XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
     YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
     Xtitle=info.xtitle, XMargin=info.xmargin, $
     XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
     Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
  OPlot, info.indep, info.dep, Color=dataColor, psym=psyms[0]

  ; Standard position of legends
  title_pos1a = CONVERT_COORD([0.85, 0.90], /NORMAL, /TO_DATA)  ; for symbol
  title_pos1b = CONVERT_COORD([0.86, 0.90], /NORMAL, /TO_DEVICE); for label string
  title_pos1b = CONVERT_COORD(title_pos1b[0],title_pos1b[1]-5, /DEVICE, /TO_DATA)

;#
  WSet, info.drawIndex
  Plot, info.indep, info.dep, $
     XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
     YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
     Xtitle=info.xtitle, XMargin=info.xmargin, $
     XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
     Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
  OPlot, info.indep, info.dep, Color=dataColor, psym=psyms[0]
  ; ## DISPLAY END##

  ; Update the plot system variables.
  info.x = !X
  info.y = !Y
  info.p = !P

  Widget_Control, event.top, Set_UValue=info, /No_Copy

end


;-----------------------------------------------------------------
pro sbExtBtn, Event, info ;;;; Switch the extra button mode
COMMON TOP_WID_ID, rootID ; rootID is the FISv top level ID when zplot_alt was called by FISv.

  plotwin_geom = widget_info(Event.top, /GEOMETRY); Geometry information of the current window

  extbtn_mode = (info.extbtn_mode EQ 1) ? 0:1

  setbad_plot, info.indep, info.dep, $
   Xtitle=info.xtitle, FILENAME=info.filename, GROUP_LEADER=rootID, $
   XLog=info.xlog, YLog=info.ylog, $
   x_range2=info.xrange, y_range2=info.yrange, xstyle=1, ystyle=1, $
   psym=info.psym, TickLen=info.ticklen, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
   ZOOM_XSIZE = (info.zxsize GT 600)?info.zxsize:600, ZOOM_YSIZE=info.zysize, $
   extbtn_mode=extbtn_mode, $ ;;; Extra Button Mode ON
   XOffset=plotwin_geom.xoffset, YOffset=plotwin_geom.yoffset, $
   PIXNO=info.pixno, $
   _Extra=*info.extraKeywords

  WIDGET_CONTROL, Event.top, /DESTROY

end


;-----------------------------------------------------------------
PRO sbZPLOT_RESIZE, event

On_Error, 2

; This event handler reponds to TLB re-size events.
 Widget_Control, event.top, Get_UValue=info, /No_Copy

;#####Start of altered code#####
  wWidget = Event.top
  wTarget = Event.id
  ;help, event, /structure

  case wTarget of

    ; ##Close Plot Window##
    Widget_Info(wWidget, FIND_BY_UNAME='ClsBtn'): begin
    if( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' )then $
      sbClsBtn, Event, info
    end

    ; ##Grid On/Off##
    Widget_Info(wWidget, FIND_BY_UNAME='GridBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Switch ticklen
        info.ticklen = (info.ticklen EQ 0.02) ? 1.0:0.02

        ; Make new plot
        sbNewPlot, Event, info
      ENDIF
    end

    ; ##Reset range##
    Widget_Info(wWidget, FIND_BY_UNAME='ResetBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Back to the initial ranges
        info.xrange = info.xrange_def
        info.yrange = info.yrange_def

        ; Set axis style
        info.xstyle = 0
        info.ystyle = 0

        ; Make new plot
        sbNewPlot, Event, info
      ENDIF
    end

    ; ##Auto Scale##
    Widget_Info(wWidget, FIND_BY_UNAME='ASBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        x0 = info.xrange[0]
        x1 = info.xrange[1]
        data1 = info.dep[where((info.indep GT x0) AND (info.indep LT x1))]
        info.yrange[0] = min([data1])
        info.yrange[1] = max([data1])

        ; Make new plot
        sbNewPlot, Event, info
      ENDIF
    end

    ; ## X&Y Zoom Out (half) ##
    Widget_Info(wWidget, FIND_BY_UNAME='ZoutBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_xrange = info.xrange[1] - info.xrange[0]
        info.xrange[0] = info.xrange[0] - current_xrange/2.0
        info.xrange[1] = info.xrange[1] + current_xrange/2.0

        current_yrange = info.yrange[1] - info.yrange[0]
        info.yrange[0] = info.yrange[0] - current_yrange/2.0
        info.yrange[1] = info.yrange[1] + current_yrange/2.0

        ; Make new plot
        sbNewPlot, Event, info
      ENDIF
    end
    ; ## X Zoom Out (half) ##
    Widget_Info(wWidget, FIND_BY_UNAME='xZoutBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_xrange = info.xrange[1] - info.xrange[0]
        info.xrange[0] = info.xrange[0] - current_xrange/2.0
        info.xrange[1] = info.xrange[1] + current_xrange/2.0

        ; Make new plot
        sbNewPlot, Event, info
      ENDIF
    end
    ; ## Y Zoom Out (half) ##
    Widget_Info(wWidget, FIND_BY_UNAME='yZoutBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_yrange = info.yrange[1] - info.yrange[0]
        info.yrange[0] = info.yrange[0] - current_yrange/2.0
        info.yrange[1] = info.yrange[1] + current_yrange/2.0

        ; Make new plot
        sbNewPlot, Event, info
      ENDIF
    end
    ; ## X&Y Zoom In (twice) ##
    Widget_Info(wWidget, FIND_BY_UNAME='ZinBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_xrange = info.xrange[1] - info.xrange[0]
        info.xrange[0] = info.xrange[0] + current_xrange/4.0
        info.xrange[1] = info.xrange[1] - current_xrange/4.0

        current_yrange = info.yrange[1] - info.yrange[0]
        info.yrange[0] = info.yrange[0] + current_yrange/4.0
        info.yrange[1] = info.yrange[1] - current_yrange/4.0

        ; Make new plot
        sbNewPlot, Event, info
      ENDIF
    end
    ; ## X Zoom In (twice) ##
    Widget_Info(wWidget, FIND_BY_UNAME='xZinBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_xrange = info.xrange[1] - info.xrange[0]
        info.xrange[0] = info.xrange[0] + current_xrange/4.0
        info.xrange[1] = info.xrange[1] - current_xrange/4.0

        ; Make new plot
        sbNewPlot, Event, info
      ENDIF
    end
    ; ## Y Zoom In (twice) ##
    Widget_Info(wWidget, FIND_BY_UNAME='yZinBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_yrange = info.yrange[1] - info.yrange[0]
        info.yrange[0] = info.yrange[0] + current_yrange/4.0
        info.yrange[1] = info.yrange[1] - current_yrange/4.0

        ; Make new plot
        sbNewPlot, Event, info
      ENDIF
    end

    ; ##Scroll to Left##
    Widget_Info(wWidget, FIND_BY_UNAME='ScrLBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_xrange = info.xrange[1] - info.xrange[0]
        info.xrange[0] = info.xrange[0] - current_xrange*0.8
        info.xrange[1] = info.xrange[1] - current_xrange*0.8

        ; Make new plot
        sbNewPlot, Event, info
      ENDIF
    end
    ; ##Scroll to Right##
    Widget_Info(wWidget, FIND_BY_UNAME='ScrRBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_xrange = info.xrange[1] - info.xrange[0]
        info.xrange[0] = info.xrange[0] + current_xrange*0.8
        info.xrange[1] = info.xrange[1] + current_xrange*0.8

        ; Make new plot
        sbNewPlot, Event, info
      ENDIF
    end
    ; ##Scroll Up##
    Widget_Info(wWidget, FIND_BY_UNAME='ScrUBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_yrange = info.yrange[1] - info.yrange[0]
        info.yrange[0] = info.yrange[0] + current_yrange*0.8
        info.yrange[1] = info.yrange[1] + current_yrange*0.8

        ; Make new plot
        sbNewPlot, Event, info
      ENDIF
    end
    ; ##Scroll Down##
    Widget_Info(wWidget, FIND_BY_UNAME='ScrDBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_yrange = info.yrange[1] - info.yrange[0]
        info.yrange[0] = info.yrange[0] - current_yrange*0.8
        info.yrange[1] = info.yrange[1] - current_yrange*0.8

        ; Make new plot
        sbNewPlot, Event, info
      ENDIF
    end

    ; ##Switch Extra Button Display##
    Widget_Info(wWidget, FIND_BY_UNAME='ExtBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN $
        sbExtBtn, Event, info
    end

    ; ##Print Out##
    Widget_Info(wWidget, FIND_BY_UNAME='PrintBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' )THEN $
        zPrintBtn, Event, info
    end

    ; ##Make a PS file##
    Widget_Info(wWidget, FIND_BY_UNAME='PSBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' )THEN $
        zPSBtn, Event, info
    end

    ; ##Plot Symbol On/Off##
    Widget_Info(wWidget, FIND_BY_UNAME='SymbBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' )THEN BEGIN

        ; Get widget ID of SymbBtn
        LineBtn = Widget_Info(wWidget, FIND_BY_UNAME='LineBtn')
        IF (LineBtn NE 0) THEN BEGIN
          ; Switch widgets sensitive
          IF (info.psym EQ 0) THEN BEGIN
            Widget_Control, LineBtn, SENSITIVE=1
          ENDIF ELSE BEGIN
            Widget_Control, LineBtn, /SET_BUTTON
            Widget_Control, LineBtn, SENSITIVE=0
          ENDELSE
          info.line = Widget_Info(LineBtn, /BUTTON_SET)
        ENDIF

        ; Switch info.psym
        info.psym = (info.psym EQ 0) ? -7:0

        ; Make new plot
        sbNewPlot, Event, info

      ENDIF
    end

    ; ##Plot Line On/Off##
    Widget_Info(wWidget, FIND_BY_UNAME='LineBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' )THEN BEGIN

        ; Switch info.line
        info.line = (info.line EQ 0) ? 1:0

        ; Make new plot
        sbNewPlot, Event, info

      ENDIF
    end


    else: BEGIN;#####End of altered code#####

   ; Update window sizes.

event.x = (event.x -    5 > 150) ; adjust for the top level base

IF (!d.name eq 'X') THEN $
  event.y = (event.y -  120 > 200) $ ; adjust for a part of STAT display area (Linux, etc.)
ELSE $ ; !d.name eq 'WIN'
  event.y = (event.y -  100 > 200) ; adjust for a part of STAT display area (Win)

info.zxsize = event.x
info.zysize = event.y

   ; Destroy old pixmap and create a new one.

WDelete, info.pixIndex
Window, XSize=event.x, YSize=event.y, /Free, /Pixmap
info.pixIndex = !D. Window

   ; Resize draw widget.

Widget_Control, info.drawID, Draw_XSize=(event.x > 200), Draw_YSize=(event.y > 150)

   ;  Set up colors for line plot.
   backColor = GetColor('navy', !D.Table_Size-2)
   dataColor = GetColor('yellow', !D.Table_Size-3)
   axisColor = GetColor('green', !D.Table_Size-4)

   ;  Set up properties (line and symbol) of line plot.
   get_prop_plot, info, PSYMS=psyms

   ; Draw the plot in both windows.

Plot, info.indep, info.dep, $
  XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
  YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
  Xtitle=info.xtitle, XMargin=info.xmargin, $
  XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
  Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]

; Standard position of legends
title_pos1a = CONVERT_COORD([0.85, 0.90], /NORMAL, /TO_DATA)  ; for symbol
title_pos1b = CONVERT_COORD([0.86, 0.90], /NORMAL, /TO_DEVICE); for label string
title_pos1b = CONVERT_COORD(title_pos1b[0],title_pos1b[1]-5, /DEVICE, /TO_DATA)


WSet, info.drawIndex
Plot, info.indep, info.dep, $
  XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
  YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
  Xtitle=info.xtitle, XMargin=info.xmargin, $
  XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
  Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]


   ; Update system parameters.

info.x = !X
info.y = !Y
info.p = !P

Widget_Control, event.top, Set_UValue=info, /No_Copy

    end
  endcase

END ; of sbZPLOT_RESIZE **********************************************************


PRO sbZPLOT_PROCESS_EVENTS, event

   ; This event handler ONLY responds to button down events from the
   ; draw widget. If it gets a DOWN event, it does three things: (1) sets
   ; the static and dynamic corners of the arrow box, (2) changes the
   ; event handler for the draw widget to ZPLOT_DRAWBOX and turns on MOTION
   ; events, and (3) update the user's color table vectors.

On_Error, 2

possibleEventTypes = [ 'DOWN', 'UP', 'MOTION', 'SCROLL' ]
thisEvent = possibleEventTypes(event.type)
IF thisEvent NE 'DOWN' THEN RETURN

    ; Must be DOWN event to get here, so get info structure.

 Widget_Control, event.top, Get_UValue=info, /No_Copy

    ; Set the static corners of the arrow box to current
    ; cursor location.

 info.xs = event.x
 info.ys = event.y

    ; Change the event handler for the draw widget and turn MOTION
    ; events ON.

 Widget_Control, event.id, Event_Pro='sbZPLOT_DRAWBOX', $
    Draw_Motion_Events=1

   ; Put the info structure back into its storage location.

Widget_Control, event.top, Set_UValue=info, /No_Copy
END ; of sbZPLOT_PROCESS_EVENTS *****************************************************



PRO sbZPLOT_DRAWBOX, event

   ; This event handler continuously draws and erases the arrow box until it
   ; receives an UP event from the draw widget. Then it turns draw widget motion
   ; events OFF and changes the event handler for the draw widget back to
   ; ZPLOT_PROCESS_EVENTS.

   ; Get the info structure out of the top-level base.

Widget_Control, event.top, Get_UValue=info, /No_Copy

   ;  Set up colors for line plot.
   backColor = GetColor('navy', !D.Table_Size-2)
   dataColor = GetColor('yellow', !D.Table_Size-3)
   axisColor = GetColor('green', !D.Table_Size-4)
   boxColor = GetColor('beige', !D.Table_Size-5)


   ;  Set up properties (line and symbol) of line plot.
   get_prop_plot, info, PSYMS=psyms

   ; What type of an event is this?

possibleEventTypes = [ 'DOWN', 'UP', 'MOTION', 'SCROLL' ]
thisEvent = possibleEventTypes(event.type)

IF thisEvent EQ 'UP' THEN BEGIN

      ; If this is an UP event, you need to erase the zoombox, restore
      ; the user's color table, turn motion events OFF, set the
      ; draw widget's event handler back to ZPLOT_PROCESS_EVENTS, and
      ; draw the "zoomed" plot in both the draw widget and the pixmap.

      ; Erase the arrow box one final time by copying the plot from the pixmap.

   WSet, info.drawIndex
   Device, Copy = [0, 0, info.zxsize, info.zysize, 0, 0, info.pixIndex]

      ; Turn motion events off and redirect the events to ZPLOT_PROCESS_EVENTS.

    Widget_Control, event.id, Draw_Motion_Events=0, $
       Event_Pro='sbZPLOT_PROCESS_EVENTS'

      ; Draw the "zoomed" plot. Start by getting the new limits to the plot
      ; (i.e., the LAST zoom box outline).

   x = [info.xs, event.x]
   y = [info.ys, event.y]

;#
   ; Make sure the x values are ordered as [min, max].
   IF info.xs GT event.x THEN x = [event.x, info.xs]

   ; Don't want exact style if we are drawing entire plot.
   ;IF info.xs EQ event.x THEN xstyle = 0 ELSE xstyle = 1
   ;info.xstyle = xstyle

;#
   ; Make sure the y values are ordered as [min, max].
   IF info.ys GT event.y THEN y = [event.y, info.ys]

   ; Don't want exact style if we are drawing entire plot.
   ;IF info.ys EQ event.y THEN ystyle = 0 ELSE ystyle = 1
   ;info.ystyle = ystyle


   ; Restore plot system variables.
   !X = info.x
   !Y = info.y
   !P = info.p


   ; Convert the x device coordinates to data coordinates.
   coords = Convert_Coord(x, y, /Device, /To_Data)

;   ; Make sure the x coordinates are within the data boundaries of the plot.
;   IF info.xlog THEN BEGIN
;      x1 = 10^!X.CRange(0) > coords(0,0) < 10^!X.CRange(1)
;      x2 = 10^!X.CRange(0) > coords(0,1) < 10^!X.CRange(1)
;   ENDIF ELSE BEGIN
;      x1 = !X.CRange(0) > coords(0,0) < !X.CRange(1)
;      x2 = !X.CRange(0) > coords(0,1) < !X.CRange(1)
;   ENDELSE
   x1 = coords(0,0)
   x2 = coords(0,1)


   ;#####altered code#####
;   ; Make sure the y coordinates are within the data boundaries of the plot.
;   IF info.ylog THEN BEGIN
;      y1 = 10^!Y.CRange(0) > coords(1,0) < 10^!Y.CRange(1)
;      y2 = 10^!Y.CRange(0) > coords(1,1) < 10^!Y.CRange(1)
;   ENDIF ELSE BEGIN
;      y1 = !Y.CRange(0) > coords(1,0) < !Y.CRange(1)
;      y2 = !Y.CRange(0) > coords(1,1) < !Y.CRange(1)
;   ENDELSE
   y1 = coords(1,0)
   y2 = coords(1,1)


   ;###################################################################
   ;  Set frames to be bad
   ;###################################################################
   print, x1, x2
   remv_idx   = where((info.indep GE x1) AND (info.indep LE x2), cnt)

   IF (cnt GT 0) THEN BEGIN
     IF (size(info.indep, /type) EQ 4) OR (size(info.indep, /type) EQ 5) THEN BEGIN
       info.indep[remv_idx] = !Values.F_NaN
     ENDIF ELSE BEGIN
       info.indep[remv_idx] = 0
     ENDELSE
     IF (size(info.dep, /type) EQ 4) OR (size(info.dep, /type) EQ 5) THEN BEGIN
       info.dep[remv_idx]   = !Values.F_NaN
     ENDIF ELSE BEGIN
       info.dep[remv_idx]   = 0
     ENDELSE
   ENDIF

   idx_to_be_bad = where(finite(info.indep) EQ 0)
   IF (size(idx_to_be_bad, /n_dimensions) NE 0) THEN $
     info.to_be_bad[idx_to_be_bad] = 1
   ;###################################################################

   ; ## Set new ranges ##
   IF ((x1 NE x2) and (y1 NE y2)) THEN BEGIN
;     info.xrange = [x1,x2]
;     info.yrange = [y1,y2]
;     info.xstyle=1
;     info.ystyle=1
   ; When click without drag, does not change the ranges.
   ; But, print out the coordinates of the point.
   ENDIF ELSE BEGIN
     print, 'X:', x1, ',   Y:', y1
   ENDELSE

   ; ## Context menu event ##
   IF (event.RELEASE EQ 4) THEN BEGIN
     ; Obtain the widget ID of the context menu base.
     contextBase = WIDGET_INFO(event.TOP, FIND_BY_UNAME = 'drawContext')
     ; Display the context menu.
     WIDGET_DISPLAYCONTEXTMENU, event.ID, event.X, event.Y, contextBase
   ENDIF

   ; Back to the initial ranges
;   IF ((x1 EQ x2) or (y1 EQ y2)) THEN BEGIN
;     info.xrange = info.xrange_def
;     info.yrange = info.yrange_def
;   ENDIF
   ;######################


      ; Draw the "zoomed" plot in both the draw widget and the pixmap.

   Plot, info.indep, info.dep, $
     XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
     YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
     Xtitle=info.xtitle, XMargin=info.xmargin, $
     XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
     Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
   OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]

    ; Standard position of legends
   title_pos1a = CONVERT_COORD([0.85, 0.90], /NORMAL, /TO_DATA)  ; for symbol
   title_pos1b = CONVERT_COORD([0.86, 0.90], /NORMAL, /TO_DEVICE); for label string
   title_pos1b = CONVERT_COORD(title_pos1b[0],title_pos1b[1]-5, /DEVICE, /TO_DATA)


   WSet, info.pixIndex
   Plot, info.indep, info.dep, $
     XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
     YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
     Xtitle=info.xtitle, XMargin=info.xmargin, $
     XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
     Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
   OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]

      ; Update the plot system variables.

   info.x = !X
   info.y = !Y
   info.p = !P

      ; Put the info structure back into its storage location and then, out of here!

   Widget_Control, event.top, Set_UValue=info, /No_Copy
   RETURN
ENDIF ; thisEvent = UP


   ; Most of the action in this event handler occurs here while we are waiting
   ; for an UP event to occur. As long as we don't get it, keep erasing the
   ; old zoom box and drawing a new one.

   ; Erase the old zoom box.

WSet, info.drawIndex
Device, Copy = [0, 0, info.zxsize, info.zysize, 0, 0, info.pixIndex]

   ; Update the dynamic corner of the zoom box to the current cursor location.

 info.xd = event.x
 info.yd = event.y

   ; Restore plot system variables.

!X = info.x
!Y = info.y
!P = info.p

   ; Convert the x device coordinates to data coordinates.

x = [info.xs, event.x]
y = [info.ys, event.y]
coords = Convert_Coord(x, y, /Device, /To_Data)

;; Make sure the x coordinates are within the data boundaries of the plot.
;IF info.xlog THEN BEGIN
;   x1 = 10^!X.CRange(0) > coords(0,0) < 10^!X.CRange(1)
;   x2 = 10^!X.CRange(0) > coords(0,1) < 10^!X.CRange(1)
;ENDIF ELSE BEGIN
;   x1 = !X.CRange(0) > coords(0,0) < !X.CRange(1)
;   x2 = !X.CRange(0) > coords(0,1) < !X.CRange(1)
;ENDELSE

;; Make sure the y coordinates are within the data boundaries of the plot.
;IF info.ylog THEN BEGIN
;   y1 = 10^!Y.CRange(0) > coords(1,0) < 10^!Y.CRange(1)
;   y2 = 10^!Y.CRange(0) > coords(1,1) < 10^!Y.CRange(1)
;ENDIF ELSE BEGIN
;   y1 = !Y.CRange(0) > coords(1,0) < !Y.CRange(1)
;   y2 = !Y.CRange(0) > coords(1,1) < !Y.CRange(1)
;ENDELSE
x1 = coords(0,0)
x2 = coords(0,1)
y1 = coords(1,0)
y2 = coords(1,1)

   ; Draw the arrow box.
   Arrow, x1, y1, x2, y1, /Data, Color=boxColor, /Solid, HSize=12

IF info.ylog THEN BEGIN
   PlotS, [x1, x1], [y1, y2], Color=boxColor
   PlotS, [x2, x2], [y1, y2], Color=boxColor
;   PlotS, [x1, x2], [y1, y1], Color=boxColor
;   PlotS, [x1, x2], [y2, y2], Color=boxColor
ENDIF ELSE BEGIN
   PlotS, [x1, x1], [!Y.CRange[0], !Y.CRange[1]], Color=boxColor
   PlotS, [x2, x2], [!Y.CRange[0], !Y.CRange[1]], Color=boxColor
;   PlotS, [x1, x1], [y1, y2], Color=boxColor
;   PlotS, [x2, x2], [y1, y2], Color=boxColor
;   PlotS, [x1, x2], [y1, y1], Color=boxColor
;   PlotS, [x1, x2], [y2, y2], Color=boxColor
ENDELSE

   ; Put the info structure back into its storage location.

Widget_Control, event.top, Set_UValue=info, /No_Copy
END ; of sbZPLOT_DRAWBOX ******************************************************************



PRO SetBad_Plot, x, y, $
   XTitle=xtitle, $
   Zoom_XSize=zxsize, Zoom_YSize=zysize, XRANGE=xrange, XMargin=xmargin, $
   Group_Leader=group, XLog=xlog, YLog=ylog, PSYM=psym, FILENAME=filename, EXTBTN_MODE=extbtn_mode, $
   XOffset=xoffset, YOffset=yoffset, TickLen=ticklen, XTickFormat=xtickformat, YTickFormat=ytickformat, $
   X_Range2=x_range2, Y_Range2=y_range2, $ ; Used when this zplot_alt was called from another zplot_alt.)
   Xstyle=xstyle, Ystyle=ystyle, $
   PixNo = pixno, $
   _Extra=extra

   ; This procedure allows the user to "zoom" into the data plot
   ; by drawing an arrow box around the part of the data to zoom into.
   ; The arrow box will be drawn and erased by using a pixmap and
   ; the "Device Copy" technique.

   ; On an error condition, return to the main level of IDL.

On_Error, 1

   ; Was data passed into the procedure? If not, create some.

CASE N_Params() OF

   0: BEGIN
   dep = Findgen(101)
   dep = Sin(dep/5) / Exp(dep/50)
   indep = Findgen(101)
   ENDCASE

   1: BEGIN
   dep = x
   indep = Findgen(N_Elements(dep))
   ENDCASE

   2: BEGIN
   dep = y
   indep = x
   ENDCASE

ENDCASE

;;===============================================
;;  Mask the data by bad flags
;;===============================================
Common Share, tsd
badflag = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'BAD', PixNo=pixno)
badflag = reform(badflag)
idx_bad = where(badflag EQ 1, cnt_bad)

IF (cnt_bad GT 0) THEN BEGIN
  IF (size(indep, /type) EQ 4) OR (size(indep, /type) EQ 5) THEN BEGIN
    indep[idx_bad] = !Values.F_NaN
  ENDIF ELSE BEGIN
    indep[idx_bad] = 0
  ENDELSE
  IF (size(dep, /type) EQ 4) OR (size(dep, /type) EQ 5) THEN BEGIN
    dep[idx_bad]   = !Values.F_NaN
  ENDIF ELSE BEGIN
    dep[idx_bad]   = 0
  ENDELSE
ENDIF

idx_no_bad = where(finite(indep) EQ 1)
IF (size(idx_no_bad, /n_dimensions) EQ 0) THEN BEGIN
  print, 'All data are BAD!!'
  return
ENDIF
;;===============================================


;;  Set up colors for line plot.
backColor = GetColor('navy', !D.Table_Size-2)
dataColor = GetColor('yellow', !D.Table_Size-3)
axisColor = GetColor('green', !D.Table_Size-4)

;;===============================================
;; Check for keywords. Set defaults if necessary.
;;===============================================
IF N_Elements(zxsize) EQ 0 THEN zxsize = 400
IF N_Elements(zysize) EQ 0 THEN zysize = 400
xlog = Keyword_Set(xlog)
ylog = Keyword_Set(ylog)
;#
to_be_bad = make_array(n_elements(indep), /Long)
IF N_Elements(pixno) EQ 0 THEN BEGIN
  print, '"pixno" must be set!!'
  return
ENDIF
;#
IF N_Elements(xtitle)  EQ 0 THEN xtitle=''

IF N_Elements(xoffset) EQ 0 THEN xoffset=0.0
IF N_Elements(yoffset) EQ 0 THEN yoffset=0.0

IF N_Elements(ticklen) EQ 0 THEN ticklen=0.02
IF N_Elements(xtickformat) EQ 0 THEN xtickformat=''
IF N_Elements(ytickformat) EQ 0 THEN ytickformat=''
IF N_Elements(Xstyle) EQ 0 THEN xstyle=0
IF N_Elements(Ystyle) EQ 0 THEN ystyle=0

IF (Keyword_Set(psym) NE 1) THEN psym=0
line = 1 ; initialize as default
IF (Keyword_Set(filename) NE 1) THEN filename=''
IF (Keyword_Set(extbtn_mode) NE 1) THEN extbtn_mode=0 ; If extbtn_mode=1 then display extra buttons
;;===============================================

;;## Create a top-level base for this program. No resizing of this base.
tlb = Widget_Base(Title='BAD flag Setting tool: '+filename, TLB_Size_Events=1, column=1, UNAME='PlotWin', $
                  XOffset=xoffset, YOffset=yoffset)

;;## Draw widget will have its own event handler.
drawID = Widget_Draw(tlb, XSize=zxsize, YSize=zysize, $
   Button_Events=1, Event_Pro='sbZPLOT_PROCESS_EVENTS')


;;===============================================
;; Start of making control button base
;;===============================================
; Create buttons
ctrlbase = Widget_Base(tlb, column=1)

DispBtnbase = Widget_Base(ctrlbase, row=1, /frame, xpad=0, ypad=0)

  chkecbox_base = Widget_Base(DispBtnbase, row=1, /NONEXCLUSIVE)
    SymbBtn = Widget_Button(chkecbox_base, VALUE='Symbol', UNAME='SymbBtn', Tooltip='Symbol On/Off')
    IF (psym EQ 0) THEN Widget_Control, SymbBtn, SET_BUTTON=0 ELSE Widget_Control, SymbBtn, /SET_BUTTON

    IF (extbtn_mode EQ 1) THEN BEGIN
      sybm_status = Widget_Info(SymbBtn, /BUTTON_SET)
      LineBtn = Widget_Button(chkecbox_base, VALUE='Line', UNAME='LineBtn', Tooltip='Line On/Off', $
                              Sensitive=sybm_status)
      Widget_Control, LineBtn, /SET_BUTTON
    ENDIF

    GridBtn = Widget_Button(chkecbox_base, VALUE='Grid', UNAME='GridBtn', Tooltip='Grid On/Off')
    IF (ticklen EQ 0.02) THEN Widget_Control, GridBtn, SET_BUTTON=0 ELSE Widget_Control, GridBtn, /SET_BUTTON

  btn1base = Widget_Base(DispBtnbase, row=1)
    ResetBtn = Widget_Button(btn1base, xsize=40, value='Reset', uname='ResetBtn', Tooltip='Reset range')
    ASBtn = Widget_Button(btn1base, xsize=40, value='Auto', uname='ASBtn', Tooltip='Auto Scale')

    ZinBtn = Widget_Button(btn1base, xsize=30, value='ZoomIn.bmp', /bitmap, uname='ZinBtn', Tooltip='Zoom in')
    ZoutBtn = Widget_Button(btn1base, xsize=30, value='ZoomOut.bmp', /bitmap, uname='ZoutBtn', Tooltip='Zoom Out')

    IF (extbtn_mode EQ 1) THEN BEGIN
      xZinBtn = Widget_Button(btn1base, xsize=30, value='x+.bmp', /bitmap, uname='xZinBtn', Tooltip='X-axis Zoom in')
      xZoutBtn = Widget_Button(btn1base, xsize=30, value='x-.bmp', /bitmap, uname='xZoutBtn', Tooltip='X-axis Zoom Out')
      yZinBtn = Widget_Button(btn1base, xsize=30, value='y+.bmp', /bitmap, uname='yZinBtn', Tooltip='Y-axis Zoom in')
      yZoutBtn = Widget_Button(btn1base, xsize=30, value='y-.bmp', /bitmap, uname='yZoutBtn', Tooltip='Y-axis Zoom Out')
    ENDIF

    ScrLBtn = Widget_Button(btn1base, xsize=25, value='left_arr.bmp', /bitmap, uname='ScrLBtn', Tooltip='Scroll to Left')
    ScrRBtn = Widget_Button(btn1base, xsize=25, value='right_arr.bmp', /bitmap, uname='ScrRBtn', Tooltip='Scroll to Right')

    IF (extbtn_mode EQ 1) THEN BEGIN
      ScrUBtn = Widget_Button(btn1base, xsize=25, value='up_arr.bmp', /bitmap, uname='ScrUBtn', Tooltip='Scroll Up')
      ScrDBtn = Widget_Button(btn1base, xsize=25, value='down_arr.bmp', /bitmap, uname='ScrDBtn', Tooltip='Scroll Down')
    ENDIF

    IF (extbtn_mode EQ 0) THEN BEGIN
      ExtBtn = Widget_Button(btn1base, xsize=17, value='>>', uname='ExtBtn', Tooltip='Extra Mode')
    ENDIF ELSE BEGIN
      ExtBtn = Widget_Button(btn1base, xsize=17, value='<<', uname='ExtBtn', Tooltip='Simple Mode')
    ENDELSE


buttbase2 = Widget_Base(ctrlbase, row=1)
  ClsBtn = Widget_Button(buttbase2, value='Done', xsize=140, uname='ClsBtn', Tooltip='Done setting Bad flags')
;;===============================================
;; End of making control button base
;;===============================================


; Realize the program.
Widget_Control, tlb, /Realize

   ; Get the window index number of the draw widget.
   ; Make the draw widget the current graphics window
   ; and draw the plot of the data in it. Make the
   ; X data range exactly fit the data.

Widget_Control, drawID, Get_Value=drawIndex
WSet, drawIndex
IF N_Elements(xrange) EQ 0 THEN $
  xrange = [Min(indep), Max(indep)]
yrange = [min(dep), max(dep)]
xrange_def = xrange
yrange_def = yrange
IF (N_Elements(xmargin) EQ 0) THEN xmargin=[10.0, 3.0]

;; When this zplot_alt was called from another zplot_alt.
;;   (i.e. ExtBtn mode, HEX in Yaxis, etc.)
IF N_Elements(x_range2) NE 0 THEN xrange=x_range2
IF N_Elements(y_range2) NE 0 THEN yrange=y_range2


Plot, indep, dep, XRange=xrange, YRange=yrange, XMargin=xmargin, XLog=xlog, YLog=ylog, $
    Xticklen=ticklen, Xgridstyle=(ticklen NE 0.02) ? 1:0, Yticklen=ticklen, Ygridstyle=(ticklen NE 0.02) ? 1:0, $
    Xtitle=xtitle, XTickFormat=xtickformat, YTickFormat=ytickformat, Xstyle=xstyle, Ystyle=ystyle, $
    Background=backColor, Color=axisColor, /NoData, _Extra=extra
OPlot, indep, dep, Color=dataColor, psym=psym

; Standard position of legends
title_pos1a = CONVERT_COORD([0.85, 0.90], /NORMAL, /TO_DATA)  ; for symbol
title_pos1b = CONVERT_COORD([0.86, 0.90], /NORMAL, /TO_DEVICE); for label string
title_pos1b = CONVERT_COORD(title_pos1b[0],title_pos1b[1]-5, /DEVICE, /TO_DATA)


  ; Create a pixmap window the same size as the draw widget window.
  ; Store its window index number in a local variable. Draw the same
  ; plot you just put in the draw widget in the pixmap window.

Window, /Free, XSize=zxsize, YSize=zysize, /Pixmap
pixIndex = !D.Window
Plot, indep, dep, XRange=xrange, YRange=yrange, XMargin=xmargin, XLog=xlog, YLog=ylog, $
   Xticklen=ticklen, Xgridstyle=(ticklen NE 0.02) ? 1:0, Yticklen=ticklen, Ygridstyle=(ticklen NE 0.02) ? 1:0, $
   Xtitle=xtitle, XTickFormat=xtickformat, YTickFormat=ytickformat, Xstyle=xstyle, Ystyle=ystyle, $
   Background=backColor, Color=axisColor, /NoData, _Extra=extra
OPlot, indep, dep, Color=dataColor, psym=psym


IF N_Elements(extra) EQ 0 THEN extraKeywords = Ptr_New(/Allocate_Heap) ELSE extraKeywords = Ptr_New(extra)

;; Create an info structure to hold information required by the program.
info = { $
   dep:dep, $                       ; The dependent data to be plotted.
   xtitle:xtitle,   $               ;# (2005/11/02)
   indep:indep, $                   ; The independent data to be plotted.
   zxsize:zxsize, $                 ; The X size of the draw widget.
   zysize:zysize, $                 ; The Y size of the draw widget.
   drawID:drawID, $                 ; The widget identifier of the draw widget.
   drawIndex:drawIndex, $           ; The draw window index number.
   pixIndex:pixIndex, $             ; The pixmap window index number.
   xrange:xrange, $                 ; The current X range of the plot.
   yrange:yrange, $                 ; The current Y range of the plot.
   xrange_def:xrange_def, $         ;# default X range (2003/05/27)
   yrange_def:yrange_def, $         ;# default Y range (2003/04/24)
   xlog:xlog, $                     ; A flag for X logarithmic axis style.
   ylog:ylog, $                     ; A flag for Y logarithmic axis style.
   xstyle:xstyle, $                 ; The setting for the XStyle keyword.
   ystyle:ystyle, $                 ;# Added member (2003/04/24)
   ticklen:ticklen, $               ;# (2003/05/27)
   xmargin:xmargin, $               ;# (2004/04/20)
   ytickformat:ytickformat, $       ;# (2005/10/26)
   xtickformat:xtickformat, $       ;# (2005/11/02)
   xs:0d, $                         ; X static corner of the zoom box.
   ys:0d, $                         ; Y static corner of the zoom box.
   xd:0, $                          ; X dynamic corner of the zoom box.
   yd:0, $                          ; Y dynamic corner of the zoom box.
   x:!X, $                          ; The !X system variable after plot.
   y:!Y, $                          ; The !Y system variable after plot.
   p:!P, $                          ; The !P system variable after plot.
   psym:psym, $                     ;# New Added member (2003/03/27)
   line:line, $                     ;# (2005/03/18)
   filename:filename, $             ;# (2003/06/05)
   extbtn_mode:extbtn_mode, $       ;# To display extra buttons (2005/03/17)
   to_be_bad:to_be_bad, $           ;#########################################
   pixno:pixno, $
   extraKeywords:extraKeywords }    ; Extra plot keywords pointer.

  ; Store the info structure in the user value of the top-level base.
  Widget_Control, tlb, Set_UValue=info, /No_Copy


  ; Register this program and set up the event loop.
  XManager, 'SETBAD_PLOT', tlb, Cleanup='ZPLOT_Cleanup', Group_Leader=group, /No_Block, $
    Event_Handler='sbZPLOT_Resize'

END ; of ZPLOT_ALT ************************************************************************
