; $Id: sw_tree_wid.pro,v 1.16 2006/05/08 08:20:31 makiuti Exp $
;+
; NAME:
;       SW_TREE_WID
;
; PURPOSE:
;       The purpose of this procedure is to (re)map the data
;       selector tree widgets in the FISv. This one is for SW
;       detector. This procedure is called by FISv.
;
; AUTHOR:
;       ASTRO-F Data Reduction team
;       Web Page: http://www.ir.isas.ac.jp/ASTRO-F/iris_data/
;
; CATEGORY:
;       FIS Data Visualizer
;
; CALLING SEQUENCE:
;       sw_tree_wid, Event, pre_detector
;          'pre_detector' indicates detector type (SW or LW)
;
; MODIFICATION HISTORY:
;        Written by: Makiuti,S.
;        2006/05/08 Last modified
;-

pro sw_tree_wid, Event, pre_detector

IF (pre_detector EQ 0) THEN BEGIN ; If previous TSD was SW
  X_TREENODE_1 = widget_info(Event.top, find_by_uname='X_TREENODE_1')
  Y_TREENODE_4 = widget_info(Event.top, find_by_uname='Y_TREENODE_4')

  Widget_control, X_TREENODE_1, /SET_TREE_EXPANDED
  Widget_control, Y_TREENODE_4, /SET_TREE_EXPANDED


ENDIF ELSE BEGIN ; If previous TSD was LW or neither SW nor LW

  Widget_Control, Event.top, UPDATE=0

  X_TREENODE_1 = widget_info(Event.top, find_by_uname='X_TREENODE_1')
  Y_TREENODE_4 = widget_info(Event.top, find_by_uname='Y_TREENODE_4')

  Widget_control, X_TREENODE_1, /SET_TREE_EXPANDED
  Widget_control, Y_TREENODE_4, /SET_TREE_EXPANDED

  ;# Make VDET brances #
  X_TREENODE_48 = widget_info(Event.top, find_by_uname='X_TREENODE_48')
  Y_TREENODE_48 = widget_info(Event.top, find_by_uname='Y_TREENODE_48')

  ; X
  pixmin = (widget_info(X_TREENODE_48, /child) eq 0) ? 101:76
  FOR i = pixmin, 100 DO BEGIN

    IF (i LE 9) THEN BEGIN
      pix_str = string(i, format='(I1)')
    ENDIF ELSE IF ((i GE 10) AND (i LE 99)) THEN BEGIN
      pix_str = string(i, format='(I2)')
    ENDIF ELSE IF (i EQ 100) THEN BEGIN
      pix_str = string(i, format='(I3)')
    ENDIF

    temp_str1 = 'X_TREE_VDET'+pix_str
    temp_str1 = Widget_Tree(X_TREENODE_48, UNAME='X_TREE_VDET'+pix_str $
      , VALUE=pix_str, UVALUE='VDET'+pix_str)

  ENDFOR

  ; Y
  pixmin = (widget_info(Y_TREENODE_48, /child) eq 0) ? 101:76
  FOR i = pixmin, 100 DO BEGIN

    IF (i LE 9) THEN BEGIN
      pix_str = string(i, format='(I1)')
    ENDIF ELSE IF ((i GE 10) AND (i LE 99)) THEN BEGIN
      pix_str = string(i, format='(I2)')
    ENDIF ELSE IF (i EQ 100) THEN BEGIN
      pix_str = string(i, format='(I3)')
    ENDIF

    temp_str1 = 'Y_TREE_VDET'+pix_str
    temp_str1 = Widget_Tree(Y_TREENODE_48, UNAME='Y_TREE_VDET'+pix_str $
      , VALUE=pix_str, UVALUE='VDET'+pix_str)

  ENDFOR


  ;# Make FLUX brances #
  X_TREENODE_49 = widget_info(Event.top, find_by_uname='X_TREENODE_49')
  Y_TREENODE_49 = widget_info(Event.top, find_by_uname='Y_TREENODE_49')

  ; X
  pixmin = (widget_info(X_TREENODE_49, /child) eq 0) ? 101:76
  FOR i = pixmin, 100 DO BEGIN

    IF (i LE 9) THEN BEGIN
      pix_str = string(i, format='(I1)')
    ENDIF ELSE IF ((i GE 10) AND (i LE 99)) THEN BEGIN
      pix_str = string(i, format='(I2)')
    ENDIF ELSE IF (i EQ 100) THEN BEGIN
      pix_str = string(i, format='(I3)')
    ENDIF

    temp_str1 = 'X_TREE_FLUX'+pix_str
    temp_str1 = Widget_Tree(X_TREENODE_49, UNAME='X_TREE_FLUX'+pix_str $
      , VALUE=pix_str, UVALUE='FLUX'+pix_str)

  ENDFOR

  ; Y
  pixmin = (widget_info(Y_TREENODE_49, /child) eq 0) ? 101:76
  FOR i = pixmin, 100 DO BEGIN

    IF (i LE 9) THEN BEGIN
      pix_str = string(i, format='(I1)')
    ENDIF ELSE IF ((i GE 10) AND (i LE 99)) THEN BEGIN
      pix_str = string(i, format='(I2)')
    ENDIF ELSE IF (i EQ 100) THEN BEGIN
      pix_str = string(i, format='(I3)')
    ENDIF

    temp_str1 = 'Y_TREE_FLUX'+pix_str
    temp_str1 = Widget_Tree(Y_TREENODE_49, UNAME='Y_TREE_FLUX'+pix_str $
      , VALUE=pix_str, UVALUE='FLUX'+pix_str)

  ENDFOR


  ;# Make FERR brances #
  X_TREENODE_50 = widget_info(Event.top, find_by_uname='X_TREENODE_50')
  Y_TREENODE_50 = widget_info(Event.top, find_by_uname='Y_TREENODE_50')

  ; X
  pixmin = (widget_info(X_TREENODE_50, /child) eq 0) ? 101:76
  FOR i = pixmin, 100 DO BEGIN

    IF (i LE 9) THEN BEGIN
      pix_str = string(i, format='(I1)')
    ENDIF ELSE IF ((i GE 10) AND (i LE 99)) THEN BEGIN
      pix_str = string(i, format='(I2)')
    ENDIF ELSE IF (i EQ 100) THEN BEGIN
      pix_str = string(i, format='(I3)')
    ENDIF

    temp_str1 = 'X_TREE_FERR'+pix_str
    temp_str1 = Widget_Tree(X_TREENODE_50, UNAME='X_TREE_FERR'+pix_str $
      , VALUE=pix_str, UVALUE='FERR'+pix_str)

  ENDFOR

  ; Y
  pixmin = (widget_info(Y_TREENODE_50, /child) eq 0) ? 101:76
  FOR i = pixmin, 100 DO BEGIN

    IF (i LE 9) THEN BEGIN
      pix_str = string(i, format='(I1)')
    ENDIF ELSE IF ((i GE 10) AND (i LE 99)) THEN BEGIN
      pix_str = string(i, format='(I2)')
    ENDIF ELSE IF (i EQ 100) THEN BEGIN
      pix_str = string(i, format='(I3)')
    ENDIF

    temp_str1 = 'Y_TREE_FERR'+pix_str
    temp_str1 = Widget_Tree(Y_TREENODE_50, UNAME='Y_TREE_FERR'+pix_str $
      , VALUE=pix_str, UVALUE='FERR'+pix_str)

  ENDFOR


  ;# Destroy and Remake Pix_Flag branches #
  X_TREE_PIX_FLAG = widget_info(Event.top, find_by_uname='X_TREE_PIX_FLAG')
  Y_TREE_PIX_FLAG = widget_info(Event.top, find_by_uname='Y_TREE_PIX_FLAG')

  ; X
  IF (widget_info(X_TREE_PIX_FLAG, /child) ne 0) THEN BEGIN
    Widget_control, X_TREE_PIX_FLAG, /DESTROY
    X_TREENODE_5 = Widget_Info(Event.top, find_by_uname='X_TREENODE_5')
    X_TREE_PIX_FLAG = Widget_Tree(X_TREENODE_5, UNAME='X_TREE_PIX_FLAG'  $
      ,/FOLDER ,VALUE='PIX_FLAG', UVALUE='XFlag')
  ENDIF

  ; Y
  IF (widget_info(Y_TREE_PIX_FLAG, /child) ne 0) THEN BEGIN
    Widget_control, Y_TREE_PIX_FLAG, /DESTROY
    Y_TREENODE_5 = Widget_Info(Event.top, find_by_uname='Y_TREENODE_5')
    Y_TREE_PIX_FLAG = Widget_Tree(Y_TREENODE_5, UNAME='Y_TREE_PIX_FLAG'  $
      ,/FOLDER ,VALUE='PIX_FLAG', UVALUE='YFlag')
  ENDIF

  ;# Destroy and Remake Quality branches #
  X_TREE_QUALITY = widget_info(Event.top, find_by_uname='X_TREE_QUALITY')
  Y_TREE_QUALITY = widget_info(Event.top, find_by_uname='Y_TREE_QUALITY')

  ; X
  IF (widget_info(X_TREE_QUALITY, /child) ne 0) THEN BEGIN
    Widget_control, X_TREE_QUALITY, /DESTROY
    X_TREENODE_0 = Widget_Info(Event.top, find_by_uname='X_TREENODE_0')
    X_TREE_QUALITY = Widget_Tree(X_TREENODE_0, UNAME='X_TREE_QUALITY'  $
      ,/FOLDER ,VALUE='Quality', UVALUE='XQual')
  ENDIF

  ; Y
  IF (widget_info(Y_TREE_QUALITY, /child) ne 0) THEN BEGIN
    Widget_control, Y_TREE_QUALITY, /DESTROY
    Y_TREENODE_0 = Widget_Info(Event.top, find_by_uname='Y_TREENODE_0')
    Y_TREE_QUALITY = Widget_Tree(Y_TREENODE_0, UNAME='Y_TREE_QUALITY'  $
      ,/FOLDER ,VALUE='Quality', UVALUE='YQual')
  ENDIF

  ;# Destroy and Remake Counter branches #
  X_TREE_COUNTER = widget_info(Event.top, find_by_uname='X_TREE_COUNTER')
  Y_TREE_COUNTER = widget_info(Event.top, find_by_uname='Y_TREE_COUNTER')

  ; X
  IF (widget_info(X_TREE_COUNTER, /child) ne 0) THEN BEGIN
    Widget_control, X_TREE_COUNTER, /DESTROY
    X_TREENODE_0 = Widget_Info(Event.top, find_by_uname='X_TREENODE_0')
    X_TREE_COUNTER = Widget_Tree(X_TREENODE_0, UNAME='X_TREE_COUNTER'  $
      ,/FOLDER ,VALUE='Counter', UVALUE='XCunt')
  ENDIF

  ; Y
  IF (widget_info(Y_TREE_COUNTER, /child) ne 0) THEN BEGIN
    Widget_control, Y_TREE_COUNTER, /DESTROY
    Y_TREENODE_0 = Widget_Info(Event.top, find_by_uname='Y_TREENODE_0')
    Y_TREE_COUNTER = Widget_Tree(Y_TREENODE_0, UNAME='Y_TREE_COUNTER'  $
      ,/FOLDER ,VALUE='Counter', UVALUE='YCunt')
  ENDIF


  Widget_Control, Event.top, /UPDATE

ENDELSE

end
