;+
; NAME:
;       VIEW_FITS_HEADER
;
; PURPOSE:
;       The purpose of this procedure is to show the FIS header
;       of a TSD file.
;       This procedure is called by FISv.
;
; AUTHOR:
;       ASTRO-F Data Reduction team
;       Web Page: http://www.ir.isas.ac.jp/ASTRO-F/iris_data/
;
; CATEGORY:
;       FIS Data Visualizer
;
; CALLING SEQUENCE:
;       view_fits_header, LOCATION=location, Group_Leader=group
;
; MODIFICATION HISTORY:
;        Written by: Makiuti,S.
;        04/10/16 last modified
;-

; Simple event-handler routine
PRO view_fits_header_event, ev

  ; Retrieve the anonymous structure contained in the user value of
  ; the top-level base widget.
  WIDGET_CONTROL, ev.TOP, GET_UVALUE=stash

  ; If the user clicked the 'Done' button, destroy the widgets.
  IF (ev.ID EQ stash.bDone) THEN WIDGET_CONTROL, ev.TOP, /DESTROY

END

; Widget creation routine.
PRO view_fits_header, LOCATION=location, Group_Leader=group
COMMON Share, tsd

  ; for TEST
  ;tsd=Obj_New('tsd')
  ;result=tsd->read_tsd('/home/makiuti/ASTRO-F/SampleFITS/fis20030804_105659_02_lw.fits')
  ;result=tsd->read_tsd('C:\RSI\sample_fits\TSD2\fis20030804_105659_01_lw.fits')

  tsd_filename = tsd->get_filename()

  ; Create the top-level base and the tab.
  wTLB = WIDGET_BASE(/COLUMN, /BASE_ALIGN_TOP, TITLE='TSD FITS Header of '+tsd_filename, GROUP_LEADER=group)
  wTab = WIDGET_TAB(wTLB, LOCATION=location)

  ; Set font
  font_set = (!d.name EQ 'WIN') ? 'Courier*fixed*14':''

  ; Create the tab base for the 'Primary' header
  header = tsd->get_header_tsd()

  wT1 = WIDGET_BASE(wTab, TITLE='Primary', /COLUMN)
  wLabel2 = WIDGET_LABEL(wT1, VALUE='Primary Header')
  wText1 = Widget_text(wT1, SCR_XSIZE=550, SCR_YSIZE=450, /Scroll, FONT=font_set)
  Widget_control, wText1, Set_value = header


  ; Create the tab base for the 'FIS_OBS' header
  header = tsd->get_header_tsd('FIS_OBS')

  wT2 = WIDGET_BASE(wTab, TITLE='FIS_OBS', /COLUMN)
  wLabel2 = WIDGET_LABEL(wT2, VALUE='FIS_OBS Header')
  wText2 = Widget_text(wT2, SCR_XSIZE=550, SCR_YSIZE=450, /Scroll, FONT=font_set)
  Widget_control, wText2, Set_value = header


  ; Create the tab base for the 'FIS_HK' header
  header = tsd->get_header_tsd('FIS_HK')

  wT8 = WIDGET_BASE(wTab, TITLE='FIS_HK', /COLUMN)
  wLabel8 = WIDGET_LABEL(wT8, VALUE='FIS_HK Header')
  wText8 = Widget_text(wT8, SCR_XSIZE=550, SCR_YSIZE=450, /Scroll, FONT=font_set)
  Widget_control, wText8, Set_value = header


  ; Create the tab base for the 'IRC_HK' header
  header = tsd->get_header_tsd('IRC_HK')

  wT3 = WIDGET_BASE(wTab, TITLE='IRC_HK', /COLUMN)
  wLabel3 = WIDGET_LABEL(wT3, VALUE='IRC_HK Header')
  wText3 = Widget_text(wT3, SCR_XSIZE=550, SCR_YSIZE=450, /Scroll, FONT=font_set)
  Widget_control, wText3, Set_value = header


  ; Create the tab base for the 'HK_2' header
  header = tsd->get_header_tsd('HK_2')

  wT4 = WIDGET_BASE(wTab, TITLE='HK_2', /COLUMN)
  wLabel4 = WIDGET_LABEL(wT4, VALUE='HK_2 (CRYO) Header')
  wText4 = Widget_text(wT4, SCR_XSIZE=550, SCR_YSIZE=450, /Scroll, FONT=font_set)
  Widget_control, wText4, Set_value = header


  ; Create the tab base for the 'AOCU' header
  header = tsd->get_header_tsd('AOCU')

  wT5 = WIDGET_BASE(wTab, TITLE='AOCU', /COLUMN)
  wLabel5 = WIDGET_LABEL(wT5, VALUE='AOCU Header')
  wText5 = Widget_text(wT5, SCR_XSIZE=550, SCR_YSIZE=450, /Scroll, FONT=font_set)
  Widget_control, wText5, Set_value = header


  ; Create the tab base for the 'ADS' header
  header = tsd->get_header_tsd('GADS')

  wT7 = WIDGET_BASE(wTab, TITLE='GADS', /COLUMN)
  wLabel7 = WIDGET_LABEL(wT7, VALUE='GADS Header')
  wText7 = Widget_text(wT7, SCR_XSIZE=550, SCR_YSIZE=450, /Scroll, FONT=font_set)
  Widget_control, wText7, Set_value = header


  ; Create the tab base for the 'PR' header
  header = tsd->get_header_tsd('PR')

  wT8 = WIDGET_BASE(wTab, TITLE='PR', /COLUMN)
  wLabel8 = WIDGET_LABEL(wT8, VALUE='PR Header')
  wText8 = Widget_text(wT8, SCR_XSIZE=550, SCR_YSIZE=450, /Scroll, FONT=font_set)
  Widget_control, wText8, Set_value = header


  ; Create the tab base for the 'SE' header
  header = tsd->get_header_tsd('SE')

  wT6 = WIDGET_BASE(wTab, TITLE='SE', /COLUMN)
  wLabel6 = WIDGET_LABEL(wT6, VALUE='SE Header')
  wText6 = Widget_text(wT6, SCR_XSIZE=550, SCR_YSIZE=450, /Scroll, FONT=font_set)
  Widget_control, wText6, Set_value = header



  ; Create a base widget to hold the 'Done' button, and
  ; the button itself.
  wControl = WIDGET_BASE(wTLB, /ROW)
  bDone = WIDGET_BUTTON(wControl, VALUE='Done', XSIZE=100)

  ; Create an anonymous structure to hold widget IDs. This
  ; structure becomes the user value of the top-level base
  ; widget.
  stash = { bDone:bDone }

  ; Realize the widgets, set the user value of the top-level
  ; base, and call XMANAGER to manage everything.
  WIDGET_CONTROL, wTLB, /REALIZE
  WIDGET_CONTROL, wTLB, SET_UVALUE=stash
  XMANAGER, 'view_fits_header', wTLB, /NO_BLOCK

END
