; $Id: xydata.pro,v 1.19 2007/02/05 07:16:44 makiuti Exp $
;+
; NAME:
;       XYDATA
;
; PURPOSE:
;       The purpose of this procedure is to get X, Y data and titles
;       for the selected branch of TSD. The data and titles are used
;       in plot or some routines in the FISv.
;
; AUTHOR:
;       ASTRO-F Data Reduction team
;       Web Page: http://www.ir.isas.jaxa.jp/ASTRO-F/iris_data/
;
; CATEGORY:
;       FIS Data Visualizer
;
; CALLING SEQUENCE:
;       xyData, xuvalue, yuvalue, x, y, xtitle, ytitle, title
;       (*) xuvalue and yuvalue must be defined in caller
;
; RESTRICTIONS:
;
; MODIFICATION HISTORY:
;        Written by: Makiuti,S.
;        2007/02/05  Last modified
;-

pro xyData, xuvalue, yuvalue, x, y, xtitle, ytitle, title
COMMON Share

  ; X values

  ; (0) Index (Sample number)
  IF strmatch(xuvalue, 'Sample#') THEN BEGIN
    cti = tsd->get_value_tsd('FIS_OBS', 'PIMTI')
    x = indgen(n_elements(cti), /LONG)
    xtitle = 'Sample number'

  ; ## FIS_OBS
  ; (1) Time
  ENDIF ELSE IF strmatch(xuvalue, 'AFTIME') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'AFTIME')
    xtitle = 'AF TIME'
  ENDIF ELSE IF strmatch(xuvalue, 'PIM_TI_ORG') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'PIMTIORG')
    xtitle = 'PIM TI original'
  ENDIF ELSE IF strmatch(xuvalue, 'FIS_TI_ORG') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'FISTIORG')
    xtitle = 'FIS TI original'
  ENDIF ELSE IF strmatch(xuvalue, 'PIM_TI_ITP') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'PIMTI')
    xtitle = 'PIM TI interpolated'
  ENDIF ELSE IF strmatch(xuvalue, 'FIS_TI_ITP') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'FISTI')
    xtitle = 'FIS TI interpolated'

  ; (4) Detector Data
  ENDIF ELSE IF strmatch(xuvalue, 'VDET*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    vdet = tsd->get_value_tsd('FIS_OBS', 'DET')
    x = transpose( vdet[ch-1, *] )
    xtitle = 'Signal (ADU)'
  ENDIF ELSE IF strmatch(xuvalue, 'FLUX*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    flux = tsd->get_value_tsd('FIS_OBS', 'FLUX')
    x = transpose( flux[ch-1, *] )
    xtitle = 'Signal'
  ENDIF ELSE IF strmatch(xuvalue, 'FERR*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    ferr = tsd->get_value_tsd('FIS_OBS', 'FERR')
    x = transpose( ferr[ch-1, *] )
    xtitle = 'Flux error'

  ; (2) Status
  ENDIF ELSE IF strmatch(xuvalue, 'CREON') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'creon')
    xtitle = 'CRE ON'
  ENDIF ELSE IF strmatch(xuvalue, 'ShtOp') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'SHTOP')
    xtitle = 'ShtOp'
  ENDIF ELSE IF strmatch(xuvalue, 'FWposOn') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'fwposon')
    xtitle = 'FWposOn'
  ENDIF ELSE IF strmatch(xuvalue, 'FWpos_B1') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'fwpos_b1')
    xtitle = 'FWpos_B1'
  ENDIF ELSE IF strmatch(xuvalue, 'FWpos_B0') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'fwpos_b0')
    xtitle = 'FWpos_B0'
  ENDIF ELSE IF strmatch(xuvalue, 'MposOn') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'mposon')
    xtitle = 'MposOn'
  ENDIF ELSE IF strmatch(xuvalue, 'Mpos_B1') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'mpos_b1')
    xtitle = 'Mpos_B1'
  ENDIF ELSE IF strmatch(xuvalue, 'Mpos_B0') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'mpos_b0')
    xtitle = 'Mpos_B0'
  ENDIF ELSE IF strmatch(xuvalue, 'RstWideLOn') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'rstwidelon')
    xtitle = 'RstWideLOn'
  ENDIF ELSE IF strmatch(xuvalue, 'RstWideSOn') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'rstwideson')
    xtitle = 'RstWideSOn'
  ENDIF ELSE IF strmatch(xuvalue, 'RstN170On') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'rstn170on')
    xtitle = 'RstN170On'
  ENDIF ELSE IF strmatch(xuvalue, 'RstN60On') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'rstn60on')
    xtitle = 'RstN60On'
  ENDIF ELSE IF strmatch(xuvalue, 'LWboostOn') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'lwbooston')
    xtitle = 'LWboostOn'
  ENDIF ELSE IF strmatch(xuvalue, 'SWboostOn') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'swbooston')
    xtitle = 'SWboostOn'
  ENDIF ELSE IF strmatch(xuvalue, 'LWbiasOn') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'lwbiason')
    xtitle = 'LWbiasOn'
  ENDIF ELSE IF strmatch(xuvalue, 'SWbiasOn') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'swbiason')
    xtitle = 'SWbiasOn'
  ENDIF ELSE IF strmatch(xuvalue, 'CalALOn') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'calalon')
    xtitle = 'CalALOn'
  ENDIF ELSE IF strmatch(xuvalue, 'CalASOn') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'calason')
    xtitle = 'CalASOn'
  ENDIF ELSE IF strmatch(xuvalue, 'CalBOn') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'calbon')
    xtitle = 'CalBOn'
  ENDIF ELSE IF strmatch(xuvalue, 'SinALOn') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'sinalon')
    xtitle = 'SinALOn'
  ENDIF ELSE IF strmatch(xuvalue, 'SinASOn') THEN BEGIN
    x = tsd->get_status_tsd('FIS_OBS', 'sinason')
    xtitle = 'SinASOn'

  ; (3) Analog Telemetry
  ENDIF ELSE IF strmatch(xuvalue, 'PacketID') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'packetid')
    xtitle = 'Packet ID'
  ; Counter
  ENDIF ELSE IF strmatch(xuvalue, 'RstCntWideL') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'rstcntwidel')
    xtitle = 'Reset Count WideL'
  ENDIF ELSE IF strmatch(xuvalue, 'RstCntWideS') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'rstcntwides')
    xtitle = 'Reset Count WideS'
  ENDIF ELSE IF strmatch(xuvalue, 'RstCntN170') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'rstcntn170')
    xtitle = 'Reset Count N170'
  ENDIF ELSE IF strmatch(xuvalue, 'RstCntN60') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'rstcntn60')
    xtitle = 'Reset Count N60'
  ENDIF ELSE IF strmatch(xuvalue, 'CalPlsCntAL') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'calplscntal')
    xtitle = 'CalPlsCntAL'
  ENDIF ELSE IF strmatch(xuvalue, 'CalPlsCntAS') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'calplscntas')
    xtitle = 'CalPlsCntAS'
  ENDIF ELSE IF strmatch(xuvalue, 'CalPlsCntB') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'calplscntb')
    xtitle = 'CalPlsCntB'
  ENDIF ELSE IF strmatch(xuvalue, 'ADErrCntSW') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'aderrcntsw')
    xtitle = 'ADErrCntSW'
  ENDIF ELSE IF strmatch(xuvalue, 'ADErrCntLW') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'aderrcntlw')
    xtitle = 'ADErrCntLW'
  ENDIF ELSE IF strmatch(xuvalue, 'MPosCnt') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'mposcnt')
    xtitle = 'MPosCnt'
  ; DAC value
  ENDIF ELSE IF strmatch(xuvalue, 'DacBiasWideS') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'dacbiaswides')
    xtitle = 'DacBiasWideS'
  ENDIF ELSE IF strmatch(xuvalue, 'DacBiasN60') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'dacbiasn60')
    xtitle = 'DacBiasN60'
  ENDIF ELSE IF strmatch(xuvalue, 'DacBiasWideL') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'dacbiaswidel')
    xtitle = 'DacBiasWideL'
  ENDIF ELSE IF strmatch(xuvalue, 'DacBiasN170') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'dacbiasn170')
    xtitle = 'DacBiasN170'
  ENDIF ELSE IF strmatch(xuvalue, 'DacCalAS') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'daccalas')
    xtitle = 'DacCalAS'
  ENDIF ELSE IF strmatch(xuvalue, 'DacCalAL') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'daccalal')
    xtitle = 'DacCalAL'
  ENDIF ELSE IF strmatch(xuvalue, 'DacCalB') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'daccalb')
    xtitle = 'DacCalB'
  ENDIF ELSE IF strmatch(xuvalue, 'DacSinAS') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'dacsinas')
    xtitle = 'DacSinAS'
  ENDIF ELSE IF strmatch(xuvalue, 'DacSinAL') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'dacsinal')
    xtitle = 'DacSinAL'
  ; Temperature
  ENDIF ELSE IF strmatch(xuvalue, 'TpBody') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'tpbody')
    xtitle = 'TpBody'
  ENDIF ELSE IF strmatch(xuvalue, 'TpSW') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'tpsw')
    xtitle = 'TpSW'
  ENDIF ELSE IF strmatch(xuvalue, 'TpLW') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'tplw')
    xtitle = 'TpLW'
  ENDIF ELSE IF strmatch(xuvalue, 'TpCalFT') THEN BEGIN
    x = tsd->get_value_tsd('FIS_OBS', 'tpcalft')
    xtitle = 'TpCalFT'

  ; (5) Flags
  ENDIF ELSE IF strmatch(xuvalue, 'BAD_FRAME') EQ 1 THEN BEGIN
    x = tsd->Get_Flag_TSD('FIS_OBS', 'BAD_FRAME')
    xtitle = 'Bad_Frame Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'UNDEF_ANOM_FRAME') EQ 1 THEN BEGIN
    x = tsd->Get_Flag_TSD('FIS_OBS', 'UNDEF_ANOM_FRAME')
    xtitle = 'Undef_Anom_Frame Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'BLANK') EQ 1 THEN BEGIN
    x = tsd->Get_Flag_TSD('FIS_OBS', 'BLANK')
    xtitle = 'Blank Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'IN_SAA') EQ 1 THEN BEGIN
    x = tsd->Get_Flag_TSD('FIS_OBS', 'IN_SAA')
    xtitle = 'In_SAA Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'NEAR_MOON') EQ 1 THEN BEGIN
    x = tsd->Get_Flag_TSD('FIS_OBS', 'NEAR_MOON')
    xtitle = 'Near_MOON Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'UNTRUSTED_FRAME') EQ 1 THEN BEGIN
    x = tsd->Get_Flag_TSD('FIS_OBS', 'UNTRUSTED_FRAME')
    xtitle = 'Untrusted_frame Flag'

  ; Pix_Flag
  ENDIF ELSE IF strmatch(xuvalue, 'BAD_*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'BAD', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'BAD Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'UANM*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'UNDEF_ANOM', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'Undef_Anom Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'AERR*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'ARITH_ERR', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'Arith_Err Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'DEAD*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'DEAD', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'DEAD Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'SATU*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'SATURATE', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'SATURATE Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'REST*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'RESET', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'RESET Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'RANM*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'RSTANOM', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'RSTANOM Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'NDIF*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_DIFF', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'NO_DIFF Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'NRPC*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_RP_CORR', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'NO_RP_CORR Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'NDKC*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_DK_CORR', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'NO_DK_CORR Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'NDCC*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_DCCAL_CORR', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'NO_DCCAL_CORR Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'NTRC*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_TR_CORR', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'NO_TR_CORR Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'NFLF*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_FLAT_FIELD', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'NO_FLAT_FIELD Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'NGPG*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_GPGL', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'NO_GPGL Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'NMTG*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_MTGL', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'NO_MTGL Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'NABC*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_ABSCAL', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'NO_ABSCAL Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'GPG1*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'GPGL_TYPE1', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'GPGL_TYPE1 Flag 0/1'
  ENDIF ELSE IF strmatch(xuvalue, 'GPG2*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'GPGL_TYPE2', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'GPGL_TYPE2 Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'GPG3*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'GPGL_TYPE3', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'GPGL_TYPE3 Flag 0/1'
  ENDIF ELSE IF strmatch(xuvalue, 'GPG4*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'GPGL_TYPE4', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'GPGL_TYPE4 Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'GPGT*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'GPGL_TAIL', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'GPGL_TAIL Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'MTG1*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'MTGL_TYPE1', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'MTGL_TYPE1 Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'MTG2*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'MTGL_TYPE2', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'MTGL_TYPE2 Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'MTG3*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'MTGL_TYPE3', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'MTGL_TYPE3 Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'MTG4*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'MTGL_TYPE4', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'MTGL_TYPE4 Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'MTGT*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'MTGL_TAIL', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'MTGL_TAIL Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'NPER*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_PERI_CORR', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'NO_PERI_CORR Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'SPAK*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'SX_PEAK', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'SX_PEAK Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'SRCE*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'SX_SOURCE', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'SX_SOURCE Flag'
  ENDIF ELSE IF strmatch(xuvalue, 'SOBJ*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'SX_OBJ', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'SX_OBJ Flag'

  ; (6) Quality
  ENDIF ELSE IF strmatch(xuvalue, 'QCVP*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_CV_PARAM', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_CV_PARAM'
  ENDIF ELSE IF strmatch(xuvalue, 'QRCP*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_RC_PARAM', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_RC_PARAM'
  ENDIF ELSE IF strmatch(xuvalue, 'QRCC*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_RC_CF', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_RC_CF'
  ENDIF ELSE IF strmatch(xuvalue, 'QDFE*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_DF_EQ', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_DF_EQ'
  ENDIF ELSE IF strmatch(xuvalue, 'QRPD*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_RP_DATA', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_RP_DATA'
  ENDIF ELSE IF strmatch(xuvalue, 'QRPP*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_RP_PARAM', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_RP_PARAM'
  ENDIF ELSE IF strmatch(xuvalue, 'QRPT*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_RP_TABLE', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_RP_TABLE'
  ENDIF ELSE IF strmatch(xuvalue, 'QFFP*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_FF_PARAM', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_FF_PARAM'
  ENDIF ELSE IF strmatch(xuvalue, 'QFFC*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_FF_CF', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_FF_CF'
  ENDIF ELSE IF strmatch(xuvalue, 'QGPC*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_GPGL_CORR', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_GPGL_CORR'
  ENDIF ELSE IF strmatch(xuvalue, 'QMTC*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_MTGL_CORR', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_MTGL_CORR'
  ENDIF ELSE IF strmatch(xuvalue, 'QTRH*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_TR_HIST', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_TR_HIST'
  ENDIF ELSE IF strmatch(xuvalue, 'QTRP*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_TR_PARAM', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_TR_PARAM'
  ENDIF ELSE IF strmatch(xuvalue, 'QDKD*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_DK_DATA', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_DK_DATA'
  ENDIF ELSE IF strmatch(xuvalue, 'QDKP*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_DK_PARAM', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_DK_PARAM'
  ENDIF ELSE IF strmatch(xuvalue, 'QDKT*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_DK_TABLE', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_DK_TABLE'
  ENDIF ELSE IF strmatch(xuvalue, 'QFXC*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_FX_CORR', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_FX_CORR'
  ENDIF ELSE IF strmatch(xuvalue, 'QFXP*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_FX_PARAM', PIXNO=ch-1)
    x = transpose(x)
    xtitle = 'QUAL_FX_PARAM'

  ; (7) Counter
  ENDIF ELSE IF strmatch(xuvalue, 'CSAA*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Value_TSD('FIS_OBS', 'CNT_SAA')
    x = transpose( x[ch-1, *] )
    xtitle = 'CNT_SAA'
  ENDIF ELSE IF strmatch(xuvalue, 'CGGP*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Value_TSD('FIS_OBS', 'CNT_GLITCH_GP')
    x = transpose( x[ch-1, *] )
    xtitle = 'CNT_GLITCH_GP'
  ENDIF ELSE IF strmatch(xuvalue, 'CGMT*') EQ 1 THEN BEGIN
    ch = uint(strmid(xuvalue, 4,3))
    x = tsd->Get_Value_TSD('FIS_OBS', 'CNT_GLITCH_MT')
    x = transpose( x[ch-1, *] )
    xtitle = 'CNT_GLITCH_MT'


  ; ## FIS_HK
  ; (1) Time
  ENDIF ELSE IF strmatch(xuvalue, 'FIS_HK_AFTIME') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('FIS_HK', 'AFTIME')
    xtitle = 'AF TIME'
  ENDIF ELSE IF strmatch(xuvalue, 'FIS_HK_PIM_TI_ORG') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('FIS_HK', 'PIMTIORG')
    xtitle = 'PIM TI original'
  ; (2) Status
  ENDIF ELSE IF strmatch(xuvalue, 'FIS_HK_BLANK') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('FIS_HK', 'BLANK')
    xtitle = 'FIS_HK_Blank'
  ENDIF ELSE IF strmatch(xuvalue, 'FIS_HK_BLANK_SUBCOM_DATA') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('FIS_HK', 'BLANK_SUBCOM_DATA')
    xtitle = 'FIS_HK_BLANK_Subcom_Data'
  ; (3) Analog Data
  ENDIF ELSE IF strmatch(xuvalue, 'FIS_HK_FIS_FW_F_PUL') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('FIS_HK', 'FIS_FW_F_PUL')
    xtitle = 'FIS_FW_F_PUL'
  ENDIF ELSE IF strmatch(xuvalue, 'FIS_HK_FIS_FW_R_PUL') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('FIS_HK', 'FIS_FW_R_PUL')
    xtitle = 'FIS_FW_R_PUL'
  ENDIF ELSE IF strmatch(xuvalue, 'FIS_HK_FIS_LW_WIRE_LIGHT') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('FIS_HK', 'FIS_LW_WIRE_LIGHT')
    xtitle = 'FIS_LW_WIRE_LIGHT'
  ENDIF ELSE IF strmatch(xuvalue, 'FIS_HK_FIS_RUN_MODE') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('FIS_HK', 'FIS_RUN_MODE')
    xtitle = 'FIS_RUN_MODE'
  ENDIF ELSE IF strmatch(xuvalue, 'FIS_HK_FIS_OBS_MODE') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('FIS_HK', 'FIS_OBS_MODE')
    xtitle = 'FIS_OBS_MODE'
  ENDIF ELSE IF strmatch(xuvalue, 'FIS_HK_FIS_ASQ_PATTERN') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('FIS_HK', 'FIS_ASQ_PATTERN')
    xtitle = 'FIS_ASQ_PATTERN'
  ENDIF ELSE IF strmatch(xuvalue, 'FIS_HK_FIS_ASQ_STEP') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('FIS_HK', 'FIS_ASQ_STEP')
    xtitle = 'FIS_ASQ_STEP'
  ENDIF ELSE IF strmatch(xuvalue, 'FIS_HK_SW_HEATER_TMP') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('FIS_HK', 'SW_HEATER_TMP')
    xtitle = 'SW_HEATER_TMP'

  ; ## IRC_HK
  ; (1) Time
  ENDIF ELSE IF strmatch(xuvalue, 'IRC_HK_AFTIME') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('IRC_HK', 'AFTIME')
    xtitle = 'AF TIME'
  ENDIF ELSE IF strmatch(xuvalue, 'IRC_HK_PIM_TI_ORG') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('IRC_HK', 'PIMTIORG')
    xtitle = 'PIM TI original'
  ; (2) Status
  ENDIF ELSE IF strmatch(xuvalue, 'IRC_HK_BLANK') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('IRC_HK', 'BLANK')
    xtitle = 'IRC_HK_Blank'
  ; (3) Analog Data
  ENDIF ELSE IF strmatch(xuvalue, 'IRC_HK_IRC_MAINREF_TMP1') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('IRC_HK', 'IRC_MAINREF_TMP1')
    xtitle = 'IRC_MAINREF_TMP1'
  ENDIF ELSE IF strmatch(xuvalue, 'IRC_HK_IRC_SUBREF_TMP') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('IRC_HK', 'IRC_SUBREF_TMP')
    xtitle = 'IRC_SUBREF_TMP'
  ENDIF ELSE IF strmatch(xuvalue, 'IRC_HK_IRC_FPIP_TMP1') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('IRC_HK', 'IRC_FPIP_TMP1')

  ; ## HK_2
  ; (1) Time
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_AFTIME') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('HK_2', 'AFTIME')
    xtitle = 'AF TIME'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_PIM_TI_ORG') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('HK_2', 'PIMTIORG')
    xtitle = 'PIM TI original'
  ; (2) Status
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_BLANK') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('HK_2', 'BLANK')
    xtitle = 'HK_2_Blank'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_BLANK_CRYO_TEMP_DATA') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('HK_2', 'BLANK_CRYO_TEMP_DATA')
    xtitle = 'HK_2_Balnk_Cryo_Temp_Data'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_CRYO_TEMP_DATA_EN_DS') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('HK_2', 'CRYO_TEMP_DATA_EN_DS')
    xtitle = 'CRYO_Temp_Data_EN_DS'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_FIS_CPU_RUN_RST') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('HK_2', 'FIS_CPU_RUN_RST')
    xtitle = 'FIS_CPU_RUN_RST'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_FIS_FIS_ON_OFF') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('HK_2', 'FIS_FIS_ON_OFF')
    xtitle = 'FIS_FIS_ON_OFF'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_FIS_TMP_POL_POS_NEG') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('HK_2', 'FIS_TMP_POL_POS_NEG')
    xtitle = 'FIS_Tmp_Pol_POS_NEG'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_FIS_OBS_SEQ') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('HK_2', 'FIS_OBS_SEQ')
    xtitle = 'FIS_OBS_SEQ'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_FIS_RSW_AUTO_CMND') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('HK_2', 'FIS_RSW_AUTO_CMND')
    xtitle = 'FIS_RSW_Auto_CMND'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_FIS_FCAL_FRQ_B1') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('HK_2', 'FIS_FCAL_FRQ_B1')
    xtitle = 'FIS_FCal_FRQ_B1'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_FIS_FCAL_FRQ_B0') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('HK_2', 'FIS_FCAL_FRQ_B0')
    xtitle = 'FIS_FCal_FRQ_B0'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_IRC_CPU_RU_RS') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('HK_2', 'IRC_CPU_RU_RS')
    xtitle = 'IRC_CPU_RU_RS'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_IRC_IRC_ON_OF') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('HK_2', 'IRC_IRC_ON_OF')
    xtitle = 'IRC_IRC_ON_OF'
  ; (3) Cryostat temperature
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_CRYO_HE_TANK_1') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('HK_2', 'CRYO_HE_TANK_1')
    xtitle = 'CRYO_HE_TANK_1'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_CRYO_BAFFLE_1') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('HK_2', 'CRYO_BAFFLE_1')
    xtitle = 'CRYO_BAFFLE_1'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_CRYO_BAFFLE_2') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('HK_2', 'CRYO_BAFFLE_2')
    xtitle = 'CRYO_BAFFLE_2'
  ; (4) Cryostat current
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_CRYO_COLD_HD_A_DR_I') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('HK_2', 'CRYO_COLD_HD_A_DR_I')
    xtitle = 'CRYO_COLD_HD_A_DR_I'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_CRYO_COLD_HD_B_DR_I') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('HK_2', 'CRYO_COLD_HD_B_DR_I')
    xtitle = 'CRYO_COLD_HD_B_DR_I'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_CRYO_COMP_A_DR_I') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('HK_2', 'CRYO_COMP_A_DR_I')
    xtitle = 'CRYO_COMP_A_DR_I'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_CRYO_COMP_B_DR_I') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('HK_2', 'CRYO_COMP_B_DR_I')
    xtitle = 'CRYO_COMP_B_DR_I'
  ; (5) IRC Analog data
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_IRC_MAINREF_TMP1') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('HK_2', 'IRC_MAINREF_TMP1')
    xtitle = 'IRC_MAINREF_TMP1'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_IRC_SUBREF_TMP') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('HK_2', 'IRC_SUBREF_TMP')
    xtitle = 'IRC_SUBREF_TMP'
  ENDIF ELSE IF strmatch(xuvalue, 'HK_2_IRC_FPIP_TMP1') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('HK_2', 'IRC_FPIP_TMP1')
    xtitle = 'IRC_FPIP_TMP1'

  ; ## AOCU
  ; (1) Time
  ENDIF ELSE IF strmatch(xuvalue, 'AOCU_AFTIME') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('AOCU', 'AFTIME')
    xtitle = 'AF TIME'
  ENDIF ELSE IF strmatch(xuvalue, 'AOCU_PIM_TI_ORG') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('AOCU', 'PIMTIORG')
    xtitle = 'PIM TI original'
  ; (2) Status
  ENDIF ELSE IF strmatch(xuvalue, 'AOCU_BLANK') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('AOCU', 'BLANK')
    xtitle = 'AOCU_Blank'
  ENDIF ELSE IF strmatch(xuvalue, 'AOCU_AO_ROM_RAM') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('AOCU', 'AO_ROM_RAM')
    xtitle = 'AO_ROM_RAM'
  ENDIF ELSE IF strmatch(xuvalue, 'AOCU_ADS_MODE_B1') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('AOCU', 'ADS_MODE_B1')
    xtitle = 'ADS_MODE_B1'
  ENDIF ELSE IF strmatch(xuvalue, 'AOCU_ADS_MODE_B0') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('AOCU', 'ADS_MODE_B0')
    xtitle = 'ADS_MODE_B0'

  ; (3) Analog Data
  ENDIF ELSE IF strmatch(xuvalue, 'ADS_Q*') EQ 1 THEN BEGIN
    num=strmid(xuvalue, 5,1)
    x = tsd->get_value_tsd('AOCU', 'AOCU_ADS_Q')
    x = reform(x[fix(num-1), *])
    xtitle = 'Quaternion'+strcompress(string(fix(num)))
  ENDIF ELSE IF strmatch(xuvalue, 'AOCU_BR*') EQ 1 THEN BEGIN
    num=strmid(xuvalue, 7,1)
    x = tsd->get_value_tsd('AOCU', 'AOCU_BODY_RATE')
    x = reform(x[fix(num-1), *])
    xtitle = 'BODY_RATE'+strcompress(string(fix(num)))

  ENDIF ELSE IF strmatch(xuvalue, 'AOCU_RA') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('AOCU', 'RA')
    xtitle = 'R.A. (deg) at boresight'
  ENDIF ELSE IF strmatch(xuvalue, 'AOCU_DEC') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('AOCU', 'DEC')
    xtitle = 'Dec. (deg) at boresight'
  ENDIF ELSE IF strmatch(xuvalue, 'AOCU_RANG') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('AOCU', 'RANG')
    xtitle = 'Roll Angle'
  ENDIF ELSE IF strmatch(xuvalue, 'AOCU_DRA') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('AOCU', 'DRA')
    xtitle = 'Scan rate in R.A. (deg)'
  ENDIF ELSE IF strmatch(xuvalue, 'AOCU_DDEC') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('AOCU', 'DDEC')
    xtitle = 'Scan rate in Dec. (deg)'
  ENDIF ELSE IF strmatch(xuvalue, 'AOCU_DRANG') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('AOCU', 'DRANG')
    xtitle = 'Scan rate of roll angle'
  ENDIF ELSE IF strmatch(xuvalue, 'AOCU_CRS_OFF') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('AOCU', 'CRS_OFF')
    xtitle = 'Offset of cross-scan direction'

  ;(4) Quality
  ENDIF ELSE IF strmatch(xuvalue, 'AOCU_QUAL_INTP') EQ 1 THEN BEGIN
    x = tsd->Get_Quality_TSD('AOCU', 'Interpolated')
    x = reform(x)
    xtitle = 'Interpolated flag'

  ; ## GADS
  ; (1) Time
  ENDIF ELSE IF strmatch(xuvalue, 'GADS_AFTIME') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('GADS', 'AFTIME')
    xtitle = 'AF TIME'
  ENDIF ELSE IF strmatch(xuvalue, 'GADS_PIM_TI_ORG') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('GADS', 'PIMTIORG')
    xtitle = 'PIM TI original'
  ; (2) Status
  ENDIF ELSE IF strmatch(xuvalue, 'GADS_BLANK') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('GADS', 'BLANK')
    xtitle = 'GADS_Blank'

  ; (3) Analog Data
  ENDIF ELSE IF strmatch(xuvalue, 'GADS_QUAT*') EQ 1 THEN BEGIN
    num=strmid(xuvalue, 9,1)
    x = tsd->get_value_tsd('GADS', 'ATTITUDE')
    x = reform(x[fix(num-1), *])
    xtitle = 'Attitude'+strcompress(string(fix(num)))
  ENDIF ELSE IF strmatch(xuvalue, 'GADS_ERR*') EQ 1 THEN BEGIN
    num=strmid(xuvalue, 8,1)
    x = tsd->get_value_tsd('GADS', 'ATTITUDE_ER')
    x = reform(x[fix(num-1), *])
    xtitle = 'Attitude_Er'+strcompress(string(fix(num)))
  ENDIF ELSE IF strmatch(xuvalue, 'GADS_BR*') EQ 1 THEN BEGIN
    num=strmid(xuvalue, 7,1)
    x = tsd->get_value_tsd('GADS', 'ANGL_VEL')
    x = reform(x[fix(num-1), *])
    xtitle = 'ANGL_VEL'+strcompress(string(fix(num)))

  ENDIF ELSE IF strmatch(xuvalue, 'GADS_RA') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('GADS', 'RA')
    xtitle = 'R.A. (deg) at boresight'
  ENDIF ELSE IF strmatch(xuvalue, 'GADS_DEC') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('GADS', 'DEC')
    xtitle = 'Dec. (deg) at boresight'
  ENDIF ELSE IF strmatch(xuvalue, 'GADS_RANG') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('GADS', 'RANG')
    xtitle = 'Roll Angle'

  ENDIF ELSE IF strmatch(xuvalue, 'GADS_DRA') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('GADS', 'DRA')
    xtitle = 'Scan rate in R.A. (deg)'
  ENDIF ELSE IF strmatch(xuvalue, 'GADS_DDEC') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('GADS', 'DDEC')
    xtitle = 'Scan rate in Dec. (deg)'
  ENDIF ELSE IF strmatch(xuvalue, 'GADS_DRANG') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('GADS', 'DRANG')
    xtitle = 'Scan rate of roll angle'

  ENDIF ELSE IF strmatch(xuvalue, 'GADS_EL_SOL') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('GADS', 'EL_SOL')
    xtitle = 'Solar elongation'
  ENDIF ELSE IF strmatch(xuvalue, 'GADS_AA_SOL') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('GADS', 'AA_SOL')
    xtitle = 'Solar avoidance angle'
  ENDIF ELSE IF strmatch(xuvalue, 'GADS_AA_EAR') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('GADS', 'AA_EAR')
    xtitle = 'Earth avoidance angle'
  ENDIF ELSE IF strmatch(xuvalue, 'GADS_AA_LUN') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('GADS', 'AA_LUN')
    xtitle = 'Lunar avoidance angle'
  ENDIF ELSE IF strmatch(xuvalue, 'GADS_CRS_OFF') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('GADS', 'CRS_OFF')
    xtitle = 'Offset of cross-scan direction'

  ;(4) Quality
  ENDIF ELSE IF strmatch(xuvalue, 'GADS_QUAL_INTP') EQ 1 THEN BEGIN
    x = tsd->Get_Quality_TSD('GADS', 'Interpolated')
    x = reform(x)
    xtitle = 'Interpolated flag'

  ; ## PR
  ; (1) Time
  ENDIF ELSE IF strmatch(xuvalue, 'PR_AFTIME') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('PR', 'AFTIME')
    xtitle = 'AF TIME'
  ENDIF ELSE IF strmatch(xuvalue, 'PR_PIM_TI_ORG') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('PR', 'PIMTIORG')
    xtitle = 'PIM TI original'
  ; (2) Status
  ENDIF ELSE IF strmatch(xuvalue, 'PR_BLANK') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('PR', 'BLANK')
    xtitle = 'PR_Blank'

  ; (3) Analog Data
  ENDIF ELSE IF strmatch(xuvalue, 'PR_QUAT*') EQ 1 THEN BEGIN
    num=strmid(xuvalue, 7,1)
    x = tsd->get_value_tsd('PR', 'QUATERNION')
    x = reform(x[fix(num-1), *])
    xtitle = 'Quaternion'+strcompress(string(fix(num)))
  ENDIF ELSE IF strmatch(xuvalue, 'PR_ERR*') EQ 1 THEN BEGIN
    num=strmid(xuvalue, 6,1)
    x = tsd->get_value_tsd('PR', 'POS_ERR')
    x = reform(x[fix(num-1), *])
    xtitle = 'Position Error'+strcompress(string(fix(num)))
  ENDIF ELSE IF strmatch(xuvalue, 'PR_BR*') EQ 1 THEN BEGIN
    num=strmid(xuvalue, 5,1)
    x = tsd->get_value_tsd('PR', 'BODY_RATE')
    x = reform(x[fix(num-1), *])
    xtitle = 'BODY_RATE'+strcompress(string(fix(num)))

  ENDIF ELSE IF strmatch(xuvalue, 'PR_RA') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('PR', 'RA')
    xtitle = 'R.A. (deg) at boresight'
  ENDIF ELSE IF strmatch(xuvalue, 'PR_DEC') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('PR', 'DEC')
    xtitle = 'Dec. (deg) at boresight'
  ENDIF ELSE IF strmatch(xuvalue, 'PR_RANG') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('PR', 'RANG')
    xtitle = 'Roll Angle'

  ENDIF ELSE IF strmatch(xuvalue, 'PR_DRA') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('PR', 'DRA')
    xtitle = 'Scan rate in R.A. (deg)'
  ENDIF ELSE IF strmatch(xuvalue, 'PR_DDEC') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('PR', 'DDEC')
    xtitle = 'Scan rate in Dec. (deg)'
  ENDIF ELSE IF strmatch(xuvalue, 'PR_DRANG') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('PR', 'DRANG')
    xtitle = 'Scan rate of roll angle'

  ENDIF ELSE IF strmatch(xuvalue, 'PR_EL_SOL') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('PR', 'EL_SOL')
    xtitle = 'Solar elongation'
  ENDIF ELSE IF strmatch(xuvalue, 'PR_AA_SOL') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('PR', 'AA_SOL')
    xtitle = 'Solar avoidance angle'
  ENDIF ELSE IF strmatch(xuvalue, 'PR_AA_EAR') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('PR', 'AA_EAR')
    xtitle = 'Earth avoidance angle'
  ENDIF ELSE IF strmatch(xuvalue, 'PR_AA_LUN') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('PR', 'AA_LUN')
    xtitle = 'Lunar avoidance angle'
  ENDIF ELSE IF strmatch(xuvalue, 'PR_CRS_OFF') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('PR', 'CRS_OFF')
    xtitle = 'Offset of cross-scan direction'

  ;(4) Quality
  ENDIF ELSE IF strmatch(xuvalue, 'PR_QUAL_INTP') EQ 1 THEN BEGIN
    x = tsd->Get_Quality_TSD('PR', 'Interpolated')
    x = reform(x)
    xtitle = 'Interpolated flag'

  ; ## SE
  ; (1) Time
  ENDIF ELSE IF strmatch(xuvalue, 'SE_AFTIME') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('SE', 'AFTIME')
    xtitle = 'AF TIME'
  ENDIF ELSE IF strmatch(xuvalue, 'SE_PIM_TI_ORG') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('SE', 'PIMTIORG')
    xtitle = 'PIM TI original'
  ; (2) Status
  ENDIF ELSE IF strmatch(xuvalue, 'SE_BLANK') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('SE', 'BLANK')
    xtitle = 'SE_Blank'
  ENDIF ELSE IF strmatch(xuvalue, 'SE_TYPE') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('SE', 'TYPE')
    xtitle = 'SE_TYPE'
  ENDIF ELSE IF strmatch(xuvalue, 'SE_DAYNIGHT') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('SE', 'DAYNIGHT')
    xtitle = 'SE_DayNight'
  ENDIF ELSE IF strmatch(xuvalue, 'SE_IN_SAA') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('SE', 'IN_SAA')
    xtitle = 'SE_In_SAA'
  ENDIF ELSE IF strmatch(xuvalue, 'SE_IN_POLAR') EQ 1 THEN BEGIN
    x = tsd->get_status_tsd('SE', 'IN_POLAR')
    xtitle = 'SE_In_Polar'
  ; (3) Analog Data
  ENDIF ELSE IF strmatch(xuvalue, 'SE_TM_SAA') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('SE', 'TM_SAA')
    xtitle = 'Sec. since last SAA'
  ENDIF ELSE IF strmatch(xuvalue, 'SE_SAT_X') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('SE', 'SAT_X')
    xtitle = 'Satellite position X'
  ENDIF ELSE IF strmatch(xuvalue, 'SE_SAT_Y') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('SE', 'SAT_Y')
    xtitle = 'Satellite position Y'
  ENDIF ELSE IF strmatch(xuvalue, 'SE_SAT_Z') EQ 1 THEN BEGIN
    x = tsd->get_value_tsd('SE', 'SAT_Z')
    xtitle = 'Satellite position Z'

  ENDIF


  ; Y values
  ; (4) Detector Data
  IF strmatch(yuvalue, 'VDET*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    vdet = tsd->get_value_tsd('FIS_OBS', 'DET')
    y = transpose( vdet[ch-1, *] )
    ytitle = 'Signal (ADU)'

    ; Find number of pixels and set plot title
    vdet_ch_num = n_elements(vdet[*,0])
    IF (vdet_ch_num EQ 100) THEN $
    title = 'SW Detector ch'+string(ch, format='(i3)') ;pixel to plot
    IF (vdet_ch_num EQ 75) THEN $
    title = 'LW Detector ch'+string(ch, format='(i3)') ;pixel to plot

  ENDIF ELSE IF strmatch(yuvalue, 'FLUX*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    flux = tsd->get_value_tsd('FIS_OBS', 'FLUX')
    y = transpose( flux[ch-1, *] )
    ytitle = 'Signal'

    ; Find number of pixels and set plot title
    flux_ch_num = n_elements(flux[*,0])
    IF (flux_ch_num EQ 100) THEN $
    title = 'SW Detector ch'+string(ch, format='(i3)') ;pixel to plot
    IF (flux_ch_num EQ 75) THEN $
    title = 'LW Detector ch'+string(ch, format='(i3)') ;pixel to plot

  ENDIF ELSE IF strmatch(yuvalue, 'FERR*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    ferr = tsd->get_value_tsd('FIS_OBS', 'FERR')
    y = transpose( ferr[ch-1, *] )
    ytitle = 'Flux Error'

    ; Find number of pixels and set plot title
    ferr_ch_num = n_elements(ferr[*,0])
    IF (ferr_ch_num EQ 100) THEN $
    title = 'SW Detector ch'+string(ch, format='(i3)') ;pixel to plot
    IF (ferr_ch_num EQ 75) THEN $
    title = 'LW Detector ch'+string(ch, format='(i3)') ;pixel to plot

  ; (1) Time
  ENDIF ELSE IF strmatch(yuvalue, 'AFTIME') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'AFTIME')
    ytitle = 'AF TIME'
    title = 'Astro-F TIME (from 2000/01/01T00:00:00UTC)'
  ENDIF ELSE IF strmatch(yuvalue, 'PIM_TI_ORG') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'PIMTIORG')
    ytitle = 'PIM TI original'
    title = 'PIM TI original'
  ENDIF ELSE IF strmatch(yuvalue, 'FIS_TI_ORG') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'FISTIORG')
    ytitle = 'FIS TI original'
    title = 'FIS TI original'
  ENDIF ELSE IF strmatch(yuvalue, 'PIM_TI_ITP') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'PIMTI')
    ytitle = 'PIM TI interpolated'
    title = 'PIM TI interpolated'
  ENDIF ELSE IF strmatch(yuvalue, 'FIS_TI_ITP') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'FISTI')
    ytitle = 'FIS TI interpolated'
    title = 'FIS TI interpolated'

  ; (2) Status
  ENDIF ELSE IF strmatch(yuvalue, 'CREON') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'creon')
    ytitle = 'CRE ON'
    title = 'Status - CRE ON'
  ENDIF ELSE IF strmatch(yuvalue, 'ShtOp') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'shtop')
    ytitle = 'ShtOp'
    title = 'Status - Shutter Open'
  ENDIF ELSE IF strmatch(yuvalue, 'FWposOn') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'fwposon')
    ytitle = 'FWposOn'
    title = 'Status - Filter Wheel Position On'
  ENDIF ELSE IF strmatch(yuvalue, 'FWpos_B1') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'fwpos_b1')
    ytitle = 'FWpos_B1'
    title = 'Status - Filter Wheel Position Bit1'
  ENDIF ELSE IF strmatch(yuvalue, 'FWpos_B0') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'fwpos_b0')
    ytitle = 'FWpos_B0'
    title = 'Status - Filter Wheel Position Bit0'
  ENDIF ELSE IF strmatch(yuvalue, 'MposOn') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'mposon')
    ytitle = 'MposOn'
    title = 'Status - Mirror Position On'
  ENDIF ELSE IF strmatch(yuvalue, 'Mpos_B1') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'mpos_b1')
    ytitle = 'Mpos_B1'
    title = 'Status - Mirror Position Bit1'
  ENDIF ELSE IF strmatch(yuvalue, 'Mpos_B0') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'mpos_b0')
    ytitle = 'Mpos_B0'
    title = 'Status - Mirror Position Bit0'
  ENDIF ELSE IF strmatch(yuvalue, 'RstWideLOn') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'rstwidelon')
    ytitle = 'RstWideLOn'
    title = 'Status - Reset WideL On'
  ENDIF ELSE IF strmatch(yuvalue, 'RstWideSOn') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'rstwideson')
    ytitle = 'RstWideSOn'
    title = 'Status - Reset WideS On'
  ENDIF ELSE IF strmatch(yuvalue, 'RstN170On') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'rstn170on')
    ytitle = 'RstN170On'
    title = 'Status - Reset N170 (N160) On'
  ENDIF ELSE IF strmatch(yuvalue, 'RstN60On') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'rstn60on')
    ytitle = 'RstN60On'
    title = 'Status - Reset N60 On'
  ENDIF ELSE IF strmatch(yuvalue, 'LWboostOn') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'lwbooston')
    ytitle = 'LWboostOn'
    title = 'Status - LW Bias Boost On'
  ENDIF ELSE IF strmatch(yuvalue, 'SWboostOn') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'swbooston')
    ytitle = 'SWboostOn'
    title = 'Status - SW Bias Boost On'
  ENDIF ELSE IF strmatch(yuvalue, 'LWbiasOn') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'lwbiason')
    ytitle = 'LWbiasOn'
    title = 'Status - LW Bias On'
  ENDIF ELSE IF strmatch(yuvalue, 'SWbiasOn') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'swbiason')
    ytitle = 'SWbiasOn'
    title = 'Status - SW Bias On'
  ENDIF ELSE IF strmatch(yuvalue, 'CalALOn') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'calalon')
    ytitle = 'CalALOn'
    title = 'Status - Cal AL On'
  ENDIF ELSE IF strmatch(yuvalue, 'CalASOn') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'calason')
    ytitle = 'CalASOn'
    title = 'Status - Cal AS On'
  ENDIF ELSE IF strmatch(yuvalue, 'CalBOn') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'calbon')
    ytitle = 'CalBOn'
    title = 'Status - Cal B On'
  ENDIF ELSE IF strmatch(yuvalue, 'SinALOn') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'sinalon')
    ytitle = 'SinALOn'
    title = 'Status - Cal sin-conv. AL On'
  ENDIF ELSE IF strmatch(yuvalue, 'SinASOn') THEN BEGIN
    y = tsd->get_status_tsd('FIS_OBS', 'sinason')
    ytitle = 'SinASOn'
    title = 'Status - Cal sin-conv. AS On'

  ; (3) Analog Telemetry
  ENDIF ELSE IF strmatch(yuvalue, 'PacketID') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'packetid')
    ytitle = 'Packet ID'
    title = 'Packet ID'
  ; Counter
  ENDIF ELSE IF strmatch(yuvalue, 'RstCntWideL') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'rstcntwidel')
    ytitle = 'Reset Count WideL'
    title = 'Reset Count WideL'
  ENDIF ELSE IF strmatch(yuvalue, 'RstCntWideS') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'rstcntwides')
    ytitle = 'Reset Count WideS'
    title = 'Reset Count WideS'
  ENDIF ELSE IF strmatch(yuvalue, 'RstCntN170') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'rstcntn170')
    ytitle = 'Reset Count N170'
    title = 'Reset Count N170 (N160)'
  ENDIF ELSE IF strmatch(yuvalue, 'RstCntN60') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'rstcntn60')
    ytitle = 'Reset Count N60'
    title = 'Reset Count N60'
  ENDIF ELSE IF strmatch(yuvalue, 'CalPlsCntAL') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'calplscntal')
    ytitle = 'CalPlsCntAL'
    title = 'CAL pulse counter AL'
  ENDIF ELSE IF strmatch(yuvalue, 'CalPlsCntAS') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'calplscntas')
    ytitle = 'CalPlsCntAS'
    title = 'CAL pulse counter AS'
  ENDIF ELSE IF strmatch(yuvalue, 'CalPlsCntB') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'calplscntb')
    ytitle = 'CalPlsCntB'
    title = 'CAL pulse counter B'
  ENDIF ELSE IF strmatch(yuvalue, 'ADErrCntSW') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'aderrcntsw')
    ytitle = 'ADErrCntSW'
    title = 'SW A/D Error Counter'
  ENDIF ELSE IF strmatch(yuvalue, 'ADErrCntLW') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'aderrcntlw')
    ytitle = 'ADErrCntLW'
    title = 'LW A/D Error Counter'
  ENDIF ELSE IF strmatch(yuvalue, 'MPosCnt') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'mposcnt')
    ytitle = 'MPosCnt'
    title = 'Mirror Position (FTS) / Frame Counter (Survey)'
  ENDIF ELSE IF strmatch(yuvalue, 'MPosCnt*') THEN BEGIN
    num=strmid(yuvalue, 7,2)
    y = tsd->get_value_tsd('FIS_OBS', 'MPOSCNT')
    y = reform(y[fix(num), *])
    ytitle = 'MPosCnt'
    title = 'Mirror Position Counter'
  ; DAC value
  ENDIF ELSE IF strmatch(yuvalue, 'DacBiasWideS') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'dacbiaswides')
    ytitle = 'DacBiasWideS'
    title = 'DAC Bias WideS Level'
  ENDIF ELSE IF strmatch(yuvalue, 'DacBiasN60') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'dacbiasn60')
    ytitle = 'DacBiasN60'
    title = 'DAC Bias N60 Level'
  ENDIF ELSE IF strmatch(yuvalue, 'DacBiasWideL') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'dacbiaswidel')
    ytitle = 'DacBiasWideL'
    title = 'DAC Bias WideL Level'
  ENDIF ELSE IF strmatch(yuvalue, 'DacBiasN170') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'dacbiasn170')
    ytitle = 'DacBiasN170'
    title = 'DAC Bias N170 (N160) Level'
  ENDIF ELSE IF strmatch(yuvalue, 'DacCalAS') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'daccalas')
    ytitle = 'DacCalAS'
    title = 'DAC Cal AS Level'
  ENDIF ELSE IF strmatch(yuvalue, 'DacCalAL') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'daccalal')
    ytitle = 'DacCalAL'
    title = 'DAC Cal AL Level'
  ENDIF ELSE IF strmatch(yuvalue, 'DacCalB') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'daccalb')
    ytitle = 'DacCalB'
    title = 'DAC Cal B Level'
  ENDIF ELSE IF strmatch(yuvalue, 'DacSinAS') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'dacsinas')
    ytitle = 'DacSinAS'
    title = 'DAC Cal sin-conv. AS Level'
  ENDIF ELSE IF strmatch(yuvalue, 'DacSinAL') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'dacsinal')
    ytitle = 'DacSinAL'
    title = 'DAC Cal sin-conv. AL Level'
  ; Temperature
  ENDIF ELSE IF strmatch(yuvalue, 'TpBody') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'tpbody')
    ytitle = 'TpBody'
    title = 'FIS Body Temp.'
  ENDIF ELSE IF strmatch(yuvalue, 'TpSW') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'tpsw')
    ytitle = 'TpSW'
    title = 'SW Det. Temp.'
  ENDIF ELSE IF strmatch(yuvalue, 'TpLW') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'tplw')
    ytitle = 'TpLW'
    title = 'LW Det. Temp.'
  ENDIF ELSE IF strmatch(yuvalue, 'TpCalFT') THEN BEGIN
    y = tsd->get_value_tsd('FIS_OBS', 'tpcalft')
    ytitle = 'TpCalFT'
    title = 'CAL FT Temp.'

  ; (5) Flags
  ENDIF ELSE IF strmatch(yuvalue, 'BAD_FRAME') EQ 1 THEN BEGIN
    y = tsd->Get_Flag_TSD('FIS_OBS', 'BAD_FRAME')
    ytitle = 'Bad_Frame Flag'
    title = 'Bad_Frame Flag 0/1'
  ENDIF ELSE IF strmatch(yuvalue, 'UNDEF_ANOM_FRAME') EQ 1 THEN BEGIN
    y = tsd->Get_Flag_TSD('FIS_OBS', 'UNDEF_ANOM_FRAME')
    ytitle = 'Undef_Anom_Frame Flag'
    title = 'Undef_Anom_Frame Flag 0/1'
  ENDIF ELSE IF strmatch(yuvalue, 'BLANK') EQ 1 THEN BEGIN
    y = tsd->Get_Flag_TSD('FIS_OBS', 'BLANK')
    ytitle = 'Blank Flag'
    title = 'Blank flag 0/1'
  ENDIF ELSE IF strmatch(yuvalue, 'IN_SAA') EQ 1 THEN BEGIN
    y = tsd->Get_Flag_TSD('FIS_OBS', 'IN_SAA')
    ytitle = 'IN_SAA Flag'
    title = 'In_SAA flag 0/1'
  ENDIF ELSE IF strmatch(yuvalue, 'NEAR_MOON') EQ 1 THEN BEGIN
    y = tsd->Get_Flag_TSD('FIS_OBS', 'NEAR_MOON')
    ytitle = 'Near_MOON Flag'
    title = 'Near_MOON flag 0/1'
  ENDIF ELSE IF strmatch(yuvalue, 'UNTRUSTED_FRAME') EQ 1 THEN BEGIN
    y = tsd->Get_Flag_TSD('FIS_OBS', 'UNTRUSTED_FRAME')
    ytitle = 'Untrusted_frame Flag'
    title = 'Untrusted frame flag 0/1'

  ; Pix_Flag
  ENDIF ELSE IF strmatch(yuvalue, 'BAD_*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'BAD', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'BAD Flag'
    title = 'Bad flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'UANM*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'UNDEF_ANOM', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'Undef_Anom Flag'
    title = 'Undef Anomaly Flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'AERR*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'ARITH_ERR', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'Arith_Err Flag'
    title = 'Arithmetic Error Flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'DEAD*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'DEAD', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'DEAD Flag'
    title = 'Dead Flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'SATU*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'SATURATE', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'SATURATE Flag'
    title = 'Saturation Flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'REST*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'RESET', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'RESET Flag'
    title = 'Reset Flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'RANM*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'RSTANOM', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'RSTANOM Flag'
    title = 'Reset Anomaly ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'NDIF*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_DIFF', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'NO_DIFF Flag'
    title = 'No Differentiation Flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'NRPC*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_RP_CORR', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'NO_RP_CORR Flag'
    title = 'No Ramp Curve Correction Flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'NDKC*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_DK_CORR', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'NO_DK_CORR Flag'
    title = 'No Dark Correction Flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'NDCC*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_DCCAL_CORR', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'NO_DCCAL_CORR Flag'
    title = 'No DC Cal Correction Flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'NTRC*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_TR_CORR', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'NO_TR_CORR Flag'
    title = 'No Transient Correction Flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'NFLF*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_FLAT_FIELD', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'NO_FLAT_FIELD Flag'
    title = 'No Flat Field Flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'NGPG*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_GPGL', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'NO_GPGL Flag'
    title = 'No GPGL ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'NMTG*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_MTGL', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'NO_MTGL Flag'
    title = 'No MTGL ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'NABC*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_ABSCAL', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'NO_ABSCAL Flag'
    title = 'No Abs-Cal Flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'GPG1*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'GPGL_TYPE1', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'GPGL_TYPE1 Flag'
    title = 'GP glitch Type 1, ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'GPG2*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'GPGL_TYPE2', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'GPGL_TYPE2 Flag'
    title = 'GP glitch Type 2, ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'GPG3*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'GPGL_TYPE3', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'GPGL_TYPE3 Flag'
    title = 'GP glitch Type 3, ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'GPG4*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'GPGL_TYPE4', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'GPGL_TYPE4 Flag'
    title = 'GP glitch Type 4, ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'GPGT*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'GPGL_TAIL', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'GPGL_TAIL Flag'
    title = 'GP glitch tail, ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'MTG1*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'MTGL_TYPE1', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'MTGL_TYPE1 Flag'
    title = 'MT glitch Type 1, ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'MTG2*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'MTGL_TYPE2', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'MTGL_TYPE2 Flag'
    title = 'MT glitch Type 2, ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'MTG3*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'MTGL_TYPE3', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'MTGL_TYPE3 Flag'
    title = 'MT glitch Type 3, ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'MTG4*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'MTGL_TYPE4', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'MTGL_TYPE4 Flag'
    title = 'MT glitch Type 4, ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'MTGT*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'MTGL_TAIL', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'MTGL_TAIL Flag'
    title = 'MT glitch tail, ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'NPER*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'NO_PERI_CORR', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'NO_PERI_CORR Flag'
    title = 'No Periodic Noise Correction Flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'SPAK*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'SX_PEAK', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'SX_PEAK Flag'
    title = 'SX_Peak flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'SRCE*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'SX_SOURCE', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'SX_SOURCE Flag'
    title = 'SX_Source flag ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'SOBJ*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Pix_Flag_TSD('FIS_OBS', 'SX_OBJ', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'SX_OBJ Flag'
    title = 'SX_Object flag ch'+string(ch, format='(i3)') ;

  ; (6) Quality
  ENDIF ELSE IF strmatch(yuvalue, 'QCVP*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_CV_PARAM', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_CV_PARAM'
    title = 'Quality of CV_PARAM ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QRCP*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_RC_PARAM', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_RC_PARAM'
    title = 'Quality of RC_PARAM ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QRCC*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_RC_CF', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_RC_CF'
    title = 'Quality of RC_CF ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QDFE*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_DF_EQ', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_DF_EQ'
    title = 'Quality of DF_EQ ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QRPD*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_RP_DATA', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_RP_DATA'
    title = 'Quality of RP_DATA ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QRPP*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_RP_PARAM', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_RP_PARAM'
    title = 'Quality of RP_PARAM ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QRPT*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_RP_TABLE', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_RP_TABLE'
    title = 'Quality of RP_TABLE ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QFFP*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_FF_PARAM', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_FF_PARAM'
    title = 'Quality of FF_PARAM ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QFFC*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_FF_CF', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_FF_CF'
    title = 'Quality of FF_CF ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QGPC*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_GPGL_CORR', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_GPGL_CORR'
    title = 'Quality of GPGL_CORR ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QMTC*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_MTGL_CORR', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_MTGL_CORR'
    title = 'Quality of MTGL_CORR ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QTRH*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_TR_HIST', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_TR_HIST'
    title = 'Quality of TR_HIST ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QTRP*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_TR_PARAM', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_TR_PARAM'
    title = 'Quality of TR_PARAM ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QDKD*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_DK_DATA', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_DK_DATA'
    title = 'Quality of DK_DATA ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QDKP*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_DK_PARAM', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_DK_PARAM'
    title = 'Quality of DK_PARAM ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QDKT*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_DK_TABLE', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_DK_TABLE'
    title = 'Quality of DK_TABLE ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QFXC*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_FX_CORR', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_FX_CORR'
    title = 'Quality of FX_CORR ch'+string(ch, format='(i3)') ;
  ENDIF ELSE IF strmatch(yuvalue, 'QFXP*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Quality_TSD('FIS_OBS', 'QUAL_FX_PARAM', PIXNO=ch-1)
    y = transpose(y)
    ytitle = 'QUAL_FX_PARAM'
    title = 'Quality of FX_PARAM ch'+string(ch, format='(i3)') ;

  ; (7) Counter
  ENDIF ELSE IF strmatch(yuvalue, 'CSAA*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Value_TSD('FIS_OBS', 'CNT_SAA')
    y = transpose( y[ch-1, *] )
    ytitle = 'CNT_SAA'
    title = 'Counter after SAA ch'+string(ch, format='(i3)')
  ENDIF ELSE IF strmatch(yuvalue, 'CGGP*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Value_TSD('FIS_OBS', 'CNT_GLITCH_GP')
    y = transpose( y[ch-1, *] )
    ytitle = 'CNT_GLITCH_GP'
    title = 'Counter after GLITCH_GP ch'+string(ch, format='(i3)')
  ENDIF ELSE IF strmatch(yuvalue, 'CGMT*') EQ 1 THEN BEGIN
    ch = uint(strmid(yuvalue, 4,3))
    y = tsd->Get_Value_TSD('FIS_OBS', 'CNT_GLITCH_MT')
    y = transpose( y[ch-1, *] )
    ytitle = 'CNT_GLITCH_MT'
    title = 'Counter after GLITCH_MT ch'+string(ch, format='(i3)')


  ; ## FIS_HK
  ; (1) Time
  ENDIF ELSE IF strmatch(yuvalue, 'FIS_HK_AFTIME') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('FIS_HK', 'AFTIME')
    ytitle = 'AF TIME'
    title  = 'AF TIME in FIS_HK'
  ENDIF ELSE IF strmatch(yuvalue, 'FIS_HK_PIM_TI_ORG') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('FIS_HK', 'PIMTIORG')
    ytitle = 'PIM TI original'
    title  = 'PIM TI original in FIS_HK'
  ; (2) Status
  ENDIF ELSE IF strmatch(yuvalue, 'FIS_HK_BLANK') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('FIS_HK', 'BLANK')
    ytitle = 'FIS_HK_Blank'
    title  = 'FIS_HK Status - Blank'
  ENDIF ELSE IF strmatch(yuvalue, 'FIS_HK_BLANK_SUBCOM_DATA') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('FIS_HK', 'BLANK_SUBCOM_DATA')
    ytitle = 'FIS_HK_BLANK_Subcom_Data'
    title  = 'FIS_HK Status - Blank Subcom data'
  ; (3) Analog Data
  ENDIF ELSE IF strmatch(yuvalue, 'FIS_HK_FIS_FW_F_PUL') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('FIS_HK', 'FIS_FW_F_PUL')
    ytitle = 'FIS_FW_F_PUL'
    title  = 'Filter Wheel Pulse Counter (Foward)'
  ENDIF ELSE IF strmatch(yuvalue, 'FIS_HK_FIS_FW_R_PUL') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('FIS_HK', 'FIS_FW_R_PUL')
    ytitle = 'FIS_FW_R_PUL'
    title  = 'Filter Wheel Pulse Counter (Rewind)'
  ENDIF ELSE IF strmatch(yuvalue, 'FIS_HK_FIS_LW_WIRE_LIGHT') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('FIS_HK', 'FIS_LW_WIRE_LIGHT')
    ytitle = 'FIS_LW_WIRE_LIGHT'
    title  = 'LW wire light DAC value'
  ENDIF ELSE IF strmatch(yuvalue, 'FIS_HK_FIS_RUN_MODE') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('FIS_HK', 'FIS_RUN_MODE')
    ytitle = 'FIS_RUN_MODE'
    title  = 'FIS Run Mode'
  ENDIF ELSE IF strmatch(yuvalue, 'FIS_HK_FIS_OBS_MODE') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('FIS_HK', 'FIS_OBS_MODE')
    ytitle = 'FIS_OBS_MODE'
    title  = 'FIS Observation mode'
  ENDIF ELSE IF strmatch(yuvalue, 'FIS_HK_FIS_ASQ_PATTERN') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('FIS_HK', 'FIS_ASQ_PATTERN')
    ytitle = 'FIS_ASQ_PATTERN'
    title  = 'ASQ pattern'
  ENDIF ELSE IF strmatch(yuvalue, 'FIS_HK_FIS_ASQ_STEP') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('FIS_HK', 'FIS_ASQ_STEP')
    ytitle = 'FIS_ASQ_STEP'
    title  = 'ASQ step'
  ENDIF ELSE IF strmatch(yuvalue, 'FIS_HK_SW_HEATER_TMP') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('FIS_HK', 'SW_HEATER_TMP')
    ytitle = 'SW_HEATER_TMP'
    title  = 'SW Heater temperature'

  ; ## IRC_HK
  ; (1) Time
  ENDIF ELSE IF strmatch(yuvalue, 'IRC_HK_AFTIME') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('IRC_HK', 'AFTIME')
    ytitle = 'AF TIME'
    title  = 'AF TIME in IRC_HK'
  ENDIF ELSE IF strmatch(yuvalue, 'IRC_HK_PIM_TI_ORG') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('IRC_HK', 'PIMTIORG')
    ytitle = 'PIM TI original'
    title  = 'PIM TI original in IRC_HK'
  ; (2) Status
  ENDIF ELSE IF strmatch(yuvalue, 'IRC_HK_BLANK') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('IRC_HK', 'BLANK')
    ytitle = 'IRC_HK_Blank'
    title  = 'IRC_HK Status - Blank'
  ; (3) Analog Data
  ENDIF ELSE IF strmatch(yuvalue, 'IRC_HK_IRC_MAINREF_TMP1') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('IRC_HK', 'IRC_MAINREF_TMP1')
    ytitle = 'IRC_MAINREF_TMP1'
    title  = 'Primary mirror temperature'
  ENDIF ELSE IF strmatch(yuvalue, 'IRC_HK_IRC_SUBREF_TMP') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('IRC_HK', 'IRC_SUBREF_TMP')
    ytitle = 'IRC_SUBREF_TMP'
    title  = 'Secondary mirror temperature'
  ENDIF ELSE IF strmatch(yuvalue, 'IRC_HK_IRC_FPIP_TMP1') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('IRC_HK', 'IRC_FPIP_TMP1')
    ytitle = 'IRC_FPIP_TMP1'
    title  = 'FPI plate temperature (IRC_HK)'

  ; ## HK_2
  ; (1) Time
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_AFTIME') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('HK_2', 'AFTIME')
    ytitle = 'AF TIME'
    title  = 'AF TIME in HK_2'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_PIM_TI_ORG') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('HK_2', 'PIMTIORG')
    ytitle = 'PIM TI original'
    title  = 'PIM TI original in HK_2'
  ; (2) Status
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_BLANK') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('HK_2', 'BLANK')
    ytitle = 'HK_2_Blank'
    title  = 'HK_2 Status - Blank'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_BLANK_CRYO_TEMP_DATA') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('HK_2', 'BLANK_CRYO_TEMP_DATA')
    ytitle = 'HK_2_Balnk_Cryo_Temp_Data'
    title  = 'Blank bit for Cryo temperature data'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_CRYO_TEMP_DATA_EN_DS') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('HK_2', 'CRYO_TEMP_DATA_EN_DS')
    ytitle = 'CRYO_Temp_Data_EN_DS'
    title  = 'Cryo temperature data Enabled/Disabled'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_FIS_CPU_RUN_RST') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('HK_2', 'FIS_CPU_RUN_RST')
    ytitle = 'FIS_CPU_RUN_RST'
    title  = 'FIS CPU Run/Reset'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_FIS_FIS_ON_OFF') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('HK_2', 'FIS_FIS_ON_OFF')
    ytitle = 'FIS_FIS_ON_OFF'
    title  = 'FIS On/Off'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_FIS_TMP_POL_POS_NEG') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('HK_2', 'FIS_TMP_POL_POS_NEG')
    ytitle = 'FIS_Tmp_Pol_POS_NEG'
    title  = 'Thermometer Polarity'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_FIS_OBS_SEQ') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('HK_2', 'FIS_OBS_SEQ')
    ytitle = 'FIS_OBS_SEQ'
    title  = 'FIS Observation Sequence Start/Stop'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_FIS_RSW_AUTO_CMND') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('HK_2', 'FIS_RSW_AUTO_CMND')
    ytitle = 'FIS_RSW_Auto_CMND'
    title  = 'FIS Auto (periodic) Reset On/Off'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_FIS_FCAL_FRQ_B1') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('HK_2', 'FIS_FCAL_FRQ_B1')
    ytitle = 'FIS_FCal_FRQ_B1'
    title  = 'FIS Cal sine wave frequency bit#1'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_FIS_FCAL_FRQ_B0') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('HK_2', 'FIS_FCAL_FRQ_B0')
    ytitle = 'FIS_FCal_FRQ_B0'
    title  = 'FIS Cal sine wave frequency bit#0'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_IRC_CPU_RU_RS') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('HK_2', 'IRC_CPU_RU_RS')
    ytitle = 'IRC_CPU_RU_RS'
    title  = 'IRC CPU Run/Reset'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_IRC_IRC_ON_OF') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('HK_2', 'IRC_IRC_ON_OF')
    ytitle = 'IRC_IRC_ON_OF'
    title  = 'IRC On/Off'
  ; (3) Cryostat temperature
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_CRYO_HE_TANK_1') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('HK_2', 'CRYO_HE_TANK_1')
    ytitle = 'CRYO_HE_TANK_1'
    title  = 'He tank temperature 1 [K]'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_CRYO_BAFFLE_1') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('HK_2', 'CRYO_BAFFLE_1')
    ytitle = 'CRYO_BAFFLE_1'
    title  = 'Baffle temperature 1 [K]'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_CRYO_BAFFLE_2') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('HK_2', 'CRYO_BAFFLE_2')
    ytitle = 'CRYO_BAFFLE_2'
    title  = 'Baffle temperature 2 [K]'
  ; (4) Cryostat current
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_CRYO_COLD_HD_A_DR_I') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('HK_2', 'CRYO_COLD_HD_A_DR_I')
    ytitle = 'CRYO_COLD_HD_A_DR_I'
    title  = 'Cold head A driving current [A]'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_CRYO_COLD_HD_B_DR_I') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('HK_2', 'CRYO_COLD_HD_B_DR_I')
    ytitle = 'CRYO_COLD_HD_B_DR_I'
    title  = 'Cold head B driving current [A]'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_CRYO_COMP_A_DR_I') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('HK_2', 'CRYO_COMP_A_DR_I')
    ytitle = 'CRYO_COMP_A_DR_I'
    title  = 'Compressor A driving current [A]'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_CRYO_COMP_B_DR_I') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('HK_2', 'CRYO_COMP_B_DR_I')
    ytitle = 'CRYO_COMP_B_DR_I'
    title  = 'Compressor B driving current [A]'
  ; (5) IRC Analog data
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_IRC_MAINREF_TMP1') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('HK_2', 'IRC_MAINREF_TMP1')
    ytitle = 'IRC_MAINREF_TMP1'
    title  = 'Primary Mirror Temperature [K]'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_IRC_SUBREF_TMP') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('HK_2', 'IRC_SUBREF_TMP')
    ytitle = 'IRC_SUBREF_TMP'
    title  = 'Secondary Mirror Temperature [K]'
  ENDIF ELSE IF strmatch(yuvalue, 'HK_2_IRC_FPIP_TMP1') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('HK_2', 'IRC_FPIP_TMP1')
    ytitle = 'IRC_FPIP_TMP1'
    title  = 'FPI Plate Temperature [K]'

  ; ## AOCU
  ; (1) Time
  ENDIF ELSE IF strmatch(yuvalue, 'AOCU_AFTIME') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('AOCU', 'AFTIME')
    ytitle = 'AF TIME'
    title  = 'AF TIME in AOCU'
  ENDIF ELSE IF strmatch(yuvalue, 'AOCU_PIM_TI_ORG') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('AOCU', 'PIMTIORG')
    ytitle = 'PIM TI original'
    title  = 'PIM TI original in AOCU'
  ; (2) Status
  ENDIF ELSE IF strmatch(yuvalue, 'AOCU_BLANK') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('AOCU', 'BLANK')
    ytitle = 'AOCU_Blank'
    title  = 'AOCU Status - Blank'
  ENDIF ELSE IF strmatch(yuvalue, 'AOCU_AO_ROM_RAM') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('AOCU', 'AO_ROM_RAM')
    ytitle = 'AO_ROM_RAM'
    title  = 'ROM mode:1 / RAM mode:0'
  ENDIF ELSE IF strmatch(yuvalue, 'AOCU_ADS_MODE_B1') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('AOCU', 'ADS_MODE_B1')
    ytitle = 'ADS_MODE_B1'
    title  = 'Attitude determination mode bit#1'
  ENDIF ELSE IF strmatch(yuvalue, 'AOCU_ADS_MODE_B0') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('AOCU', 'ADS_MODE_B0')
    ytitle = 'ADS_MODE_B0'
    title  = 'Attitude determination mode bit#0'

  ; (3) Analog Data
  ENDIF ELSE IF strmatch(yuvalue, 'ADS_Q*') EQ 1 THEN BEGIN
    num=strmid(yuvalue, 5,1)
    y = tsd->get_value_tsd('AOCU', 'AOCU_ADS_Q')
    y = reform(y[fix(num-1), *])
    ytitle = 'Quaternion'+strcompress(string(fix(num)))
    title  = 'AOCU Quaternion'+strcompress(string(fix(num)))
  ENDIF ELSE IF strmatch(yuvalue, 'AOCU_BR*') EQ 1 THEN BEGIN
    num=strmid(yuvalue, 7,1)
    y = tsd->get_value_tsd('AOCU', 'AOCU_BODY_RATE')
    y = reform(y[fix(num-1), *])
    ytitle = 'BODY_RATE'+strcompress(string(fix(num)))
    title  = 'AOCU Body rate'+strcompress(string(fix(num)))

  ENDIF ELSE IF strmatch(yuvalue, 'AOCU_RA') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('AOCU', 'RA')
    ytitle = 'R.A. (deg) at boresight'
    title  = 'J2000 R.A. (deg) at boresight'
  ENDIF ELSE IF strmatch(yuvalue, 'AOCU_DEC') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('AOCU', 'DEC')
    ytitle = 'Dec. (deg) at boresight'
    title  = 'J2000 Dec. (deg) at boresight'
  ENDIF ELSE IF strmatch(yuvalue, 'AOCU_RANG') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('AOCU', 'RANG')
    ytitle = 'Roll Angle'
    title  = 'Roll Angle'
  ENDIF ELSE IF strmatch(yuvalue, 'AOCU_DRA') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('AOCU', 'DRA')
    ytitle = 'Scan rate in R.A. (deg)'
    title  = 'Scan rate in J2000 R.A. (deg)'
  ENDIF ELSE IF strmatch(yuvalue, 'AOCU_DDEC') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('AOCU', 'DDEC')
    ytitle = 'Scan rate in Dec. (deg)'
    title  = 'Scan rate in J2000 Dec. (deg)'
  ENDIF ELSE IF strmatch(yuvalue, 'AOCU_DRANG') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('AOCU', 'DRANG')
    ytitle = 'Scan rate of roll angle'
    title  = 'Scan rate of roll angle'
  ENDIF ELSE IF strmatch(yuvalue, 'AOCU_CRS_OFF') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('AOCU', 'CRS_OFF')
    ytitle = 'Offset of cross-scan direction'
    title  = 'Offset of cross-scan direction from nominal scan path'

  ;(4) Quality
  ENDIF ELSE IF strmatch(yuvalue, 'AOCU_QUAL_INTP') EQ 1 THEN BEGIN
    y = tsd->Get_Quality_TSD('AOCU', 'Interpolated')
    y = reform(y)
    ytitle = 'Interpolated flag'
    title  = 'Interpolated flag'

  ; ## GADS
  ; (1) Time
  ENDIF ELSE IF strmatch(yuvalue, 'GADS_AFTIME') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('GADS', 'AFTIME')
    ytitle = 'AF TIME'
    title  = 'AF TIME in GADS'
  ENDIF ELSE IF strmatch(yuvalue, 'GADS_PIM_TI_ORG') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('GADS', 'PIMTIORG')
    ytitle = 'PIM TI original'
    title  = 'PIM TI original in GADS'
  ; (2) Status
  ENDIF ELSE IF strmatch(yuvalue, 'GADS_BLANK') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('GADS', 'BLANK')
    ytitle = 'GADS_Blank'
    title  = 'GADS Status - Blank'

  ; (3) Analog Data
  ENDIF ELSE IF strmatch(yuvalue, 'GADS_QUAT*') EQ 1 THEN BEGIN
    num=strmid(yuvalue, 9,1)
    y = tsd->get_value_tsd('GADS', 'ATTITUDE')
    y = reform(y[fix(num-1), *])
    ytitle = 'Attitude'+strcompress(string(fix(num)))
    title  = 'Attitude (Quaternion) '+strcompress(string(fix(num)))
  ENDIF ELSE IF strmatch(yuvalue, 'GADS_ERR*') EQ 1 THEN BEGIN
    num=strmid(yuvalue, 8,1)
    y = tsd->get_value_tsd('GADS', 'ATTITUDE_ER')
    y = reform(y[fix(num-1), *])
    ytitle = 'Attitude_Er'+strcompress(string(fix(num)))
    title  = 'Position Error'+strcompress(string(fix(num)))
  ENDIF ELSE IF strmatch(yuvalue, 'GADS_BR*') EQ 1 THEN BEGIN
    num=strmid(yuvalue, 7,1)
    y = tsd->get_value_tsd('GADS', 'ANGL_VEL')
    y = reform(y[fix(num-1), *])
    ytitle = 'ANGL_VEL'+strcompress(string(fix(num)))
    title  = 'Body rate (Angular velocity) '+strcompress(string(fix(num)))

  ENDIF ELSE IF strmatch(yuvalue, 'GADS_RA') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('GADS', 'RA')
    ytitle = 'R.A. (deg) at boresight'
    title  = 'J2000 R.A. (deg) at boresight'
  ENDIF ELSE IF strmatch(yuvalue, 'GADS_DEC') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('GADS', 'DEC')
    ytitle = 'Dec. (deg) at boresight'
    title  = 'J2000 Dec. (deg) at boresight'
  ENDIF ELSE IF strmatch(yuvalue, 'GADS_RANG') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('GADS', 'RANG')
    ytitle = 'Roll Angle'
    title  = 'Roll Angle'

  ENDIF ELSE IF strmatch(yuvalue, 'GADS_DRA') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('GADS', 'DRA')
    ytitle = 'Scan rate in R.A. (deg)'
    title  = 'Scan rate in J2000 R.A. (deg)'
  ENDIF ELSE IF strmatch(yuvalue, 'GADS_DDEC') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('GADS', 'DDEC')
    ytitle = 'Scan rate in Dec. (deg)'
    title  = 'Scan rate in J2000 Dec. (deg)'
  ENDIF ELSE IF strmatch(yuvalue, 'GADS_DRANG') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('GADS', 'DRANG')
    ytitle = 'Scan rate of roll angle'
    title  = 'Scan rate of roll angle'

  ENDIF ELSE IF strmatch(yuvalue, 'GADS_EL_SOL') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('GADS', 'EL_SOL')
    ytitle = 'Solar elongation'
    title  = 'Solar elongation'
  ENDIF ELSE IF strmatch(yuvalue, 'GADS_AA_SOL') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('GADS', 'AA_SOL')
    ytitle = 'Solar avoidance angle'
    title  = 'Solar avoidance angle'
  ENDIF ELSE IF strmatch(yuvalue, 'GADS_AA_EAR') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('GADS', 'AA_EAR')
    ytitle = 'Earth avoidance angle'
    title  = 'Earth avoidance angle'
  ENDIF ELSE IF strmatch(yuvalue, 'GADS_AA_LUN') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('GADS', 'AA_LUN')
    ytitle = 'Lunar avoidance angle'
    title  = 'Lunar avoidance angle'
  ENDIF ELSE IF strmatch(yuvalue, 'GADS_CRS_OFF') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('GADS', 'CRS_OFF')
    ytitle = 'Offset of cross-scan direction'
    title  = 'Offset of cross-scan direction from nominal scan path'

  ;(4) Quality
  ENDIF ELSE IF strmatch(yuvalue, 'GADS_QUAL_INTP') EQ 1 THEN BEGIN
    y = tsd->Get_Quality_TSD('GADS', 'Interpolated')
    y = reform(y)
    ytitle = 'Interpolated flag'
    title  = 'Interpolated flag'

  ; ## PR
  ; (1) Time
  ENDIF ELSE IF strmatch(yuvalue, 'PR_AFTIME') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('PR', 'AFTIME')
    ytitle = 'AF TIME'
    title  = 'AF TIME in PR'
  ENDIF ELSE IF strmatch(yuvalue, 'PR_PIM_TI_ORG') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('PR', 'PIMTIORG')
    ytitle = 'PIM TI original'
    title  = 'PIM TI original in PR'
  ; (2) Status
  ENDIF ELSE IF strmatch(yuvalue, 'PR_BLANK') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('PR', 'BLANK')
    ytitle = 'PR_Blank'
    title  = 'PR Status - Blank'

  ; (3) Analog Data
  ENDIF ELSE IF strmatch(yuvalue, 'PR_QUAT*') EQ 1 THEN BEGIN
    num=strmid(yuvalue, 7,1)
    y = tsd->get_value_tsd('PR', 'QUATERNION')
    y = reform(y[fix(num-1), *])
    ytitle = 'Quaternion'+strcompress(string(fix(num)))
    title  = 'Quaternion'+strcompress(string(fix(num)))
  ENDIF ELSE IF strmatch(yuvalue, 'PR_ERR*') EQ 1 THEN BEGIN
    num=strmid(yuvalue, 6,1)
    y = tsd->get_value_tsd('PR', 'POS_ERR')
    y = reform(y[fix(num-1), *])
    ytitle = 'Position Error'+strcompress(string(fix(num)))
    title  = 'Position Error'+strcompress(string(fix(num)))
  ENDIF ELSE IF strmatch(yuvalue, 'PR_BR*') EQ 1 THEN BEGIN
    num=strmid(yuvalue, 5,1)
    y = tsd->get_value_tsd('PR', 'BODY_RATE')
    y = reform(y[fix(num-1), *])
    ytitle = 'BODY_RATE'+strcompress(string(fix(num)))
    title  = 'BODY_RATE'+strcompress(string(fix(num)))

  ENDIF ELSE IF strmatch(yuvalue, 'PR_RA') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('PR', 'RA')
    ytitle = 'R.A. (deg) at boresight'
    title  = 'J2000 R.A. (deg) at boresight'
  ENDIF ELSE IF strmatch(yuvalue, 'PR_DEC') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('PR', 'DEC')
    ytitle = 'Dec. (deg) at boresight'
    title  = 'J2000 Dec. (deg) at boresight'
  ENDIF ELSE IF strmatch(yuvalue, 'PR_RANG') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('PR', 'RANG')
    ytitle = 'Roll Angle'
    title  = 'Roll Angle'

  ENDIF ELSE IF strmatch(yuvalue, 'PR_DRA') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('PR', 'DRA')
    ytitle = 'Scan rate in R.A. (deg)'
    title  = 'Scan rate in J2000 R.A. (deg)'
  ENDIF ELSE IF strmatch(yuvalue, 'PR_DDEC') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('PR', 'DDEC')
    ytitle = 'Scan rate in Dec. (deg)'
    title  = 'Scan rate in J2000 Dec. (deg)'
  ENDIF ELSE IF strmatch(yuvalue, 'PR_DRANG') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('PR', 'DRANG')
    ytitle = 'Scan rate of roll angle'
    title  = 'Scan rate of roll angle'

  ENDIF ELSE IF strmatch(yuvalue, 'PR_EL_SOL') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('PR', 'EL_SOL')
    ytitle = 'Solar elongation'
    title  = 'Solar elongation'
  ENDIF ELSE IF strmatch(yuvalue, 'PR_AA_SOL') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('PR', 'AA_SOL')
    ytitle = 'Solar avoidance angle'
    title  = 'Solar avoidance angle'
  ENDIF ELSE IF strmatch(yuvalue, 'PR_AA_EAR') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('PR', 'AA_EAR')
    ytitle = 'Earth avoidance angle'
    title  = 'Earth avoidance angle'
  ENDIF ELSE IF strmatch(yuvalue, 'PR_AA_LUN') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('PR', 'AA_LUN')
    ytitle = 'Lunar avoidance angle'
    title  = 'Lunar avoidance angle'
  ENDIF ELSE IF strmatch(yuvalue, 'PR_CRS_OFF') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('PR', 'CRS_OFF')
    ytitle = 'Offset of cross-scan direction'
    title  = 'Offset of cross-scan direction from nominal scan path'

  ;(4) Quality
  ENDIF ELSE IF strmatch(yuvalue, 'PR_QUAL_INTP') EQ 1 THEN BEGIN
    y = tsd->Get_Quality_TSD('PR', 'Interpolated')
    y = reform(y)
    ytitle = 'Interpolated flag'
    title  = 'Interpolated flag'

  ; ## SE
  ; (1) Time
  ENDIF ELSE IF strmatch(yuvalue, 'SE_AFTIME') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('SE', 'AFTIME')
    ytitle = 'AF TIME'
    title  = 'AF TIME in SE'
  ENDIF ELSE IF strmatch(yuvalue, 'SE_PIM_TI_ORG') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('SE', 'PIMTIORG')
    ytitle = 'PIM TI original'
    title  = 'PIM TI original in SE'
  ; (2) Status
  ENDIF ELSE IF strmatch(yuvalue, 'SE_BLANK') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('SE', 'BLANK')
    ytitle = 'SE_Blank'
    title  = 'SE Status - Blank'
  ENDIF ELSE IF strmatch(yuvalue, 'SE_TYPE') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('SE', 'TYPE')
    ytitle = 'SE_TYPE'
    title  = 'SE Status - Type'
  ENDIF ELSE IF strmatch(yuvalue, 'SE_DAYNIGHT') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('SE', 'DAYNIGHT')
    ytitle = 'SE_DayNight'
    title  = 'SE Status - DayNight'
  ENDIF ELSE IF strmatch(yuvalue, 'SE_IN_SAA') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('SE', 'IN_SAA')
    ytitle = 'SE_In_SAA'
    title  = 'SE Status - In_SAA region'
  ENDIF ELSE IF strmatch(yuvalue, 'SE_IN_POLAR') EQ 1 THEN BEGIN
    y = tsd->get_status_tsd('SE', 'IN_POLAR')
    ytitle = 'SE_In_Polar'
    title  = 'SE Status - In Polar region'
  ; (3) Analog Data
  ENDIF ELSE IF strmatch(yuvalue, 'SE_TM_SAA') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('SE', 'TM_SAA')
    ytitle = 'Sec. since last SAA'
    title  = 'Seconds since last SAA passage'
  ENDIF ELSE IF strmatch(yuvalue, 'SE_SAT_X') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('SE', 'SAT_X')
    ytitle = 'Satellite position X'
    title  = 'Satellite position X in Earth reference frame'
  ENDIF ELSE IF strmatch(yuvalue, 'SE_SAT_Y') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('SE', 'SAT_Y')
    ytitle = 'Satellite position Y'
    title  = 'Satellite position Y in Earth reference frame'
  ENDIF ELSE IF strmatch(yuvalue, 'SE_SAT_Z') EQ 1 THEN BEGIN
    y = tsd->get_value_tsd('SE', 'SAT_Z')
    ytitle = 'Satellite position Z'
    title  = 'Satellite position Z in Earth reference frame'

  ENDIF

end