; $Id: zplot_alt.pro,v 1.21 2006/09/28 06:20:05 makiuti Exp $
;+
; NAME:
;       ZPLOT_ALT
;
; PURPOSE:
;       The purpose of this program is to display a time series data plot.
;
; AUTHOR:
;       ASTRO-F Data Reduction team
;       Web Page: http://www.ir.isas.ac.jp/ASTRO-F/iris_data/
;
; CATEGORY:
;       FIS Data Visualizer
;       Widgets program
;
; CALLING SEQUENCE:
;       This program is usually called from fisv_eventcb.pro
;
; OTHER PROGRAMS NEEDED:
;
;   The following programs are required to run this one:
;
;    getcolor.pro(in ./lib)
;    stat_plot.pro
;
; MODIFY
;       Alternate version of ZPLOT by Makiuti,S.
;       03/03/27 added argument of psym to OPlot to be able to display symbol plot
;                added buttons (set symbol & close window)
;       03/04/17 max five dependent data can be passed
;                ex.) ZPlot, x, y, Y2DATA=y2, ..., Y5DATA=y5, $
;                       Y1TITLE=y1title, ..., Y5TITLE=y5title
;       03/04/22 double Y plot
;       03/04/24 zoom Y-axis
;       03/05/08 made a little change to zoom function
;       03/05/12 added "Update the plot system variables" in "Double Y Plot"
;                added "STAT" button to call stat_plot.pro
;       03/05/21 added "Print" and "PS" buttons, and changed how to make symbol
;       03/05/27 added "Reset"(range), "x 1/2"(zoom out), "<<",">>"(Scroll X) buttons
;                changed behavior for click (without drag) on plot window
;                added grid display function
;       03/05/28 change how to show legends
;       03/05/30 added differentiation button
;       03/10/07 added auto scale button
;       03/10/23 added FFT button
;       03/11/28 changed to use "gb_diff2p.pro" instead of "gb_diff3pl.pro"
;       03/11/30 changed method for calculation of yrange
;       04/04/20 added XMARGIN argument
;       04/11/01 changed not to use "gb_diff2p.pro"
;       05/03/18 Extra mode was added
;       05/10/27 Context menu (HEX-Y and Xticks=3) was added
;       05/11/02 Context menu (Convert AFtime) was added
;       06/09/27 Context menu (Convert temperature unit) was added
;
;#######
; below is the original zplot header
;#######
; PURPOSE:
;
;       The purpose of this program is to display a line plot in a resizeable
;       graphics window which can be zoomed by drawing an "arrow box" on top
;       of it. To return to the un-zoomed plot, click and release anywhere in the window.
;
; AUTHOR:
;
;   FANNING SOFTWARE CONSULTING
;   David Fanning, Ph.D.
;   1645 Sheely Drive
;   Fort Collins, CO 80526 USA
;   Phone: 970-221-0438
;   E-mail: davidf@dfanning.com
;   Coyote's Guide to IDL Programming: http://www.dfanning.com/
;
; CATEGORY:
;
;      Widgets.
;
; CALLING SEQUENCE:
;
;      ZPlot, x, y
;
; OPTIONAL INPUTS:
;
;      x: If only one positional parameter, this is assumed to be the
;         dependent data. If there are two positional parameters, this
;         is assumed to be the independent data in accordance with the
;         PLOT command.
;
;      y: The dependent data, if the X parameter is present.
;
; KEYWORD PARAMETERS:
;
;       Any valid PLOT keyword can be used with this program. In additon,
;       the following keywords are defined specifically.
;
;       GROUP_LEADER: This keyword is used to assign a group leader to this
;                 program. This program will be destroyed when the group
;                 leader is destroyed. Use this keyword if you are calling
;                 ZIMAGE from another widget program.
;
;       XLOG: Set this keyword if you wish the X axis to be logarthmic style.
;
;       YLOG: Set this keyword if you wish the Y axis to be logarthmic style.
;
;       ZOOM_XSIZE: The initial X size of the plot window. Default is 400 pixels.
;
;       ZOOM_YSIZE: The initial Y size of the plot window. Default is 400 pixels.
;
; COMMON BLOCKS:
;
;       None.
;
; SIDE EFFECTS:
;
;       Drawing colors are loaded into the color table.
;
; RESTRICTIONS:
;
;       Zooms only along the X axis.
;
; PROCEDURE:
;
;       Click and drag the cursor to create an "arrow box". The plot
;       is zoomed into the X coordinates of the box, when released.
;       To restore unzoomed plot, click and release anywhere in the
;       window.
;
; EXAMPLE:
;
;        To display an plot you can zoom into, type:
;
;        ZPLOT
;
; MODIFICATION HISTORY:
;
;        Written by: David Fanning, 15 February 2000.
;        Modified the original rubberband box to be an "arrow box". 1 April 2000. DWF.
;        Added the ability to produce log style plots. 20 November 2001. DWF.
;-
;###########################################################################
;
; LICENSE
;
; This software is OSI Certified Open Source Software.
; OSI Certified is a certification mark of the Open Source Initiative.
;
; Copyright  2000-2001 Fanning Software Consulting
;
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software for any
; purpose, including commercial applications, and to alter it and
; redistribute it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software. If you use this software
;    in a product, an acknowledgment in the product documentation
;    would be appreciated, but is not required.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;
; For more information on Open Source Software, visit the Open Source
; web site: http://www.opensource.org.
;
;###########################################################################

;-----------------------------------------------------------------
PRO ZPLOT_CLEANUP, tlb

   ; The purpose of this module is to delete the pixmap window
   ; and perform other cleanup chores when the program ZPLOT is
   ; destroyed.

Widget_Control, tlb, Get_UValue=info
IF N_Elements(info) NE 0 THEN BEGIN
   WDelete, info.pixIndex
   Ptr_Free, info.extraKeywords
ENDIF
END ; of ZPLOT_CLEANUP

;-----------------------------------------------------------------
pro zClsBtn, Event
  WIDGET_CONTROL, Event.top, /DESTROY
end

;-----------------------------------------------------------------
pro get_prop_plot, info, PSYMS=psyms
; This procedure returns an array 'psyms' which contains psym settings

psyms=make_array(5, /integer) ; for maximum five data

IF (info.psym NE 0) THEN BEGIN
  IF (info.line EQ 0) THEN BEGIN ; with symbol witout line
    psyms[0]=7
    psyms[1]=1
    psyms[2]=4
    psyms[3]=2
    psyms[4]=6
  ENDIF ELSE BEGIN ; with both symbol and line
    psyms[0]=-7
    psyms[1]=-1
    psyms[2]=-4
    psyms[3]=-2
    psyms[4]=-6
  ENDELSE
ENDIF ELSE BEGIN ; line witout symbol
  psyms[*]=0
ENDELSE

end

;-----------------------------------------------------------------
pro zNewPlot, Event, info

  ; ## DISPLAY START##
  ; Destroy old pixmap and create a new one.
  WDelete, info.pixIndex
  Window, XSize=info.zxsize, YSize=info.zysize, /Free, /Pixmap
  info.pixIndex = !D. Window

  ;  Set up colors for line plot.
  backColor = GetColor('charcoal', !D.Table_Size-2)
  dataColor = GetColor('yellow', !D.Table_Size-3)
  axisColor = GetColor('green', !D.Table_Size-4)
;#
  dataColor2 = GetColor('pink', !D.Table_Size-5)
  dataColor3 = GetColor('aqua', !D.Table_Size-6)
  dataColor4 = GetColor('magenta', !D.Table_Size-7)
  dataColor5 = GetColor('gray', !D.Table_Size-8)

  ;  Set up properties (line and symbol) of line plot.
  get_prop_plot, info, PSYMS=psyms

  ; ## Draw the plot in both windows. ##

;#
  Plot, info.indep, info.dep, $
     XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
     YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
     Xtitle=info.xtitle, XMargin=info.xmargin, $
     XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
     Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
  OPlot, info.indep, info.dep, Color=dataColor, psym=psyms[0]

  ; Standard position of legends
  title_pos1a = CONVERT_COORD([0.85, 0.90], /NORMAL, /TO_DATA)  ; for symbol
  title_pos1b = CONVERT_COORD([0.86, 0.90], /NORMAL, /TO_DEVICE); for label string
  title_pos1b = CONVERT_COORD(title_pos1b[0],title_pos1b[1]-5, /DEVICE, /TO_DATA)

  title_pos2a = CONVERT_COORD([0.85, 0.85], /NORMAL, /TO_DATA)  ; for symbol
  title_pos2b = CONVERT_COORD([0.86, 0.85], /NORMAL, /TO_DEVICE); for label string
  title_pos2b = CONVERT_COORD(title_pos2b[0],title_pos2b[1]-5, /DEVICE, /TO_DATA)

  title_pos3a = CONVERT_COORD([0.85, 0.80], /NORMAL, /TO_DATA)  ; for symbol
  title_pos3b = CONVERT_COORD([0.86, 0.80], /NORMAL, /TO_DEVICE); for label string
  title_pos3b = CONVERT_COORD(title_pos3b[0],title_pos3b[1]-5, /DEVICE, /TO_DATA)

  title_pos4a = CONVERT_COORD([0.85, 0.75], /NORMAL, /TO_DATA)  ; for symbol
  title_pos4b = CONVERT_COORD([0.86, 0.75], /NORMAL, /TO_DEVICE); for label string
  title_pos4b = CONVERT_COORD(title_pos4b[0],title_pos4b[1]-5, /DEVICE, /TO_DATA)

  title_pos5a = CONVERT_COORD([0.85, 0.70], /NORMAL, /TO_DATA)  ; for symbol
  title_pos5b = CONVERT_COORD([0.86, 0.70], /NORMAL, /TO_DEVICE); for label string
  title_pos5b = CONVERT_COORD(title_pos5b[0],title_pos5b[1]-5, /DEVICE, /TO_DATA)
;#
  IF n_elements(info.dep2) EQ n_elements(info.dep) THEN BEGIN
    IF (info.dbly EQ 1) THEN BEGIN
      Plot, info.indep, info.dep, $
        XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
        YRange=info.yrange, Ystyle=4, Xtitle=info.xtitle, Xmargin=[12.0,12.0], $
        XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
        Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
      axis, yaxis=0, yrange=[Min(info.dep),Max(info.dep)], ytitle=info.y1title, Color=dataColor, $
        Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
      OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]
      axis, yaxis=1, yrange=[Min(info.dep2),Max(info.dep2)], ytitle=info.y2title, Color=dataColor2, $
        Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
      OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
    ENDIF ELSE BEGIN
      OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
      XYOUTS, title_pos1b[0], title_pos1b[1],  info.y1title, Color=dataColor
      Oplot, [title_pos1a[0]], [title_pos1a[1]], Color=dataColor, psym = abs(psyms[0])
      XYOUTS, title_pos2b[0], title_pos2b[1], info.y2title, Color=dataColor2
      Oplot, [title_pos2a[0]], [title_pos2a[1]], Color=dataColor2, psym = abs(psyms[1])
    ENDELSE
  ENDIF
  IF n_elements(info.dep3) EQ n_elements(info.dep) THEN BEGIN
      OPlot, info.indep, info.dep3, Color=dataColor3, psym = psyms[2]
      XYOUTS, title_pos3b[0], title_pos3b[1], info.y3title, Color=dataColor3
      Oplot, [title_pos3a[0]], [title_pos3a[1]], Color=dataColor3, psym = abs(psyms[2])
  ENDIF
  IF n_elements(info.dep4) EQ n_elements(info.dep) THEN BEGIN
      OPlot, info.indep, info.dep4, Color=dataColor4, psym = psyms[3]
      XYOUTS, title_pos4b[0], title_pos4b[1], info.y4title, Color=dataColor4
      Oplot, [title_pos4a[0]], [title_pos4a[1]], Color=dataColor4, psym = abs(psyms[3])
  ENDIF
  IF n_elements(info.dep5) EQ n_elements(info.dep) THEN BEGIN
      OPlot, info.indep, info.dep5, Color=dataColor5, psym = psyms[4]
      XYOUTS, title_pos5b[0], title_pos5b[1], info.y5title, Color=dataColor5
      Oplot, [title_pos5a[0]], [title_pos5a[1]], Color=dataColor5, psym = abs(psyms[4])
  ENDIF
;#
  WSet, info.drawIndex
  Plot, info.indep, info.dep, $
     XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
     YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
     Xtitle=info.xtitle, XMargin=info.xmargin, $
     XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
     Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
  OPlot, info.indep, info.dep, Color=dataColor, psym=psyms[0]
;#
  IF n_elements(info.dep2) EQ n_elements(info.dep) THEN BEGIN
    IF (info.dbly EQ 1) THEN BEGIN
      Plot, info.indep, info.dep, $
        XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
        YRange=info.yrange, Ystyle=4, Xtitle=info.xtitle, Xmargin=[12.0,12.0], $
        XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
        Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
      axis, yaxis=0, yrange=[Min(info.dep),Max(info.dep)], ytitle=info.y1title, Color=dataColor, $
        Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
      OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]
      axis, yaxis=1, yrange=[Min(info.dep2),Max(info.dep2)], ytitle=info.y2title, Color=dataColor2, $
        Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
      OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
    ENDIF ELSE BEGIN
      OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
      XYOUTS, title_pos1b[0], title_pos1b[1],  info.y1title, Color=dataColor
      Oplot, [title_pos1a[0]], [title_pos1a[1]], Color=dataColor, psym = abs(psyms[0])
      XYOUTS, title_pos2b[0], title_pos2b[1], info.y2title, Color=dataColor2
      Oplot, [title_pos2a[0]], [title_pos2a[1]], Color=dataColor2, psym = abs(psyms[1])
    ENDELSE
  ENDIF
  IF n_elements(info.dep3) EQ n_elements(info.dep) THEN BEGIN
      OPlot, info.indep, info.dep3, Color=dataColor3, psym = psyms[2]
      XYOUTS, title_pos3b[0], title_pos3b[1], info.y3title, Color=dataColor3
      Oplot, [title_pos3a[0]], [title_pos3a[1]], Color=dataColor3, psym = abs(psyms[2])
  ENDIF
  IF n_elements(info.dep4) EQ n_elements(info.dep) THEN BEGIN
      OPlot, info.indep, info.dep4, Color=dataColor4, psym = psyms[3]
      XYOUTS, title_pos4b[0], title_pos4b[1], info.y4title, Color=dataColor4
      Oplot, [title_pos4a[0]], [title_pos4a[1]], Color=dataColor4, psym = abs(psyms[3])
  ENDIF
  IF n_elements(info.dep5) EQ n_elements(info.dep) THEN BEGIN
      OPlot, info.indep, info.dep5, Color=dataColor5, psym = psyms[4]
      XYOUTS, title_pos5b[0], title_pos5b[1], info.y5title, Color=dataColor5
      Oplot, [title_pos5a[0]], [title_pos5a[1]], Color=dataColor5, psym = abs(psyms[4])
  ENDIF
  ; ## DISPLAY END##

  ; Update the plot system variables.
  info.x = !X
  info.y = !Y
  info.p = !P

  Widget_Control, event.top, Set_UValue=info, /No_Copy

end

;-----------------------------------------------------------------
pro zPrintBtn, Event, info

  ; Printer OUTPUT
  result=dialog_printersetup()

  IF result EQ 1 THEN BEGIN
    entry_device = !d.name
    set_plot, 'PRINTER'

  ;  Set up properties (line and symbol) of line plot.
  get_prop_plot, info, PSYMS=psyms

      ; Draw the plot
      IF (info.dbly NE 1) THEN BEGIN
        Plot, info.indep, info.dep, $
           XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
           YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
           Xtitle=info.xtitle, XMargin=info.xmargin, $
           XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
           /NoData, _Extra=*info.extraKeywords
        OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]
      ENDIF

      ; Standard position of legends
      title_pos1a = CONVERT_COORD([0.85, 0.90], /NORMAL, /TO_DATA)  ; for symbol
      title_pos1b = CONVERT_COORD([0.86, 0.90], /NORMAL, /TO_DEVICE); for label string
      title_pos1b = CONVERT_COORD(title_pos1b[0],title_pos1b[1]-5, /DEVICE, /TO_DATA)

      title_pos2a = CONVERT_COORD([0.85, 0.85], /NORMAL, /TO_DATA)  ; for symbol
      title_pos2b = CONVERT_COORD([0.86, 0.85], /NORMAL, /TO_DEVICE); for label string
      title_pos2b = CONVERT_COORD(title_pos2b[0],title_pos2b[1]-5, /DEVICE, /TO_DATA)

      title_pos3a = CONVERT_COORD([0.85, 0.80], /NORMAL, /TO_DATA)  ; for symbol
      title_pos3b = CONVERT_COORD([0.86, 0.80], /NORMAL, /TO_DEVICE); for label string
      title_pos3b = CONVERT_COORD(title_pos3b[0],title_pos3b[1]-5, /DEVICE, /TO_DATA)

      title_pos4a = CONVERT_COORD([0.85, 0.75], /NORMAL, /TO_DATA)  ; for symbol
      title_pos4b = CONVERT_COORD([0.86, 0.75], /NORMAL, /TO_DEVICE); for label string
      title_pos4b = CONVERT_COORD(title_pos4b[0],title_pos4b[1]-5, /DEVICE, /TO_DATA)

      title_pos5a = CONVERT_COORD([0.85, 0.70], /NORMAL, /TO_DATA)  ; for symbol
      title_pos5b = CONVERT_COORD([0.86, 0.70], /NORMAL, /TO_DEVICE); for label string
      title_pos5b = CONVERT_COORD(title_pos5b[0],title_pos5b[1]-5, /DEVICE, /TO_DATA)

      IF n_elements(info.dep2) EQ n_elements(info.dep) THEN BEGIN
        IF (info.dbly EQ 1) THEN BEGIN
          Plot, info.indep, info.dep, $
            XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
            YRange=info.yrange, Ystyle=4, Xtitle=info.xtitle, Xmargin=[12.0,12.0], $
            XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
            /NoData, _Extra=*info.extraKeywords
          axis, yaxis=0, yrange=[Min(info.dep),Max(info.dep)], ytitle=info.y1title, $
            Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
          OPlot, info.indep, info.dep, psym = psyms[0]
          axis, yaxis=1, yrange=[Min(info.dep2),Max(info.dep2)], ytitle=info.y2title, $
            Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
          OPlot, info.indep, info.dep2, psym = psyms[1], linestyle=1
        ENDIF ELSE BEGIN
          OPlot, info.indep, info.dep2, psym = psyms[1], linestyle=1
          XYOUTS, title_pos1b[0], title_pos1b[1],  info.y1title
          Oplot, [title_pos1a[0]], [title_pos1a[1]], psym = abs(psyms[0])
          XYOUTS, title_pos2b[0], title_pos2b[1], info.y2title
          Oplot, [title_pos2a[0]], [title_pos2a[1]], psym = abs(psyms[1])
        ENDELSE
      ENDIF
      IF n_elements(info.dep3) EQ n_elements(info.dep) THEN BEGIN
          OPlot, info.indep, info.dep3, psym = psyms[2], linestyle=2
          XYOUTS, title_pos3b[0], title_pos3b[1], info.y3title
          Oplot, [title_pos3a[0]], [title_pos3a[1]], psym = abs(psyms[2])
      ENDIF
      IF n_elements(info.dep4) EQ n_elements(info.dep) THEN BEGIN
          OPlot, info.indep, info.dep4, psym = psyms[3], linestyle=3
          XYOUTS, title_pos4b[0], title_pos4b[1], info.y4title
          Oplot, [title_pos4a[0]], [title_pos4a[1]], psym = abs(psyms[3])
      ENDIF
      IF n_elements(info.dep5) EQ n_elements(info.dep) THEN BEGIN
          OPlot, info.indep, info.dep5, psym = psyms[4], linestyle=4
          XYOUTS, title_pos5b[0], title_pos5b[1], info.y5title
          Oplot, [title_pos5a[0]], [title_pos5a[1]], psym = abs(psyms[4])
      ENDIF

    XYOUTS, 0.02, -0.02, info.filename, /NORMAL
    XYOUTS, 0.6, 1.0, systime(), /NORMAL

    device, /close_document
    set_plot, entry_device
  ENDIF
  ; End of Printer OUTPUT

  Widget_Control, event.top, Set_UValue=info, /No_Copy

end

;-----------------------------------------------------------------
pro zPSBtn, Event, info

  ; PS file OUTPUT
  ; Using FSC_PSConfig program
  ;psObject = Obj_New("FSC_PSConfig", Color=0, /European)
  ;psObject->GUI, Cancel=cancelled, /FontInfo
  psObject = Obj_New("FSC_PSConfig", /Color, /European, /Landscape, $
                     XSize=20.0, YSize=15.0, XOffset=3.0029, YOffset=24.859)
  psObject->GUI, Cancel=cancelled, /FontInfo;, Accept_Button_Name='OK'


  IF cancelled EQ 0 THEN BEGIN
    entry_device = !d.name
    set_plot, 'PS'
    ;device, filename="testOUT.ps"
    device, _Extra=psObject->GetKeywords()

    ; For color plot (Default mode is B/W)
    tmp=psObject->GetKeywords()
    IF (tmp.color eq 1) THEN BEGIN

      ;  Set up colors for line plot.
      axisColor = GetColor('black', !D.Table_Size-4)
      dataColor = GetColor('blue', !D.Table_Size-3)
      dataColor2 = GetColor('red', !D.Table_Size-6)
      dataColor3 = GetColor('dodger blue', !D.Table_Size-7)
      dataColor4 = GetColor('magenta', !D.Table_Size-8)
      dataColor5 = GetColor('charcoal', !D.Table_Size-9)

    ENDIF

    ;  Set up properties (line and symbol) of line plot.
    get_prop_plot, info, PSYMS=psyms

      ; Draw the plot
      IF (info.dbly NE 1) THEN BEGIN
        Plot, info.indep, info.dep, $
          XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
          YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
          Xtitle=info.xtitle, XMargin=info.xmargin, $
          XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
          Color=axisColor, $
          /NoData, _Extra=*info.extraKeywords
        OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]
      ENDIF

      ; Standard position of legends
      title_pos1a = CONVERT_COORD([0.85, 0.90], /NORMAL, /TO_DATA)  ; for symbol
      title_pos1b = CONVERT_COORD([0.86, 0.90], /NORMAL, /TO_DEVICE); for label string
      title_pos1b = CONVERT_COORD(title_pos1b[0],title_pos1b[1]-5, /DEVICE, /TO_DATA)

      title_pos2a = CONVERT_COORD([0.85, 0.85], /NORMAL, /TO_DATA)  ; for symbol
      title_pos2b = CONVERT_COORD([0.86, 0.85], /NORMAL, /TO_DEVICE); for label string
      title_pos2b = CONVERT_COORD(title_pos2b[0],title_pos2b[1]-5, /DEVICE, /TO_DATA)

      title_pos3a = CONVERT_COORD([0.85, 0.80], /NORMAL, /TO_DATA)  ; for symbol
      title_pos3b = CONVERT_COORD([0.86, 0.80], /NORMAL, /TO_DEVICE); for label string
      title_pos3b = CONVERT_COORD(title_pos3b[0],title_pos3b[1]-5, /DEVICE, /TO_DATA)

      title_pos4a = CONVERT_COORD([0.85, 0.75], /NORMAL, /TO_DATA)  ; for symbol
      title_pos4b = CONVERT_COORD([0.86, 0.75], /NORMAL, /TO_DEVICE); for label string
      title_pos4b = CONVERT_COORD(title_pos4b[0],title_pos4b[1]-5, /DEVICE, /TO_DATA)

      title_pos5a = CONVERT_COORD([0.85, 0.70], /NORMAL, /TO_DATA)  ; for symbol
      title_pos5b = CONVERT_COORD([0.86, 0.70], /NORMAL, /TO_DEVICE); for label string
      title_pos5b = CONVERT_COORD(title_pos5b[0],title_pos5b[1]-5, /DEVICE, /TO_DATA)

       IF n_elements(info.dep2) EQ n_elements(info.dep) THEN BEGIN
        IF (info.dbly EQ 1) THEN BEGIN
          Plot, info.indep, info.dep, $
            XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
            YRange=info.yrange, Ystyle=4, Xtitle=info.xtitle, Xmargin=[12.0,12.0], $
            XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
            Color=axisColor, $
            /NoData, _Extra=*info.extraKeywords
          axis, yaxis=0, yrange=[Min(info.dep),Max(info.dep)], ytitle=info.y1title, Color=dataColor, $
            Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
          OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]
          axis, yaxis=1, yrange=[Min(info.dep2),Max(info.dep2)], ytitle=info.y2title, Color=dataColor2, $
            Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
          OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1], linestyle=1
        ENDIF ELSE BEGIN
          OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1], linestyle=1
          XYOUTS, title_pos1b[0], title_pos1b[1],  info.y1title, Color=dataColor
          Oplot, [title_pos1a[0]], [title_pos1a[1]], Color=dataColor, psym = abs(psyms[0])
          XYOUTS, title_pos2b[0], title_pos2b[1], info.y2title, Color=dataColor2
          Oplot, [title_pos2a[0]], [title_pos2a[1]], Color=dataColor2, psym = abs(psyms[1])
        ENDELSE
      ENDIF
      IF n_elements(info.dep3) EQ n_elements(info.dep) THEN BEGIN
          OPlot, info.indep, info.dep3, Color=dataColor3, psym = psyms[2], linestyle=2
          XYOUTS, title_pos3b[0], title_pos3b[1], info.y3title, Color=dataColor3
          Oplot, [title_pos3a[0]], [title_pos3a[1]], Color=dataColor3, psym = abs(psyms[2])
      ENDIF
      IF n_elements(info.dep4) EQ n_elements(info.dep) THEN BEGIN
          OPlot, info.indep, info.dep4, Color=dataColor4, psym = psyms[3], linestyle=3
          XYOUTS, title_pos4b[0], title_pos4b[1], info.y4title, Color=dataColor4
          Oplot, [title_pos4a[0]], [title_pos4a[1]], Color=dataColor4, psym = abs(psyms[3])
      ENDIF
      IF n_elements(info.dep5) EQ n_elements(info.dep) THEN BEGIN
          OPlot, info.indep, info.dep5, Color=dataColor5, psym = psyms[4], linestyle=4
          XYOUTS, title_pos5b[0], title_pos5b[1], info.y5title, Color=dataColor5
          Oplot, [title_pos5a[0]], [title_pos5a[1]], Color=dataColor5, psym = abs(psyms[4])
      ENDIF

    XYOUTS, 0.02, -0.02, info.filename, /NORMAL
    XYOUTS, 0.6, 1.0, systime(), /NORMAL

    device, /close_file
    set_plot, entry_device
  ENDIF

  Obj_Destroy, psObject
  ; End of PS file OUTPUT

  Widget_Control, event.top, Set_UValue=info, /No_Copy

end

;-----------------------------------------------------------------
pro zStatBtn, Event, info

  parent = widget_info(Event.top, find_by_uname='PlotWin')
  info2 = info

  ; If size of STAT window to be made is larger than the device screen size
  screen_size = get_screen_size()
  IF ( (info2.zxsize + 300) GT screen_size[0] ) THEN $
    info2.zxsize = screen_size[0] - 300
  IF ( (info2.zysize + 50) GT screen_size[1] ) THEN $
    info2.zysize = screen_size[1] - 50

  stat_plot, info2, GROUP_LEADER=parent, CHARSIZE = (!d.name EQ 'X') ? 1.4 : 1

  Widget_Control, event.top, Set_UValue=info, /No_Copy

end

;-----------------------------------------------------------------
pro zSFlagBtn, Event, info
COMMON TOP_WID_ID, rootID ; rootID is the FISv top level ID when zplot_alt was called by FISv.

  existence_of_y1 = 0 ; initialize the indicator of existence of Y1 data

  IF (n_elements(info.dep) EQ n_elements(info.indep)) THEN BEGIN
    IF ( (max(info.dep) EQ 1.0) AND (min(info.dep) EQ 0.0) ) THEN BEGIN ; Flag
      flag1 = info.dep
      f1title = info.y1title
      y1 = -1
      y1title = ''
      existence_of_y1 = 0
    ENDIF ELSE BEGIN ; Not flag
      y1 = info.dep
      y1title = info.y1title
      flag1 = -1
      f1title = ''
      existence_of_y1 = 1
    ENDELSE
  ENDIF

  IF (n_elements(info.dep2) EQ n_elements(info.indep)) THEN BEGIN
    IF ( (max(info.dep2) EQ 1.0) AND (min(info.dep2) EQ 0.0) ) THEN BEGIN
      flag2 = info.dep2
      f2title = info.y2title
      y2 = -1
      y2title = ''
    ENDIF ELSE BEGIN
      IF (existence_of_y1 EQ 1) THEN BEGIN ; If there is Y1 data
        y2 = info.dep2
        y2title = info.y2title
      ENDIF ELSE BEGIN ; If there is no Y1 data
        y1 = info.dep2
        y1title = info.y2title
        existence_of_y1 = 1
      ENDELSE
      flag2 = -1
      f2title = ''
    ENDELSE
  ENDIF

  IF (n_elements(info.dep3) EQ n_elements(info.indep)) THEN BEGIN
    IF ( (max(info.dep3) EQ 1.0) AND (min(info.dep3) EQ 0.0) ) THEN BEGIN
      flag3 = info.dep3
      f3title = info.y3title
      y3 = -1
      y3title = ''
    ENDIF ELSE BEGIN
      IF (existence_of_y1 EQ 1) THEN BEGIN ; If there is Y1 data
        y3 = info.dep3
        y3title = info.y3title
      ENDIF ELSE BEGIN ; If there is no Y1 data
        y1 = info.dep3
        y1title = info.y3title
        existence_of_y1 = 1
      ENDELSE
      flag3 = -1
      f3title = ''
    ENDELSE
  ENDIF

  IF (n_elements(info.dep4) EQ n_elements(info.indep)) THEN BEGIN
    IF ( (max(info.dep4) EQ 1.0) AND (min(info.dep4) EQ 0.0) ) THEN BEGIN
      flag4 = info.dep4
      f4title = info.y4title
      y4 = -1
      y4title = ''
    ENDIF ELSE BEGIN
      IF (existence_of_y1 EQ 1) THEN BEGIN ; If there is Y1 data
        y4 = info.dep4
        y4title = info.y4title
      ENDIF ELSE BEGIN ; If there is no Y1 data
        y1 = info.dep4
        y1title = info.y4title
        existence_of_y1 = 1
      ENDELSE
      flag4 = -1
      f4title = ''
    ENDELSE
  ENDIF

  IF (n_elements(info.dep5) EQ n_elements(info.indep)) THEN BEGIN
    IF ( (max(info.dep5) EQ 1.0) AND (min(info.dep5) EQ 0.0) ) THEN BEGIN
      flag5 = info.dep5
      f5title = info.y5title
      y5 = -1
      y5title = ''
    ENDIF ELSE BEGIN
      IF (existence_of_y1 EQ 1) THEN BEGIN ; If there is Y1 data
        y5 = info.dep5
        y5title = info.y5title
      ENDIF ELSE BEGIN ; If there is no Y1 data
        y1 = info.dep5
        y1title = info.y5title
        existence_of_y1 = 1
      ENDELSE
      flag5 = -1
      f5title = ''
    ENDELSE
  ENDIF

  IF (existence_of_y1 EQ 0) THEN BEGIN
    print, 'There is no data other than flags.'
    Result = DIALOG_MESSAGE('There is no data other than flags.', $
                             DIALOG_PARENT=Event.top, /INFORMATION)
    Widget_Control, event.top, Set_UValue=info, /No_Copy
    Return
  ENDIF

  plotwin_geom = widget_info(Event.top, /GEOMETRY); Geometry information of the current window

  zplot_flag, info.indep, y1, Y2DATA=y2, Y3DATA=y3, Y4DATA=y4, Y5DATA=y5, $
   Y1TITLE=y1title, Y2TITLE=y2title, Y3TITLE=y3title, Y4TITLE=y4title, Y5TITLE=y5title, $
   FILENAME=info.filename, $
   FLAG1=flag1, FLAG2=flag2, FLAG3=flag3, FLAG4=flag4, FLAG5=flag5, $
   F1TITLE=f1title, F2TITLE=f2title, F3TITLE=f3title, F4TITLE=f4title, F5TITLE=f5title, $
   GROUP_LEADER=rootID, CHARSIZE = (!d.name EQ 'X') ? 1.4 : 1, $
   XOffset=plotwin_geom.xoffset, YOffset=plotwin_geom.yoffset, $
   ZOOM_XSIZE=info.zxsize, ZOOM_YSIZE=info.zysize

  WIDGET_CONTROL, Event.top, /DESTROY

end

;-----------------------------------------------------------------
pro zFFTBtn, Event, info
COMMON TOP_WID_ID, rootID ; rootID is the FISv top level ID when zplot_alt was called by FISv.

  info2 = info

  ; If more than two data are plotted in the window, show message.
  IF n_elements(info2.dep2) GT 1 THEN BEGIN
    ; Show error message
    result = DIALOG_MESSAGE(["Only the first data is used for FFT!"],$
                            DIALOG_PARENT=Event.top, /INFORMATION)
    print, 'Only the first data is used for FFT!'
  ENDIF

  ; The current viewing data will be sent to FFT box.
  data = info2.dep[where( (info2.indep GT info2.xrange[0]) AND (info2.indep LT info2.xrange[1]) $
                          AND (info2.dep GT info2.yrange[0]) AND (info2.dep LT info2.yrange[1]) )]

  fft_box, data, DNAME=info2.y1title, GROUP_LEADER=rootID

  Widget_Control, event.top, Set_UValue=info, /No_Copy

end

;-----------------------------------------------------------------
pro zExtBtn, Event, info ;;;; Switch the extra button mode
COMMON TOP_WID_ID, rootID ; rootID is the FISv top level ID when zplot_alt was called by FISv.

  plotwin_geom = widget_info(Event.top, /GEOMETRY); Geometry information of the current window

  extbtn_mode = (info.extbtn_mode EQ 1) ? 0:1

  zplot_alt, info.indep, info.dep, Y2DATA=info.dep2, Y3DATA=info.dep3, Y4DATA=info.dep4, Y5DATA=info.dep5, $
   Y1TITLE=info.y1title, Y2TITLE=info.y2title, Y3TITLE=info.y3title, Y4TITLE=info.y4title, Y5TITLE=info.y5title, $
   Xtitle=info.xtitle, FILENAME=info.filename, GROUP_LEADER=rootID, $
   XLog=info.xlog, YLog=info.ylog, $
   x_range2=info.xrange, y_range2=info.yrange, xstyle=1, ystyle=1, $
   psym=info.psym, TickLen=info.ticklen, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
   ZOOM_XSIZE = (info.zxsize GT 600)?info.zxsize:600, ZOOM_YSIZE=info.zysize, $
   extbtn_mode=extbtn_mode, $ ;;; Extra Button Mode ON
   XOffset=plotwin_geom.xoffset, YOffset=plotwin_geom.yoffset, $
   _Extra=*info.extraKeywords

  WIDGET_CONTROL, Event.top, /DESTROY

end

;-----------------------------------------------------------------
PRO HexEvent, Event ;;;; Convert y-axis lavel format into hexadecimal.
COMMON TOP_WID_ID, rootID ; rootID is the FISv top level ID when zplot_alt was called by FISv.

  ; This event handler reponds to TLB re-size events.
  Widget_Control, event.top, Get_UValue=info, /No_Copy

  plotwin_geom = widget_info(Event.top, /GEOMETRY); Geometry information of the current window

  zplot_alt, info.indep, info.dep, Y2DATA=info.dep2, Y3DATA=info.dep3, Y4DATA=info.dep4, Y5DATA=info.dep5, $
   Y1TITLE=info.y1title, Y2TITLE=info.y2title, Y3TITLE=info.y3title, Y4TITLE=info.y4title, Y5TITLE=info.y5title, $
   Xtitle=info.xtitle, FILENAME=info.filename, GROUP_LEADER=rootID, $
   XLog=info.xlog, YLog=info.ylog, $
   x_range2=info.xrange, y_range2=info.yrange, xstyle=1, ystyle=1, $
   psym=info.psym, TickLen=info.ticklen, $
   ZOOM_XSIZE = info.zxsize, ZOOM_YSIZE=info.zysize, $
   extbtn_mode=info.extbtn_mode, $
   XOffset=plotwin_geom.xoffset, YOffset=plotwin_geom.yoffset, $
   XTickFormat=info.xtickformat, YTickFormat='(Z,"h")', $
   _Extra = *info.extraKeywords

  WIDGET_CONTROL, Event.top, /DESTROY

END

;-----------------------------------------------------------------
PRO ThermoEvent, Event ;;;; Convert y-axis lavel format into hexadecimal.
COMMON TOP_WID_ID, rootID ; rootID is the FISv top level ID when zplot_alt was called by FISv.

  ; This event handler reponds to TLB re-size events.
  Widget_Control, event.top, Get_UValue=info, /No_Copy

  plotwin_geom = widget_info(Event.top, /GEOMETRY); Geometry information of the current window

  WIDGET_CONTROL, /HOURGLASS

  ; Initialize thermometer flag
  nothermo = 0 ; If 1, there is no data for thermometers

  IF (info.y1title EQ 'TpSW') THEN BEGIN
    dep = fis_temp('SW', info.dep)
  ENDIF ELSE IF (info.y1title EQ 'TpLW') THEN BEGIN
    dep = fis_temp('LW', info.dep)
  ENDIF ELSE IF (info.y1title EQ 'TpBody') THEN BEGIN
    dep = fis_temp('BODY', info.dep)
  ENDIF ELSE IF (info.y1title EQ 'TpCalFT') THEN BEGIN
    dep = fis_temp('FTS', info.dep)
  ENDIF ELSE BEGIN
    dep = info.dep
    nothermo = 1 ; If 1, there is no data for thermometers
  ENDELSE

  IF (info.y2title EQ 'TpSW') THEN BEGIN
    dep2 = fis_temp('SW', info.dep2)
    nothermo = 0
  ENDIF ELSE IF (info.y2title EQ 'TpLW') THEN BEGIN
    dep2 = fis_temp('LW', info.dep2)
    nothermo = 0
  ENDIF ELSE IF (info.y2title EQ 'TpBody') THEN BEGIN
    dep2 = fis_temp('BODY', info.dep2)
    nothermo = 0
  ENDIF ELSE IF (info.y2title EQ 'TpCalFT') THEN BEGIN
    dep2 = fis_temp('FTS', info.dep2)
    nothermo = 0
  ENDIF ELSE BEGIN
    dep2 = info.dep2
    IF (n_elements(dep2) LE 1) THEN dep2=mean(dep) ; Actually no dep2
  ENDELSE

  IF (info.y3title EQ 'TpSW') THEN BEGIN
    dep3 = fis_temp('SW', info.dep3)
    nothermo = 0
  ENDIF ELSE IF (info.y3title EQ 'TpLW') THEN BEGIN
    dep3 = fis_temp('LW', info.dep3)
    nothermo = 0
  ENDIF ELSE IF (info.y3title EQ 'TpBody') THEN BEGIN
    dep3 = fis_temp('BODY', info.dep3)
    nothermo = 0
  ENDIF ELSE IF (info.y3title EQ 'TpCalFT') THEN BEGIN
    dep3 = fis_temp('FTS', info.dep3)
    nothermo = 0
  ENDIF ELSE BEGIN
    dep3 = info.dep3
    IF (n_elements(dep3) LE 1) THEN dep3=mean(dep) ; Actually no dep3
  ENDELSE

  IF (info.y4title EQ 'TpSW') THEN BEGIN
    dep4 = fis_temp('SW', info.dep4)
    nothermo = 0
  ENDIF ELSE IF (info.y4title EQ 'TpLW') THEN BEGIN
    dep4 = fis_temp('LW', info.dep4)
    nothermo = 0
  ENDIF ELSE IF (info.y4title EQ 'TpBody') THEN BEGIN
    dep4 = fis_temp('BODY', info.dep4)
    nothermo = 0
  ENDIF ELSE IF (info.y4title EQ 'TpCalFT') THEN BEGIN
    dep4 = fis_temp('FTS', info.dep4)
    nothermo = 0
  ENDIF ELSE BEGIN
    dep4 = info.dep4
    IF (n_elements(dep4) LE 1) THEN dep4=mean(dep) ; Actually no dep4
  ENDELSE

  IF (info.y5title EQ 'TpSW') THEN BEGIN
    dep5 = fis_temp('SW', info.dep5)
    nothermo = 0
  ENDIF ELSE IF (info.y5title EQ 'TpLW') THEN BEGIN
    dep5 = fis_temp('LW', info.dep5)
    nothermo = 0
  ENDIF ELSE IF (info.y5title EQ 'TpBody') THEN BEGIN
    dep5 = fis_temp('BODY', info.dep5)
    nothermo = 0
  ENDIF ELSE IF (info.y5title EQ 'TpCalFT') THEN BEGIN
    dep5 = fis_temp('FTS', info.dep5)
    nothermo = 0
  ENDIF ELSE BEGIN
    dep5 = info.dep5
    IF (n_elements(dep5) LE 1) THEN dep5=mean(dep) ; Actually no dep5
  ENDELSE

  IF (nothermo EQ 1) THEN BEGIN ; If 1, there is no data for thermometers
    Result = DIALOG_MESSAGE('No data for thermometers (TpSW, TpLW, TpBody, TpCalFT)', /INFORMATION, DIALOG_PARENT=Event.top)
    Widget_Control, event.top, Set_UValue=info, /No_Copy
    return
  ENDIF

  zplot_alt, info.indep, dep, Y2DATA=dep2, Y3DATA=dep3, Y4DATA=dep4, Y5DATA=dep5, $
   Y1TITLE=info.y1title, Y2TITLE=info.y2title, Y3TITLE=info.y3title, Y4TITLE=info.y4title, Y5TITLE=info.y5title, $
   Xtitle=info.xtitle, FILENAME=info.filename, GROUP_LEADER=rootID, $
   XLog=info.xlog, YLog=info.ylog, $
   x_range2=info.xrange, xstyle=1, $
   psym=info.psym, TickLen=info.ticklen, $
   ZOOM_XSIZE = info.zxsize, ZOOM_YSIZE=info.zysize, $
   extbtn_mode=info.extbtn_mode, $
   XOffset=plotwin_geom.xoffset, YOffset=plotwin_geom.yoffset, $
   XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
   _Extra = *info.extraKeywords

  WIDGET_CONTROL, Event.top, /DESTROY

END

;-----------------------------------------------------------------
PRO xAFtimeEvent, Event ;;;; Display AFtime of X-axis as Date and Time
COMMON TOP_WID_ID, rootID ; rootID is the FISv top level ID when zplot_alt was called by FISv.

  ; This event handler reponds to TLB re-size events.
  Widget_Control, event.top, Get_UValue=info, /No_Copy

  plotwin_geom = widget_info(Event.top, /GEOMETRY); Geometry information of the current window

  WIDGET_CONTROL, /HOURGLASS

  IF (info.xtitle EQ 'AF TIME') THEN BEGIN

    ;; Convert data from AFtime to Date
    date = cnv_aftime(info.indep, JD=jd)
    info.indep = jd

    ;; Convert initial display range of X-axis
    dmy_xrange = cnv_aftime(info.xrange, JD=jd)
    info.xrange = jd

    ;; Create format strings for a two-level axis
    dummy = LABEL_DATE(DATE_FORMAT=['%H:%I:%S%3','%Y-%M-%D'])
    info.xtickformat = 'LABEL_DATE'

    ;; Make new plot
    zplot_alt, info.indep, info.dep, Y2DATA=info.dep2, Y3DATA=info.dep3, Y4DATA=info.dep4, Y5DATA=info.dep5, $
     Y1TITLE=info.y1title, Y2TITLE=info.y2title, Y3TITLE=info.y3title, Y4TITLE=info.y4title, Y5TITLE=info.y5title, $
     Xtitle=info.xtitle, FILENAME=info.filename, GROUP_LEADER=rootID, $
     XLog=info.xlog, YLog=info.ylog, $
     x_range2=info.xrange, y_range2=info.yrange, $
     xstyle=1, ystyle=1, $
     psym=info.psym, TickLen=info.ticklen, $
     ZOOM_XSIZE = info.zxsize, ZOOM_YSIZE=info.zysize, $
     extbtn_mode=info.extbtn_mode, $
     XOffset=plotwin_geom.xoffset, YOffset=plotwin_geom.yoffset, $
     YTickFormat=info.ytickformat, XTicks=3, $
     XTickFormat=info.xtickformat, XTickUnits=['Time', 'Time'], YMARGIN=[6,2] , $
     _Extra = *info.extraKeywords

    WIDGET_CONTROL, Event.top, /DESTROY

  ENDIF ELSE BEGIN
    Result = DIALOG_MESSAGE('X-data is not AFTIME', /INFORMATION, DIALOG_PARENT=Event.top)
    Widget_Control, event.top, Set_UValue=info, /No_Copy
  ENDELSE

END

;-----------------------------------------------------------------
PRO xTicksEvent, Event ;;;; Suppress x-axis tick number and set it three.
COMMON TOP_WID_ID, rootID ; rootID is the FISv top level ID when zplot_alt was called by FISv.

  ; This event handler reponds to TLB re-size events.
  Widget_Control, event.top, Get_UValue=info, /No_Copy

  plotwin_geom = widget_info(Event.top, /GEOMETRY); Geometry information of the current window

  zplot_alt, info.indep, info.dep, Y2DATA=info.dep2, Y3DATA=info.dep3, Y4DATA=info.dep4, Y5DATA=info.dep5, $
   Y1TITLE=info.y1title, Y2TITLE=info.y2title, Y3TITLE=info.y3title, Y4TITLE=info.y4title, Y5TITLE=info.y5title, $
   Xtitle=info.xtitle, FILENAME=info.filename, GROUP_LEADER=rootID, $
   XLog=info.xlog, YLog=info.ylog, $
   x_range2=info.xrange, y_range2=info.yrange, xstyle=1, ystyle=1, $
   psym=info.psym, TickLen=info.ticklen, $
   ZOOM_XSIZE = info.zxsize, ZOOM_YSIZE=info.zysize, $
   extbtn_mode=info.extbtn_mode, $
   XOffset=plotwin_geom.xoffset, YOffset=plotwin_geom.yoffset, $
   XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, XTicks=3, $
   _Extra = *info.extraKeywords

  WIDGET_CONTROL, Event.top, /DESTROY

END

;-----------------------------------------------------------------
PRO zZPLOT_RESIZE, event

On_Error, 2

; This event handler reponds to TLB re-size events.
 Widget_Control, event.top, Get_UValue=info, /No_Copy

;#####Start of altered code#####
  wWidget = Event.top
  wTarget = Event.id
  ;help, event, /structure

  case wTarget of

    ; ##Close Plot Window##
    Widget_Info(wWidget, FIND_BY_UNAME='ClsBtn'): begin
    if( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' )then $
      zClsBtn, Event
    end

    ; ##Grid On/Off##
    Widget_Info(wWidget, FIND_BY_UNAME='GridBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Switch ticklen
        info.ticklen = (info.ticklen EQ 0.02) ? 1.0:0.02

        ; Make new plot
        zNewPlot, Event, info
      ENDIF
    end

    ; ##Reset range##
    Widget_Info(wWidget, FIND_BY_UNAME='ResetBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Back to the initial ranges
        info.xrange = info.xrange_def
        info.yrange = info.yrange_def

        ; Set axis style
        info.xstyle = 0
        info.ystyle = 0

        ; Make new plot
        zNewPlot, Event, info
      ENDIF
    end

    ; ##Auto Scale##
    Widget_Info(wWidget, FIND_BY_UNAME='ASBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        x0 = info.xrange[0]
        x1 = info.xrange[1]
        data1 = info.dep[where((info.indep GT x0) AND (info.indep LT x1))]
        data2 = info.dep2[where((info.indep GT x0) AND (info.indep LT x1))]
        data3 = info.dep3[where((info.indep GT x0) AND (info.indep LT x1))]
        data4 = info.dep4[where((info.indep GT x0) AND (info.indep LT x1))]
        data5 = info.dep5[where((info.indep GT x0) AND (info.indep LT x1))]
        info.yrange[0] = min([data1,data2,data3,data4,data5])
        info.yrange[1] = max([data1,data2,data3,data4,data5])

        ; Make new plot
        zNewPlot, Event, info
      ENDIF
    end

    ; ## X&Y Zoom Out (half) ##
    Widget_Info(wWidget, FIND_BY_UNAME='ZoutBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_xrange = info.xrange[1] - info.xrange[0]
        info.xrange[0] = info.xrange[0] - current_xrange/2.0
        info.xrange[1] = info.xrange[1] + current_xrange/2.0

        current_yrange = info.yrange[1] - info.yrange[0]
        info.yrange[0] = info.yrange[0] - current_yrange/2.0
        info.yrange[1] = info.yrange[1] + current_yrange/2.0

        ; Make new plot
        zNewPlot, Event, info
      ENDIF
    end
    ; ## X Zoom Out (half) ##
    Widget_Info(wWidget, FIND_BY_UNAME='xZoutBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_xrange = info.xrange[1] - info.xrange[0]
        info.xrange[0] = info.xrange[0] - current_xrange/2.0
        info.xrange[1] = info.xrange[1] + current_xrange/2.0

        ; Make new plot
        zNewPlot, Event, info
      ENDIF
    end
    ; ## Y Zoom Out (half) ##
    Widget_Info(wWidget, FIND_BY_UNAME='yZoutBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_yrange = info.yrange[1] - info.yrange[0]
        info.yrange[0] = info.yrange[0] - current_yrange/2.0
        info.yrange[1] = info.yrange[1] + current_yrange/2.0

        ; Make new plot
        zNewPlot, Event, info
      ENDIF
    end
    ; ## X&Y Zoom In (twice) ##
    Widget_Info(wWidget, FIND_BY_UNAME='ZinBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_xrange = info.xrange[1] - info.xrange[0]
        info.xrange[0] = info.xrange[0] + current_xrange/4.0
        info.xrange[1] = info.xrange[1] - current_xrange/4.0

        current_yrange = info.yrange[1] - info.yrange[0]
        info.yrange[0] = info.yrange[0] + current_yrange/4.0
        info.yrange[1] = info.yrange[1] - current_yrange/4.0

        ; Make new plot
        zNewPlot, Event, info
      ENDIF
    end
    ; ## X Zoom In (twice) ##
    Widget_Info(wWidget, FIND_BY_UNAME='xZinBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_xrange = info.xrange[1] - info.xrange[0]
        info.xrange[0] = info.xrange[0] + current_xrange/4.0
        info.xrange[1] = info.xrange[1] - current_xrange/4.0

        ; Make new plot
        zNewPlot, Event, info
      ENDIF
    end
    ; ## Y Zoom In (twice) ##
    Widget_Info(wWidget, FIND_BY_UNAME='yZinBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_yrange = info.yrange[1] - info.yrange[0]
        info.yrange[0] = info.yrange[0] + current_yrange/4.0
        info.yrange[1] = info.yrange[1] - current_yrange/4.0

        ; Make new plot
        zNewPlot, Event, info
      ENDIF
    end

    ; ##Scroll to Left##
    Widget_Info(wWidget, FIND_BY_UNAME='ScrLBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_xrange = info.xrange[1] - info.xrange[0]
        info.xrange[0] = info.xrange[0] - current_xrange*0.8
        info.xrange[1] = info.xrange[1] - current_xrange*0.8

        ; Make new plot
        zNewPlot, Event, info
      ENDIF
    end
    ; ##Scroll to Right##
    Widget_Info(wWidget, FIND_BY_UNAME='ScrRBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_xrange = info.xrange[1] - info.xrange[0]
        info.xrange[0] = info.xrange[0] + current_xrange*0.8
        info.xrange[1] = info.xrange[1] + current_xrange*0.8

        ; Make new plot
        zNewPlot, Event, info
      ENDIF
    end
    ; ##Scroll Up##
    Widget_Info(wWidget, FIND_BY_UNAME='ScrUBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_yrange = info.yrange[1] - info.yrange[0]
        info.yrange[0] = info.yrange[0] + current_yrange*0.8
        info.yrange[1] = info.yrange[1] + current_yrange*0.8

        ; Make new plot
        zNewPlot, Event, info
      ENDIF
    end
    ; ##Scroll Down##
    Widget_Info(wWidget, FIND_BY_UNAME='ScrDBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Set new range
        current_yrange = info.yrange[1] - info.yrange[0]
        info.yrange[0] = info.yrange[0] - current_yrange*0.8
        info.yrange[1] = info.yrange[1] - current_yrange*0.8

        ; Make new plot
        zNewPlot, Event, info
      ENDIF
    end

    ; ##Switch Extra Button Display##
    Widget_Info(wWidget, FIND_BY_UNAME='ExtBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN $
        zExtBtn, Event, info
    end

    ; ##Open Stat Window##
    Widget_Info(wWidget, FIND_BY_UNAME='StatBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN $
        zStatBtn, Event, info
    end

    ; ##Separate flag and other data##
    Widget_Info(wWidget, FIND_BY_UNAME='SFlagBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN $
        zSFlagBtn, Event, info
    end

    ; ##Differentiation##
    Widget_Info(wWidget, FIND_BY_UNAME='DiffBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Make an array to differentiate
        to_diff = info.dep
        IF n_elements(info.dep) EQ n_elements(info.dep2) THEN $
          to_diff = [[to_diff], [info.dep2]]
        IF n_elements(info.dep) EQ n_elements(info.dep3) THEN $
          to_diff = [[to_diff], [info.dep3]]
        IF n_elements(info.dep) EQ n_elements(info.dep4) THEN $
          to_diff = [[to_diff], [info.dep4]]
        IF n_elements(info.dep) EQ n_elements(info.dep5) THEN $
          to_diff = [[to_diff], [info.dep5]]
        to_diff = transpose(to_diff)

        ; Differentiate
        ;result = gb_diff2p(to_diff, diffed)
        sval = shift(to_diff, 0, 1)
        diffed = to_diff - sval

        ; Write back the array
        info.dep = diffed[0,*]
        IF (n_elements(diffed[*,0]) GE 2) THEN $
          info.dep2 = diffed[1,*]
        IF (n_elements(diffed[*,0]) GE 3) THEN $
          info.dep3 = diffed[2,*]
        IF (n_elements(diffed[*,0]) GE 4) THEN $
          info.dep4 = diffed[3,*]
        IF (n_elements(diffed[*,0]) GE 5) THEN $
          info.dep5 = diffed[4,*]

        ; Set new ranges
        info.yrange = [Min([info.dep,info.dep2,info.dep3,info.dep4,info.dep5]),$
                       Max([info.dep,info.dep2,info.dep3,info.dep4,info.dep5])]
        info.yrange_def = info.yrange

        ; Make new plot
        zNewPlot, Event, info
      ENDIF
    end

    ; ##FFT##
    Widget_Info(wWidget, FIND_BY_UNAME='FFTBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' )THEN $
        zFFTBtn, Event, info
    end

    ; ##Print Out##
    Widget_Info(wWidget, FIND_BY_UNAME='PrintBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' )THEN $
        zPrintBtn, Event, info
    end

    ; ##Make a PS file##
    Widget_Info(wWidget, FIND_BY_UNAME='PSBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' )THEN $
        zPSBtn, Event, info
    end

    ; ##Plot Symbol On/Off##
    Widget_Info(wWidget, FIND_BY_UNAME='SymbBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' )THEN BEGIN

        ; Get widget ID of SymbBtn
        LineBtn = Widget_Info(wWidget, FIND_BY_UNAME='LineBtn')
        IF (LineBtn NE 0) THEN BEGIN
          ; Switch widgets sensitive
          IF (info.psym EQ 0) THEN BEGIN
            Widget_Control, LineBtn, SENSITIVE=1
          ENDIF ELSE BEGIN
            Widget_Control, LineBtn, /SET_BUTTON
            Widget_Control, LineBtn, SENSITIVE=0
          ENDELSE
          info.line = Widget_Info(LineBtn, /BUTTON_SET)
        ENDIF

        ; Switch info.psym
        info.psym = (info.psym EQ 0) ? -7:0

        ; Make new plot
        zNewPlot, Event, info

      ENDIF
    end

    ; ##Plot Line On/Off##
    Widget_Info(wWidget, FIND_BY_UNAME='LineBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' )THEN BEGIN

        ; Switch info.line
        info.line = (info.line EQ 0) ? 1:0

        ; Make new plot
        zNewPlot, Event, info

      ENDIF
    end

    ; ##Double Y Plot##
    Widget_Info(wWidget, FIND_BY_UNAME='DblYBtn'): begin
      IF( Tag_Names(Event, /STRUCTURE_NAME) eq 'WIDGET_BUTTON' ) THEN BEGIN

        ; Switch Double Y Flag mode and enable/disable some buttoms
        ZinBtn = Widget_Info(wWidget, FIND_BY_UNAME='ZinBtn')
        ZoutBtn = Widget_Info(wWidget, FIND_BY_UNAME='ZoutBtn')
        yZinBtn = Widget_Info(wWidget, FIND_BY_UNAME='yZinBtn')
        yZoutBtn = Widget_Info(wWidget, FIND_BY_UNAME='yZoutBtn')
        ScrUBtn = Widget_Info(wWidget, FIND_BY_UNAME='ScrUBtn')
        ScrDBtn = Widget_Info(wWidget, FIND_BY_UNAME='ScrDBtn')

        IF info.dbly EQ 0 THEN BEGIN ; Normal -> Double Y
          info.dbly=1
          IF (info.extbtn_mode EQ 1) THEN BEGIN ; If extra button mode
            IF (ZinBtn NE 0) THEN Widget_Control, ZinBtn, Sensitive=0
            IF (ZoutBtn NE 0) THEN Widget_Control, ZoutBtn, Sensitive=0
          ENDIF
          IF (yZinBtn NE 0) THEN Widget_Control, yZinBtn, Sensitive=0
          IF (yZoutBtn NE 0) THEN Widget_Control, yZoutBtn, Sensitive=0
          IF (ScrUBtn NE 0) THEN Widget_Control, ScrUBtn, Sensitive=0
          IF (ScrDBtn NE 0) THEN Widget_Control, ScrDBtn, Sensitive=0
        ENDIF ELSE BEGIN ; Double Y -> Normal
          info.dbly=0
          IF (ZinBtn NE 0) THEN Widget_Control, ZinBtn, Sensitive=1
          IF (ZoutBtn NE 0) THEN Widget_Control, ZoutBtn, Sensitive=1
          IF (yZinBtn NE 0) THEN Widget_Control, yZinBtn, Sensitive=1
          IF (yZoutBtn NE 0) THEN Widget_Control, yZoutBtn, Sensitive=1
          IF (ScrUBtn NE 0) THEN Widget_Control, ScrUBtn, Sensitive=1
          IF (ScrDBtn NE 0) THEN Widget_Control, ScrDBtn, Sensitive=1
        ENDELSE
        ;print, 'DoubleY Flag', info.dbly;#####

        IF (info.dbly EQ 1) THEN BEGIN
          yZinBtn = Widget_Info(wWidget, FIND_BY_UNAME='yZinBtn')
          IF (yZinBtn NE 0) THEN Widget_Control, yZinBtn, Sensitive=0
        ENDIF

        ; Destroy old pixmap and create a new one.
        WDelete, info.pixIndex
        Window, XSize=info.zxsize, YSize=info.zysize, /Free, /Pixmap
        info.pixIndex = !D. Window

        ; Set up colors for line plot.
        backColor = GetColor('charcoal', !D.Table_Size-2)
        dataColor = GetColor('yellow', !D.Table_Size-3)
        axisColor = GetColor('green', !D.Table_Size-4)
;#
        dataColor2 = GetColor('pink', !D.Table_Size-5)

       ;  Set up properties (line and symbol) of line plot.
       get_prop_plot, info, PSYMS=psyms

        ; Back to the initial Y range
        IF info.dbly NE 1 THEN BEGIN
          info.yrange = info.yrange_def
          info.ystyle = 0
        ENDIF


        ; Draw the plot in both windows.
        Plot, info.indep, info.dep, $
          XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
          YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
          Xtitle=info.xtitle, XMargin=info.xmargin, $
          XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
          Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
        OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]

        ; Standard position of legends
        title_pos1a = CONVERT_COORD([0.85, 0.90], /NORMAL, /TO_DATA)  ; for symbol
        title_pos1b = CONVERT_COORD([0.86, 0.90], /NORMAL, /TO_DEVICE); for label string
        title_pos1b = CONVERT_COORD(title_pos1b[0],title_pos1b[1]-5, /DEVICE, /TO_DATA)

        title_pos2a = CONVERT_COORD([0.85, 0.85], /NORMAL, /TO_DATA)  ; for symbol
        title_pos2b = CONVERT_COORD([0.86, 0.85], /NORMAL, /TO_DEVICE); for label string
        title_pos2b = CONVERT_COORD(title_pos2b[0],title_pos2b[1]-5, /DEVICE, /TO_DATA)

        title_pos3a = CONVERT_COORD([0.85, 0.80], /NORMAL, /TO_DATA)  ; for symbol
        title_pos3b = CONVERT_COORD([0.86, 0.80], /NORMAL, /TO_DEVICE); for label string
        title_pos3b = CONVERT_COORD(title_pos3b[0],title_pos3b[1]-5, /DEVICE, /TO_DATA)

        title_pos4a = CONVERT_COORD([0.85, 0.75], /NORMAL, /TO_DATA)  ; for symbol
        title_pos4b = CONVERT_COORD([0.86, 0.75], /NORMAL, /TO_DEVICE); for label string
        title_pos4b = CONVERT_COORD(title_pos4b[0],title_pos4b[1]-5, /DEVICE, /TO_DATA)

        title_pos5a = CONVERT_COORD([0.85, 0.70], /NORMAL, /TO_DATA)  ; for symbol
        title_pos5b = CONVERT_COORD([0.86, 0.70], /NORMAL, /TO_DEVICE); for label string
        title_pos5b = CONVERT_COORD(title_pos5b[0],title_pos5b[1]-5, /DEVICE, /TO_DATA)
;#
        IF n_elements(info.dep2) EQ n_elements(info.dep) THEN BEGIN
          IF (info.dbly EQ 1) THEN BEGIN
            Plot, info.indep, info.dep, $
              XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
              YRange=info.yrange, Ystyle=4, Xtitle=info.xtitle, Xmargin=[12.0,12.0], $
              XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
              Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
            axis, yaxis=0, yrange=[Min(info.dep),Max(info.dep)], ytitle=info.y1title, Color=dataColor, $
              Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
            OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]
            axis, yaxis=1, yrange=[Min(info.dep2),Max(info.dep2)], ytitle=info.y2title, Color=dataColor2, $
              Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
            OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
          ENDIF ELSE BEGIN
            OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
            XYOUTS, title_pos1b[0], title_pos1b[1],  info.y1title, Color=dataColor
            Oplot, [title_pos1a[0]], [title_pos1a[1]], Color=dataColor, psym = abs(psyms[0])
            XYOUTS, title_pos2b[0], title_pos2b[1], info.y2title, Color=dataColor2
            Oplot, [title_pos2a[0]], [title_pos2a[1]], Color=dataColor2, psym = abs(psyms[1])
          ENDELSE
        ENDIF

        WSet, info.drawIndex
        Plot, info.indep, info.dep, $
          XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
          YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
          Xtitle=info.xtitle, XMargin=info.xmargin, $
          XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
          Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
        OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]
;#
        IF n_elements(info.dep2) EQ n_elements(info.dep) THEN BEGIN
          IF (info.dbly EQ 1) THEN BEGIN
            Plot, info.indep, info.dep, $
              XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
              YRange=info.yrange, Ystyle=4, Xtitle=info.xtitle, Xmargin=[12.0,12.0], $
              XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
              Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
            axis, yaxis=0, yrange=[Min(info.dep),Max(info.dep)], ytitle=info.y1title, Color=dataColor, $
              Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
            OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]
            axis, yaxis=1, yrange=[Min(info.dep2),Max(info.dep2)], ytitle=info.y2title, Color=dataColor2, $
              Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
            OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
          ENDIF ELSE BEGIN
            OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
            XYOUTS, title_pos1b[0], title_pos1b[1],  info.y1title, Color=dataColor
            Oplot, [title_pos1a[0]], [title_pos1a[1]], Color=dataColor, psym = abs(psyms[0])
            XYOUTS, title_pos2b[0], title_pos2b[1], info.y2title, Color=dataColor2
            Oplot, [title_pos2a[0]], [title_pos2a[1]], Color=dataColor2, psym = abs(psyms[1])
          ENDELSE
        ENDIF

        ; Update the plot system variables.
        info.x = !X
        info.y = !Y
        info.p = !P

        Widget_Control, event.top, Set_UValue=info, /No_Copy
      ENDIF
    end


    else: BEGIN;#####End of altered code#####

   ; Update window sizes.

event.x = (event.x -    5 > 150) ; adjust for the top level base

IF (!d.name eq 'X') THEN $
  event.y = (event.y -  120 > 200) $ ; adjust for a part of STAT display area (Linux, etc.)
ELSE $ ; !d.name eq 'WIN'
  event.y = (event.y -  100 > 200) ; adjust for a part of STAT display area (Win)

info.zxsize = event.x
info.zysize = event.y

   ; Destroy old pixmap and create a new one.

WDelete, info.pixIndex
Window, XSize=event.x, YSize=event.y, /Free, /Pixmap
info.pixIndex = !D. Window

   ; Resize draw widget.

Widget_Control, info.drawID, Draw_XSize=(event.x > 200), Draw_YSize=(event.y > 150)

   ;  Set up colors for line plot.
   backColor = GetColor('charcoal', !D.Table_Size-2)
   dataColor = GetColor('yellow', !D.Table_Size-3)
   axisColor = GetColor('green', !D.Table_Size-4)
   ;#
   dataColor2 = GetColor('pink', !D.Table_Size-5)
   dataColor3 = GetColor('aqua', !D.Table_Size-6)
   dataColor4 = GetColor('magenta', !D.Table_Size-7)
   dataColor5 = GetColor('gray', !D.Table_Size-8)

   ;  Set up properties (line and symbol) of line plot.
   get_prop_plot, info, PSYMS=psyms

   ; Draw the plot in both windows.

Plot, info.indep, info.dep, $
  XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
  YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
  Xtitle=info.xtitle, XMargin=info.xmargin, $
  XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
  Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]

; Standard position of legends
title_pos1a = CONVERT_COORD([0.85, 0.90], /NORMAL, /TO_DATA)  ; for symbol
title_pos1b = CONVERT_COORD([0.86, 0.90], /NORMAL, /TO_DEVICE); for label string
title_pos1b = CONVERT_COORD(title_pos1b[0],title_pos1b[1]-5, /DEVICE, /TO_DATA)

title_pos2a = CONVERT_COORD([0.85, 0.85], /NORMAL, /TO_DATA)  ; for symbol
title_pos2b = CONVERT_COORD([0.86, 0.85], /NORMAL, /TO_DEVICE); for label string
title_pos2b = CONVERT_COORD(title_pos2b[0],title_pos2b[1]-5, /DEVICE, /TO_DATA)

title_pos3a = CONVERT_COORD([0.85, 0.80], /NORMAL, /TO_DATA)  ; for symbol
title_pos3b = CONVERT_COORD([0.86, 0.80], /NORMAL, /TO_DEVICE); for label string
title_pos3b = CONVERT_COORD(title_pos3b[0],title_pos3b[1]-5, /DEVICE, /TO_DATA)

title_pos4a = CONVERT_COORD([0.85, 0.75], /NORMAL, /TO_DATA)  ; for symbol
title_pos4b = CONVERT_COORD([0.86, 0.75], /NORMAL, /TO_DEVICE); for label string
title_pos4b = CONVERT_COORD(title_pos4b[0],title_pos4b[1]-5, /DEVICE, /TO_DATA)

title_pos5a = CONVERT_COORD([0.85, 0.70], /NORMAL, /TO_DATA)  ; for symbol
title_pos5b = CONVERT_COORD([0.86, 0.70], /NORMAL, /TO_DEVICE); for label string
title_pos5b = CONVERT_COORD(title_pos5b[0],title_pos5b[1]-5, /DEVICE, /TO_DATA)

;#
IF n_elements(info.dep2) EQ n_elements(info.dep) THEN BEGIN
  IF (info.dbly EQ 1) THEN BEGIN
    Plot, info.indep, info.dep, $
      XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
      YRange=info.yrange, Ystyle=4, Xtitle=info.xtitle, Xmargin=[12.0,12.0], $
      XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
      Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
    axis, yaxis=0, yrange=[Min(info.dep),Max(info.dep)], ytitle=info.y1title, Color=dataColor, $
      Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
    OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]
    axis, yaxis=1, yrange=[Min(info.dep2),Max(info.dep2)], ytitle=info.y2title, Color=dataColor2, $
      Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
    OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
  ENDIF ELSE BEGIN
    OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
    XYOUTS, title_pos1b[0], title_pos1b[1],  info.y1title, Color=dataColor
    Oplot, [title_pos1a[0]], [title_pos1a[1]], Color=dataColor, psym = abs(psyms[0])
    XYOUTS, title_pos2b[0], title_pos2b[1], info.y2title, Color=dataColor2
    Oplot, [title_pos2a[0]], [title_pos2a[1]], Color=dataColor2, psym = abs(psyms[1])
  ENDELSE
ENDIF
IF n_elements(info.dep3) EQ n_elements(info.dep) THEN BEGIN
    OPlot, info.indep, info.dep3, Color=dataColor3, psym = psyms[2]
    XYOUTS, title_pos3b[0], title_pos3b[1], info.y3title, Color=dataColor3
    Oplot, [title_pos3a[0]], [title_pos3a[1]], Color=dataColor3, psym = abs(psyms[2])
ENDIF
IF n_elements(info.dep4) EQ n_elements(info.dep) THEN BEGIN
    OPlot, info.indep, info.dep4, Color=dataColor4, psym = psyms[3]
    XYOUTS, title_pos4b[0], title_pos4b[1], info.y4title, Color=dataColor4
    Oplot, [title_pos4a[0]], [title_pos4a[1]], Color=dataColor4, psym = abs(psyms[3])
ENDIF
IF n_elements(info.dep5) EQ n_elements(info.dep) THEN BEGIN
    OPlot, info.indep, info.dep5, Color=dataColor5, psym = psyms[4]
    XYOUTS, title_pos5b[0], title_pos5b[1], info.y5title, Color=dataColor5
    Oplot, [title_pos5a[0]], [title_pos5a[1]], Color=dataColor5, psym = abs(psyms[4])
ENDIF

WSet, info.drawIndex
Plot, info.indep, info.dep, $
  XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
  YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
  Xtitle=info.xtitle, XMargin=info.xmargin, $
  XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
  Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]

;#
IF n_elements(info.dep2) EQ n_elements(info.dep) THEN BEGIN
  IF (info.dbly EQ 1) THEN BEGIN
    Plot, info.indep, info.dep, $
      XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
      YRange=info.yrange, Ystyle=4, Xtitle=info.xtitle, Xmargin=[12.0,12.0], $
      XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
      Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
    axis, yaxis=0, yrange=[Min(info.dep),Max(info.dep)], ytitle=info.y1title, Color=dataColor, $
      Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
    OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]
    axis, yaxis=1, yrange=[Min(info.dep2),Max(info.dep2)], ytitle=info.y2title, Color=dataColor2, $
      Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
    OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
  ENDIF ELSE BEGIN
    OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
    XYOUTS, title_pos1b[0], title_pos1b[1],  info.y1title, Color=dataColor
    Oplot, [title_pos1a[0]], [title_pos1a[1]], Color=dataColor, psym = abs(psyms[0])
    XYOUTS, title_pos2b[0], title_pos2b[1], info.y2title, Color=dataColor2
    Oplot, [title_pos2a[0]], [title_pos2a[1]], Color=dataColor2, psym = abs(psyms[1])
  ENDELSE
ENDIF
IF n_elements(info.dep3) EQ n_elements(info.dep) THEN BEGIN
    OPlot, info.indep, info.dep3, Color=dataColor3, psym = psyms[2]
    XYOUTS, title_pos3b[0], title_pos3b[1], info.y3title, Color=dataColor3
    Oplot, [title_pos3a[0]], [title_pos3a[1]], Color=dataColor3, psym = abs(psyms[2])
ENDIF
IF n_elements(info.dep4) EQ n_elements(info.dep) THEN BEGIN
    OPlot, info.indep, info.dep4, Color=dataColor4, psym = psyms[3]
    XYOUTS, title_pos4b[0], title_pos4b[1], info.y4title, Color=dataColor4
    Oplot, [title_pos4a[0]], [title_pos4a[1]], Color=dataColor4, psym = abs(psyms[3])
ENDIF
IF n_elements(info.dep5) EQ n_elements(info.dep) THEN BEGIN
    OPlot, info.indep, info.dep5, Color=dataColor5, psym = psyms[4]
    XYOUTS, title_pos5b[0], title_pos5b[1], info.y5title, Color=dataColor5
    Oplot, [title_pos5a[0]], [title_pos5a[1]], Color=dataColor5, psym = abs(psyms[4])
ENDIF

   ; Update system parameters.

info.x = !X
info.y = !Y
info.p = !P

Widget_Control, event.top, Set_UValue=info, /No_Copy

    end
  endcase

END ; of zZPLOT_RESIZE **********************************************************


PRO zZPLOT_PROCESS_EVENTS, event

   ; This event handler ONLY responds to button down events from the
   ; draw widget. If it gets a DOWN event, it does three things: (1) sets
   ; the static and dynamic corners of the arrow box, (2) changes the
   ; event handler for the draw widget to ZPLOT_DRAWBOX and turns on MOTION
   ; events, and (3) update the user's color table vectors.

On_Error, 2

possibleEventTypes = [ 'DOWN', 'UP', 'MOTION', 'SCROLL' ]
thisEvent = possibleEventTypes(event.type)
IF thisEvent NE 'DOWN' THEN RETURN

    ; Must be DOWN event to get here, so get info structure.

 Widget_Control, event.top, Get_UValue=info, /No_Copy

    ; Set the static corners of the arrow box to current
    ; cursor location.

 info.xs = event.x
 info.ys = event.y

    ; Change the event handler for the draw widget and turn MOTION
    ; events ON.

 Widget_Control, event.id, Event_Pro='zZPLOT_DRAWBOX', $
    Draw_Motion_Events=1

   ; Put the info structure back into its storage location.

Widget_Control, event.top, Set_UValue=info, /No_Copy
END ; of zZPLOT_PROCESS_EVENTS *****************************************************



PRO zZPLOT_DRAWBOX, event

   ; This event handler continuously draws and erases the arrow box until it
   ; receives an UP event from the draw widget. Then it turns draw widget motion
   ; events OFF and changes the event handler for the draw widget back to
   ; ZPLOT_PROCESS_EVENTS.

   ; Get the info structure out of the top-level base.

Widget_Control, event.top, Get_UValue=info, /No_Copy

   ;  Set up colors for line plot.
   backColor = GetColor('charcoal', !D.Table_Size-2)
   dataColor = GetColor('yellow', !D.Table_Size-3)
   axisColor = GetColor('green', !D.Table_Size-4)
   boxColor = GetColor('beige', !D.Table_Size-5)
   ;#
   dataColor2 = GetColor('pink', !D.Table_Size-6)
   dataColor3 = GetColor('aqua', !D.Table_Size-7)
   dataColor4 = GetColor('magenta', !D.Table_Size-8)
   dataColor5 = GetColor('gray', !D.Table_Size-9)

   ;  Set up properties (line and symbol) of line plot.
   get_prop_plot, info, PSYMS=psyms

   ; What type of an event is this?

possibleEventTypes = [ 'DOWN', 'UP', 'MOTION', 'SCROLL' ]
thisEvent = possibleEventTypes(event.type)

IF thisEvent EQ 'UP' THEN BEGIN

      ; If this is an UP event, you need to erase the zoombox, restore
      ; the user's color table, turn motion events OFF, set the
      ; draw widget's event handler back to ZPLOT_PROCESS_EVENTS, and
      ; draw the "zoomed" plot in both the draw widget and the pixmap.

      ; Erase the arrow box one final time by copying the plot from the pixmap.

   WSet, info.drawIndex
   Device, Copy = [0, 0, info.zxsize, info.zysize, 0, 0, info.pixIndex]

      ; Turn motion events off and redirect the events to ZPLOT_PROCESS_EVENTS.

    Widget_Control, event.id, Draw_Motion_Events=0, $
       Event_Pro='zZPLOT_PROCESS_EVENTS'

      ; Draw the "zoomed" plot. Start by getting the new limits to the plot
      ; (i.e., the LAST zoom box outline).

   x = [info.xs, event.x]
   y = [info.ys, event.y]

;#
   ; Make sure the x values are ordered as [min, max].
   IF info.xs GT event.x THEN x = [event.x, info.xs]

   ; Don't want exact style if we are drawing entire plot.
   ;IF info.xs EQ event.x THEN xstyle = 0 ELSE xstyle = 1
   ;info.xstyle = xstyle

;#
   ; Make sure the y values are ordered as [min, max].
   IF info.ys GT event.y THEN y = [event.y, info.ys]

   ; Don't want exact style if we are drawing entire plot.
   ;IF info.ys EQ event.y THEN ystyle = 0 ELSE ystyle = 1
   ;info.ystyle = ystyle


   ; Restore plot system variables.
   !X = info.x
   !Y = info.y
   !P = info.p


   ; Convert the x device coordinates to data coordinates.
   coords = Convert_Coord(x, y, /Device, /To_Data)

;   ; Make sure the x coordinates are within the data boundaries of the plot.
;   IF info.xlog THEN BEGIN
;      x1 = 10^!X.CRange(0) > coords(0,0) < 10^!X.CRange(1)
;      x2 = 10^!X.CRange(0) > coords(0,1) < 10^!X.CRange(1)
;   ENDIF ELSE BEGIN
;      x1 = !X.CRange(0) > coords(0,0) < !X.CRange(1)
;      x2 = !X.CRange(0) > coords(0,1) < !X.CRange(1)
;   ENDELSE
   x1 = coords(0,0)
   x2 = coords(0,1)

   ;#####altered code#####
;   ; Make sure the y coordinates are within the data boundaries of the plot.
;   IF info.ylog THEN BEGIN
;      y1 = 10^!Y.CRange(0) > coords(1,0) < 10^!Y.CRange(1)
;      y2 = 10^!Y.CRange(0) > coords(1,1) < 10^!Y.CRange(1)
;   ENDIF ELSE BEGIN
;      y1 = !Y.CRange(0) > coords(1,0) < !Y.CRange(1)
;      y2 = !Y.CRange(0) > coords(1,1) < !Y.CRange(1)
;   ENDELSE
   y1 = coords(1,0)
   y2 = coords(1,1)


   ; ## Set new ranges ##
   IF ((x1 NE x2) and (y1 NE y2)) THEN BEGIN
     info.xrange = [x1,x2]
     info.yrange = [y1,y2]
     info.xstyle=1
     info.ystyle=1
   ; When click without drag, does not change the ranges.
   ; But, print out the coordinates of the point.
   ENDIF ELSE BEGIN
     print, 'X:', x1, ',   Y:', y1
   ENDELSE

   ; ## Context menu event ##
   IF (event.RELEASE EQ 4) THEN BEGIN
     ; Obtain the widget ID of the context menu base.
     contextBase = WIDGET_INFO(event.TOP, FIND_BY_UNAME = 'drawContext')
     ; Display the context menu.
     WIDGET_DISPLAYCONTEXTMENU, event.ID, event.X, event.Y, contextBase
   ENDIF

   ; Back to the initial ranges
;   IF ((x1 EQ x2) or (y1 EQ y2)) THEN BEGIN
;     info.xrange = info.xrange_def
;     info.yrange = info.yrange_def
;   ENDIF
   ;######################


      ; Draw the "zoomed" plot in both the draw widget and the pixmap.

   Plot, info.indep, info.dep, $
     XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
     YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
     Xtitle=info.xtitle, XMargin=info.xmargin, $
     XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
     Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
   OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]

    ; Standard position of legends
   title_pos1a = CONVERT_COORD([0.85, 0.90], /NORMAL, /TO_DATA)  ; for symbol
   title_pos1b = CONVERT_COORD([0.86, 0.90], /NORMAL, /TO_DEVICE); for label string
   title_pos1b = CONVERT_COORD(title_pos1b[0],title_pos1b[1]-5, /DEVICE, /TO_DATA)

   title_pos2a = CONVERT_COORD([0.85, 0.85], /NORMAL, /TO_DATA)  ; for symbol
   title_pos2b = CONVERT_COORD([0.86, 0.85], /NORMAL, /TO_DEVICE); for label string
   title_pos2b = CONVERT_COORD(title_pos2b[0],title_pos2b[1]-5, /DEVICE, /TO_DATA)

   title_pos3a = CONVERT_COORD([0.85, 0.80], /NORMAL, /TO_DATA)  ; for symbol
   title_pos3b = CONVERT_COORD([0.86, 0.80], /NORMAL, /TO_DEVICE); for label string
   title_pos3b = CONVERT_COORD(title_pos3b[0],title_pos3b[1]-5, /DEVICE, /TO_DATA)

   title_pos4a = CONVERT_COORD([0.85, 0.75], /NORMAL, /TO_DATA)  ; for symbol
   title_pos4b = CONVERT_COORD([0.86, 0.75], /NORMAL, /TO_DEVICE); for label string
   title_pos4b = CONVERT_COORD(title_pos4b[0],title_pos4b[1]-5, /DEVICE, /TO_DATA)

   title_pos5a = CONVERT_COORD([0.85, 0.70], /NORMAL, /TO_DATA)  ; for symbol
   title_pos5b = CONVERT_COORD([0.86, 0.70], /NORMAL, /TO_DEVICE); for label string
   title_pos5b = CONVERT_COORD(title_pos5b[0],title_pos5b[1]-5, /DEVICE, /TO_DATA)

;#
   IF n_elements(info.dep2) EQ n_elements(info.dep) THEN BEGIN
     IF (info.dbly EQ 1) THEN BEGIN
       Plot, info.indep, info.dep, $
         XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
         YRange=info.yrange, Ystyle=4, Xtitle=info.xtitle, Xmargin=[12.0,12.0], $
         XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
         Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
       axis, yaxis=0, yrange=[Min(info.dep),Max(info.dep)], ytitle=info.y1title, Color=dataColor, $
         Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
       OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]
       axis, yaxis=1, yrange=[Min(info.dep2),Max(info.dep2)], ytitle=info.y2title, Color=dataColor2, $
         Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
       OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
     ENDIF ELSE BEGIN
       OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
       XYOUTS, title_pos1b[0], title_pos1b[1],  info.y1title, Color=dataColor
       Oplot, [title_pos1a[0]], [title_pos1a[1]], Color=dataColor, psym = abs(psyms[0])
       XYOUTS, title_pos2b[0], title_pos2b[1], info.y2title, Color=dataColor2
       Oplot, [title_pos2a[0]], [title_pos2a[1]], Color=dataColor2, psym = abs(psyms[1])
     ENDELSE
   ENDIF
   IF n_elements(info.dep3) EQ n_elements(info.dep) THEN BEGIN
       OPlot, info.indep, info.dep3, Color=dataColor3, psym = psyms[2]
       XYOUTS, title_pos3b[0], title_pos3b[1], info.y3title, Color=dataColor3
       Oplot, [title_pos3a[0]], [title_pos3a[1]], Color=dataColor3, psym = abs(psyms[2])
   ENDIF
   IF n_elements(info.dep4) EQ n_elements(info.dep) THEN BEGIN
       OPlot, info.indep, info.dep4, Color=dataColor4, psym = psyms[3]
       XYOUTS, title_pos4b[0], title_pos4b[1], info.y4title, Color=dataColor4
       Oplot, [title_pos4a[0]], [title_pos4a[1]], Color=dataColor4, psym = abs(psyms[3])
   ENDIF
   IF n_elements(info.dep5) EQ n_elements(info.dep) THEN BEGIN
       OPlot, info.indep, info.dep5, Color=dataColor5, psym = psyms[4]
       XYOUTS, title_pos5b[0], title_pos5b[1], info.y5title, Color=dataColor5
       Oplot, [title_pos5a[0]], [title_pos5a[1]], Color=dataColor5, psym = abs(psyms[4])
   ENDIF

   WSet, info.pixIndex
   Plot, info.indep, info.dep, $
     XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
     YRange=info.yrange, YStyle=info.ystyle, Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, $
     Xtitle=info.xtitle, XMargin=info.xmargin, $
     XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
     Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
   OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]

;#
   IF n_elements(info.dep2) EQ n_elements(info.dep) THEN BEGIN
     IF (info.dbly EQ 1) THEN BEGIN
       Plot, info.indep, info.dep, $
         XRange=info.xrange, XStyle=info.xstyle, Xticklen=info.ticklen, Xgridstyle=(info.ticklen NE 0.02) ? 1:0, $
         YRange=info.yrange, Ystyle=4, Xtitle=info.xtitle, Xmargin=[12.0,12.0], $
         XLog=info.xlog, YLog=info.ylog, XTickFormat=info.xtickformat, YTickFormat=info.ytickformat, $
         Background=backColor, Color=axisColor, /NoData, _Extra=*info.extraKeywords
       axis, yaxis=0, yrange=[Min(info.dep),Max(info.dep)], ytitle=info.y1title, Color=dataColor, $
         Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
       OPlot, info.indep, info.dep, Color=dataColor, psym = psyms[0]
       axis, yaxis=1, yrange=[Min(info.dep2),Max(info.dep2)], ytitle=info.y2title, Color=dataColor2, $
         Yticklen=info.ticklen, Ygridstyle=(info.ticklen NE 0.02) ? 1:0, /save
       OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
     ENDIF ELSE BEGIN
       OPlot, info.indep, info.dep2, Color=dataColor2, psym = psyms[1]
       XYOUTS, title_pos1b[0], title_pos1b[1],  info.y1title, Color=dataColor
       Oplot, [title_pos1a[0]], [title_pos1a[1]], Color=dataColor, psym = abs(psyms[0])
       XYOUTS, title_pos2b[0], title_pos2b[1], info.y2title, Color=dataColor2
       Oplot, [title_pos2a[0]], [title_pos2a[1]], Color=dataColor2, psym = abs(psyms[1])
     ENDELSE
   ENDIF
   IF n_elements(info.dep3) EQ n_elements(info.dep) THEN BEGIN
       OPlot, info.indep, info.dep3, Color=dataColor3, psym = psyms[2]
       XYOUTS, title_pos3b[0], title_pos3b[1], info.y3title, Color=dataColor3
       Oplot, [title_pos3a[0]], [title_pos3a[1]], Color=dataColor3, psym = abs(psyms[2])
   ENDIF
   IF n_elements(info.dep4) EQ n_elements(info.dep) THEN BEGIN
       OPlot, info.indep, info.dep4, Color=dataColor4, psym = psyms[3]
       XYOUTS, title_pos4b[0], title_pos4b[1], info.y4title, Color=dataColor4
       Oplot, [title_pos4a[0]], [title_pos4a[1]], Color=dataColor4, psym = abs(psyms[3])
   ENDIF
   IF n_elements(info.dep5) EQ n_elements(info.dep) THEN BEGIN
       OPlot, info.indep, info.dep5, Color=dataColor5, psym = psyms[4]
       XYOUTS, title_pos5b[0], title_pos5b[1], info.y5title, Color=dataColor5
       Oplot, [title_pos5a[0]], [title_pos5a[1]], Color=dataColor5, psym = abs(psyms[4])
   ENDIF

      ; Update the plot system variables.

   info.x = !X
   info.y = !Y
   info.p = !P

      ; Put the info structure back into its storage location and then, out of here!

   Widget_Control, event.top, Set_UValue=info, /No_Copy
   RETURN
ENDIF ; thisEvent = UP


   ; Most of the action in this event handler occurs here while we are waiting
   ; for an UP event to occur. As long as we don't get it, keep erasing the
   ; old zoom box and drawing a new one.

   ; Erase the old zoom box.

WSet, info.drawIndex
Device, Copy = [0, 0, info.zxsize, info.zysize, 0, 0, info.pixIndex]

   ; Update the dynamic corner of the zoom box to the current cursor location.

 info.xd = event.x
 info.yd = event.y

   ; Restore plot system variables.

!X = info.x
!Y = info.y
!P = info.p

   ; Convert the x device coordinates to data coordinates.

x = [info.xs, event.x]
y = [info.ys, event.y]
coords = Convert_Coord(x, y, /Device, /To_Data)

;; Make sure the x coordinates are within the data boundaries of the plot.
;IF info.xlog THEN BEGIN
;   x1 = 10^!X.CRange(0) > coords(0,0) < 10^!X.CRange(1)
;   x2 = 10^!X.CRange(0) > coords(0,1) < 10^!X.CRange(1)
;ENDIF ELSE BEGIN
;   x1 = !X.CRange(0) > coords(0,0) < !X.CRange(1)
;   x2 = !X.CRange(0) > coords(0,1) < !X.CRange(1)
;ENDELSE

;; Make sure the y coordinates are within the data boundaries of the plot.
;IF info.ylog THEN BEGIN
;   y1 = 10^!Y.CRange(0) > coords(1,0) < 10^!Y.CRange(1)
;   y2 = 10^!Y.CRange(0) > coords(1,1) < 10^!Y.CRange(1)
;ENDIF ELSE BEGIN
;   y1 = !Y.CRange(0) > coords(1,0) < !Y.CRange(1)
;   y2 = !Y.CRange(0) > coords(1,1) < !Y.CRange(1)
;ENDELSE
x1 = coords(0,0)
x2 = coords(0,1)
y1 = coords(1,0)
y2 = coords(1,1)

   ; Draw the arrow box.
IF info.dbly EQ 1 THEN $
   Arrow, x1, y1, x2, y1, /Data, Color=boxColor, /Solid, HSize=12 $
ELSE $
   Arrow, x1, y1, x2, y2, /Data, Color=boxColor, /Solid, HSize=12

IF info.ylog THEN BEGIN
  IF info.dbly EQ 1 THEN BEGIN
   PlotS, [x1, x1], [10^!Y.CRange[0], 10^!Y.CRange[1]], Color=boxColor
   PlotS, [x2, x2], [10^!Y.CRange[0], 10^!Y.CRange[1]], Color=boxColor
   PlotS, [x1, x2], [10^!Y.CRange[0], 10^!Y.CRange[0]], Color=boxColor
   PlotS, [x1, x2], [10^!Y.CRange[1], 10^!Y.CRange[1]], Color=boxColor
  ENDIF ELSE BEGIN
   PlotS, [x1, x1], [y1, y2], Color=boxColor
   PlotS, [x2, x2], [y1, y2], Color=boxColor
   PlotS, [x1, x2], [y1, y1], Color=boxColor
   PlotS, [x1, x2], [y2, y2], Color=boxColor
  ENDELSE
ENDIF ELSE BEGIN
  IF info.dbly EQ 1 THEN BEGIN
   PlotS, [x1, x1], [!Y.CRange[0], !Y.CRange[1]], Color=boxColor
   PlotS, [x2, x2], [!Y.CRange[0], !Y.CRange[1]], Color=boxColor
   PlotS, [x1, x2], [!Y.CRange[0], !Y.CRange[0]], Color=boxColor
   PlotS, [x1, x2], [!Y.CRange[1], !Y.CRange[1]], Color=boxColor
  ENDIF ELSE BEGIN
   PlotS, [x1, x1], [y1, y2], Color=boxColor
   PlotS, [x2, x2], [y1, y2], Color=boxColor
   PlotS, [x1, x2], [y1, y1], Color=boxColor
   PlotS, [x1, x2], [y2, y2], Color=boxColor
  ENDELSE
ENDELSE

   ; Put the info structure back into its storage location.

Widget_Control, event.top, Set_UValue=info, /No_Copy
END ; of zZPLOT_DRAWBOX ******************************************************************



PRO ZPLOT_ALT, x, y, Y2DATA=y2, Y3DATA=y3, Y4DATA=y4, Y5DATA=y5, $
   Y1TITLE=y1title, Y2TITLE=y2title, Y3TITLE=y3title, Y4TITLE=y4title, Y5TITLE=y5title, $
   XTitle=xtitle, $
   Zoom_XSize=zxsize, Zoom_YSize=zysize, XRANGE=xrange, XMargin=xmargin, $
   Group_Leader=group, XLog=xlog, YLog=ylog, PSYM=psym, FILENAME=filename, EXTBTN_MODE=extbtn_mode, $
   XOffset=xoffset, YOffset=yoffset, TickLen=ticklen, XTickFormat=xtickformat, YTickFormat=ytickformat, $
   X_Range2=x_range2, Y_Range2=y_range2, $ ; Used when this zplot_alt was called from another zplot_alt.)
   Xstyle=xstyle, Ystyle=ystyle, $
   _Extra=extra

COMMON TOP_WID_ID, rootID ; for Separate Flag Button
IF (n_elements(group) NE 0) THEN rootID = group

   ; This procedure allows the user to "zoom" into the data plot
   ; by drawing an arrow box around the part of the data to zoom into.
   ; The arrow box will be drawn and erased by using a pixmap and
   ; the "Device Copy" technique.

   ; On an error condition, return to the main level of IDL.

On_Error, 1

   ; Was data passed into the procedure? If not, create some.

CASE N_Params() OF

   0: BEGIN
   dep = Findgen(101)
   dep = Sin(dep/5) / Exp(dep/50)
   indep = Findgen(101)
   ENDCASE

   1: BEGIN
   dep = x
   indep = Findgen(N_Elements(dep))
   ENDCASE

   2: BEGIN
   dep = y
   indep = x
   ENDCASE

ENDCASE

;;  Set up colors for line plot.
backColor = GetColor('charcoal', !D.Table_Size-2)
dataColor = GetColor('yellow', !D.Table_Size-3)
axisColor = GetColor('green', !D.Table_Size-4)
;#
dataColor2 = GetColor('pink', !D.Table_Size-5)
dataColor3 = GetColor('aqua', !D.Table_Size-6)
dataColor4 = GetColor('magenta', !D.Table_Size-7)
dataColor5 = GetColor('gray', !D.Table_Size-8)

;;===============================================
;; Check for keywords. Set defaults if necessary.
;;===============================================
IF N_Elements(zxsize) EQ 0 THEN zxsize = 400
IF N_Elements(zysize) EQ 0 THEN zysize = 400
xlog = Keyword_Set(xlog)
ylog = Keyword_Set(ylog)
;#
IF N_Elements(y2) EQ 0 THEN y2 = mean(dep)
IF N_Elements(y3) EQ 0 THEN y3 = mean(dep)
IF N_Elements(y4) EQ 0 THEN y4 = mean(dep)
IF N_Elements(y5) EQ 0 THEN y5 = mean(dep)
IF N_Elements(y1title) EQ 0 THEN y1title='Data1'
IF N_Elements(y2title) EQ 0 THEN y2title='Data2'
IF N_Elements(y3title) EQ 0 THEN y3title='Data3'
IF N_Elements(y4title) EQ 0 THEN y4title='Data4'
IF N_Elements(y5title) EQ 0 THEN y5title='Data5'
IF N_Elements(xtitle)  EQ 0 THEN xtitle=''

IF N_Elements(xoffset) EQ 0 THEN xoffset=0.0
IF N_Elements(yoffset) EQ 0 THEN yoffset=0.0

IF N_Elements(ticklen) EQ 0 THEN ticklen=0.02
IF N_Elements(xtickformat) EQ 0 THEN xtickformat=''
IF N_Elements(ytickformat) EQ 0 THEN ytickformat=''
IF N_Elements(Xstyle) EQ 0 THEN xstyle=0
IF N_Elements(Ystyle) EQ 0 THEN ystyle=0

IF (Keyword_Set(psym) NE 1) THEN psym=0
line = 1 ; initialize as default
IF (Keyword_Set(filename) NE 1) THEN filename=''
IF (Keyword_Set(extbtn_mode) NE 1) THEN extbtn_mode=0 ; If extbtn_mode=1 then display extra buttons
;;===============================================

;;## Create a top-level base for this program. No resizing of this base.
tlb = Widget_Base(Title='FISv Plot Window: '+filename, TLB_Size_Events=1, column=1, UNAME='PlotWin', $
                  XOffset=xoffset, YOffset=yoffset)

;;## Draw widget will have its own event handler.
drawID = Widget_Draw(tlb, XSize=zxsize, YSize=zysize, $
   Button_Events=1, Event_Pro='zZPLOT_PROCESS_EVENTS')


;;===============================================
;; Start of making control button base
;;===============================================
; Create buttons
ctrlbase = Widget_Base(tlb, column=1)

DispBtnbase = Widget_Base(ctrlbase, row=1, /frame, xpad=0, ypad=0)

  chkecbox_base = Widget_Base(DispBtnbase, row=1, /NONEXCLUSIVE)
    SymbBtn = Widget_Button(chkecbox_base, VALUE='Symbol', UNAME='SymbBtn', Tooltip='Symbol On/Off')
    IF (psym EQ 0) THEN Widget_Control, SymbBtn, SET_BUTTON=0 ELSE Widget_Control, SymbBtn, /SET_BUTTON

    IF (extbtn_mode EQ 1) THEN BEGIN
      sybm_status = Widget_Info(SymbBtn, /BUTTON_SET)
      LineBtn = Widget_Button(chkecbox_base, VALUE='Line', UNAME='LineBtn', Tooltip='Line On/Off', $
                              Sensitive=sybm_status)
      Widget_Control, LineBtn, /SET_BUTTON
    ENDIF

    GridBtn = Widget_Button(chkecbox_base, VALUE='Grid', UNAME='GridBtn', Tooltip='Grid On/Off')
    IF (ticklen EQ 0.02) THEN Widget_Control, GridBtn, SET_BUTTON=0 ELSE Widget_Control, GridBtn, /SET_BUTTON

    dbly=0
    IF (n_elements(y2) EQ n_elements(indep)) and (n_elements([y3,y4,y5]) EQ 3) THEN BEGIN
      DblYBtn = Widget_Button(chkecbox_base, VALUE='Double Y', UNAME='DblYBtn', Tooltip='Double Y-axis On/Off')
    ENDIF

  btn1base = Widget_Base(DispBtnbase, row=1)
    ResetBtn = Widget_Button(btn1base, xsize=40, value='Reset', uname='ResetBtn', Tooltip='Reset range')
    ASBtn = Widget_Button(btn1base, xsize=40, value='Auto', uname='ASBtn', Tooltip='Auto Scale')

    ZinBtn = Widget_Button(btn1base, xsize=30, value='ZoomIn.bmp', /bitmap, uname='ZinBtn', Tooltip='Zoom in')
    ZoutBtn = Widget_Button(btn1base, xsize=30, value='ZoomOut.bmp', /bitmap, uname='ZoutBtn', Tooltip='Zoom Out')

    IF (extbtn_mode EQ 1) THEN BEGIN
      xZinBtn = Widget_Button(btn1base, xsize=30, value='x+.bmp', /bitmap, uname='xZinBtn', Tooltip='X-axis Zoom in')
      xZoutBtn = Widget_Button(btn1base, xsize=30, value='x-.bmp', /bitmap, uname='xZoutBtn', Tooltip='X-axis Zoom Out')
      yZinBtn = Widget_Button(btn1base, xsize=30, value='y+.bmp', /bitmap, uname='yZinBtn', Tooltip='Y-axis Zoom in')
      yZoutBtn = Widget_Button(btn1base, xsize=30, value='y-.bmp', /bitmap, uname='yZoutBtn', Tooltip='Y-axis Zoom Out')
    ENDIF

    ScrLBtn = Widget_Button(btn1base, xsize=25, value='left_arr.bmp', /bitmap, uname='ScrLBtn', Tooltip='Scroll to Left')
    ScrRBtn = Widget_Button(btn1base, xsize=25, value='right_arr.bmp', /bitmap, uname='ScrRBtn', Tooltip='Scroll to Right')

    IF (extbtn_mode EQ 1) THEN BEGIN
      ScrUBtn = Widget_Button(btn1base, xsize=25, value='up_arr.bmp', /bitmap, uname='ScrUBtn', Tooltip='Scroll Up')
      ScrDBtn = Widget_Button(btn1base, xsize=25, value='down_arr.bmp', /bitmap, uname='ScrDBtn', Tooltip='Scroll Down')
    ENDIF

    IF (extbtn_mode EQ 0) THEN BEGIN
      ExtBtn = Widget_Button(btn1base, xsize=17, value='>>', uname='ExtBtn', Tooltip='Extra Mode')
    ENDIF ELSE BEGIN
      ExtBtn = Widget_Button(btn1base, xsize=17, value='<<', uname='ExtBtn', Tooltip='Simple Mode')
    ENDELSE

buttbase = Widget_Base(ctrlbase, /frame, row=1)
  PrintBtn = Widget_Button(buttbase, xsize=45, value='Print', uname='PrintBtn', Tooltip='Print Out')
  PSBtn = Widget_Button(buttbase, value='PS', xsize=45, uname='PSBtn', Tooltip='Save as a PostScript file')
  StatBtn = Widget_Button(buttbase, value='STAT', xsize=45, uname='StatBtn', Tooltip='Calculate statistics')
  DiffBtn = Widget_Button(buttbase, value='DIFF', xsize=45, uname='DiffBtn', Tooltip='Calculate Differentiation')

  ; If the called zplot_alt is used with TSD object.
  ; (Diff and FFT buttons can be used only when zplot_alt was called from FISv.)
  COMMON Share, tsd
  IF OBJ_VALID(tsd) EQ 1 THEN BEGIN
    SFlagBtn = Widget_Button(buttbase, value='SFlag', xsize=45, uname='SFlagBtn', Tooltip='Separate flags and other data')
    FFTBtn = Widget_Button(buttbase, value='FFT', xsize=45, uname='FFTBtn', Tooltip='FFT')
  ENDIF

buttbase2 = Widget_Base(ctrlbase, row=1)
  ClsBtn = Widget_Button(buttbase2, value='Close', xsize=70, uname='ClsBtn', Tooltip='Colse window')
;;===============================================
;; End of making control button base
;;===============================================


;;===============================================
;; Start of making context menu
;;===============================================
  ; Create the base for the context menu.
  contextBase = WIDGET_BASE(tlb, /CONTEXT_MENU, UNAME = 'drawContext')

  ; Create the buttons for the context menu.
  HexButton = WIDGET_BUTTON(contextBase, VALUE = 'Y-axis in HEX', $
    EVENT_PRO = 'HexEvent')
  ThermoButton = WIDGET_BUTTON(contextBase, VALUE = 'Temperature in Kelvin scale (Y-axis)', $
    EVENT_PRO = 'ThermoEvent')
  xAFtimeButton = WIDGET_BUTTON(contextBase, VALUE = 'AFtime to Date and Time (X-axis)', $
    EVENT_PRO = 'xAFtimeEvent')
  xTicksButton = WIDGET_BUTTON(contextBase, VALUE = 'XTicks = 3', $
    /SEPARATOR, EVENT_PRO = 'xTicksEvent')
;;===============================================
;; End of making context menu
;;===============================================

; Realize the program.
Widget_Control, tlb, /Realize

   ; Get the window index number of the draw widget.
   ; Make the draw widget the current graphics window
   ; and draw the plot of the data in it. Make the
   ; X data range exactly fit the data.

Widget_Control, drawID, Get_Value=drawIndex
WSet, drawIndex
IF N_Elements(xrange) EQ 0 THEN $
  xrange = [Min(indep), Max(indep)]
yrange = [Min([min(dep),min(y2),min(y3),min(y4),min(y5)]) $
           ,Max([max(dep),max(y2),max(y3),max(y4),max(y5)])]
xrange_def = xrange
yrange_def = yrange
y2range = [Min(y2),Max(y2)]
IF (N_Elements(xmargin) EQ 0) THEN xmargin=[10.0, 3.0]

;; When this zplot_alt was called from another zplot_alt.
;;   (i.e. ExtBtn mode, HEX in Yaxis, etc.)
IF N_Elements(x_range2) NE 0 THEN xrange=x_range2
IF N_Elements(y_range2) NE 0 THEN yrange=y_range2


Plot, indep, dep, XRange=xrange, YRange=yrange, XMargin=xmargin, XLog=xlog, YLog=ylog, $
    Xticklen=ticklen, Xgridstyle=(ticklen NE 0.02) ? 1:0, Yticklen=ticklen, Ygridstyle=(ticklen NE 0.02) ? 1:0, $
    Xtitle=xtitle, XTickFormat=xtickformat, YTickFormat=ytickformat, Xstyle=xstyle, Ystyle=ystyle, $
    Background=backColor, Color=axisColor, /NoData, _Extra=extra
OPlot, indep, dep, Color=dataColor, psym=psym

; Standard position of legends
title_pos1a = CONVERT_COORD([0.85, 0.90], /NORMAL, /TO_DATA)  ; for symbol
title_pos1b = CONVERT_COORD([0.86, 0.90], /NORMAL, /TO_DEVICE); for label string
title_pos1b = CONVERT_COORD(title_pos1b[0],title_pos1b[1]-5, /DEVICE, /TO_DATA)

title_pos2a = CONVERT_COORD([0.85, 0.85], /NORMAL, /TO_DATA)  ; for symbol
title_pos2b = CONVERT_COORD([0.86, 0.85], /NORMAL, /TO_DEVICE); for label string
title_pos2b = CONVERT_COORD(title_pos2b[0],title_pos2b[1]-5, /DEVICE, /TO_DATA)

title_pos3a = CONVERT_COORD([0.85, 0.80], /NORMAL, /TO_DATA)  ; for symbol
title_pos3b = CONVERT_COORD([0.86, 0.80], /NORMAL, /TO_DEVICE); for label string
title_pos3b = CONVERT_COORD(title_pos3b[0],title_pos3b[1]-5, /DEVICE, /TO_DATA)

title_pos4a = CONVERT_COORD([0.85, 0.75], /NORMAL, /TO_DATA)  ; for symbol
title_pos4b = CONVERT_COORD([0.86, 0.75], /NORMAL, /TO_DEVICE); for label string
title_pos4b = CONVERT_COORD(title_pos4b[0],title_pos4b[1]-5, /DEVICE, /TO_DATA)

title_pos5a = CONVERT_COORD([0.85, 0.70], /NORMAL, /TO_DATA)  ; for symbol
title_pos5b = CONVERT_COORD([0.86, 0.70], /NORMAL, /TO_DEVICE); for label string
title_pos5b = CONVERT_COORD(title_pos5b[0],title_pos5b[1]-5, /DEVICE, /TO_DATA)

;#
IF n_elements(y2) EQ n_elements(indep) THEN BEGIN
    OPlot, indep, y2, Color=dataColor2, psym=(psym NE 0) ? -1:0
    XYOUTS, title_pos1b[0], title_pos1b[1],  y1title, Color=dataColor
    Oplot, [title_pos1a[0]], [title_pos1a[1]], Color=dataColor, psym = (psym NE 0) ? psym:0
    XYOUTS, title_pos2b[0], title_pos2b[1], y2title, Color=dataColor2
    Oplot, [title_pos2a[0]], [title_pos2a[1]], Color=dataColor2, psym = (psym NE 0) ? 1:0
ENDIF
IF n_elements(y3) EQ n_elements(indep) THEN BEGIN
    OPlot, indep, y3, Color=dataColor3, psym=(psym NE 0) ? -4:0
    XYOUTS, title_pos3b[0], title_pos3b[1], y3title, Color=dataColor3
    Oplot, [title_pos3a[0]], [title_pos3a[1]], Color=dataColor3, psym = (psym NE 0) ? 4:0
ENDIF
IF n_elements(y4) EQ n_elements(indep) THEN BEGIN
    OPlot, indep, y4, Color=dataColor4, psym=(psym NE 0) ? -2:0
    XYOUTS, title_pos4b[0], title_pos4b[1], y4title, Color=dataColor4
    Oplot, [title_pos4a[0]], [title_pos4a[1]], Color=dataColor4, psym = (psym NE 0) ? 2:0
ENDIF
IF n_elements(y5) EQ n_elements(indep) THEN BEGIN
    OPlot, indep, y5, Color=dataColor5, psym=(psym NE 0) ? -6:0
    XYOUTS, title_pos5b[0], title_pos5b[1], y5title, Color=dataColor5
    Oplot, [title_pos5a[0]], [title_pos5a[1]], Color=dataColor5, psym = (psym NE 0) ? 6:0
ENDIF

  ; Create a pixmap window the same size as the draw widget window.
  ; Store its window index number in a local variable. Draw the same
  ; plot you just put in the draw widget in the pixmap window.

Window, /Free, XSize=zxsize, YSize=zysize, /Pixmap
pixIndex = !D.Window
Plot, indep, dep, XRange=xrange, YRange=yrange, XMargin=xmargin, XLog=xlog, YLog=ylog, $
   Xticklen=ticklen, Xgridstyle=(ticklen NE 0.02) ? 1:0, Yticklen=ticklen, Ygridstyle=(ticklen NE 0.02) ? 1:0, $
   Xtitle=xtitle, XTickFormat=xtickformat, YTickFormat=ytickformat, Xstyle=xstyle, Ystyle=ystyle, $
   Background=backColor, Color=axisColor, /NoData, _Extra=extra
OPlot, indep, dep, Color=dataColor, psym=psym
;#
IF n_elements(y2) EQ n_elements(indep) THEN BEGIN
    OPlot, indep, y2, Color=dataColor2, psym=(psym NE 0) ? -1:0
    XYOUTS, title_pos1b[0], title_pos1b[1],  y1title, Color=dataColor
    Oplot, [title_pos1a[0]], [title_pos1a[1]], Color=dataColor, psym = (psym NE 0) ? psym:0
    XYOUTS, title_pos2b[0], title_pos2b[1], y2title, Color=dataColor2
    Oplot, [title_pos2a[0]], [title_pos2a[1]], Color=dataColor2, psym = (psym NE 0) ? 1:0
ENDIF
IF n_elements(y3) EQ n_elements(indep) THEN BEGIN
    OPlot, indep, y3, Color=dataColor3, psym=(psym NE 0) ? -4:0
    XYOUTS, title_pos3b[0], title_pos3b[1], y3title, Color=dataColor3
    Oplot, [title_pos3a[0]], [title_pos3a[1]], Color=dataColor3, psym = (psym NE 0) ? 4:0
ENDIF
IF n_elements(y4) EQ n_elements(indep) THEN BEGIN
    OPlot, indep, y4, Color=dataColor4, psym=(psym NE 0) ? -2:0
    XYOUTS, title_pos4b[0], title_pos4b[1], y4title, Color=dataColor4
    Oplot, [title_pos4a[0]], [title_pos4a[1]], Color=dataColor4, psym = (psym NE 0) ? 2:0
ENDIF
IF n_elements(y5) EQ n_elements(indep) THEN BEGIN
    OPlot, indep, y5, Color=dataColor5, psym=(psym NE 0) ? -6:0
    XYOUTS, title_pos5b[0], title_pos5b[1], y5title, Color=dataColor5
    Oplot, [title_pos5a[0]], [title_pos5a[1]], Color=dataColor5, psym = (psym NE 0) ? 6:0
ENDIF


IF N_Elements(extra) EQ 0 THEN extraKeywords = Ptr_New(/Allocate_Heap) ELSE extraKeywords = Ptr_New(extra)

;; Create an info structure to hold information required by the program.
info = { $
   dep:dep, $                       ; The dependent data to be plotted.
   dep2:y2, $                       ;# Added member (2003/04/15)
   dep3:y3, $                       ;#
   dep4:y4, $                       ;#
   dep5:y5, $                       ;#
   y1title:y1title, $               ;#
   y2title:y2title, $               ;#
   y3title:y3title, $               ;#
   y4title:y4title, $               ;#
   y5title:y5title, $               ;#
   xtitle:xtitle,   $               ;# (2005/11/02)
   indep:indep, $                   ; The independent data to be plotted.
   zxsize:zxsize, $                 ; The X size of the draw widget.
   zysize:zysize, $                 ; The Y size of the draw widget.
   drawID:drawID, $                 ; The widget identifier of the draw widget.
   drawIndex:drawIndex, $           ; The draw window index number.
   pixIndex:pixIndex, $             ; The pixmap window index number.
   xrange:xrange, $                 ; The current X range of the plot.
   yrange:yrange, $                 ; The current Y range of the plot.
   xrange_def:xrange_def, $         ;# default X range (2003/05/27)
   yrange_def:yrange_def, $         ;# default Y range (2003/04/24)
   xlog:xlog, $                     ; A flag for X logarithmic axis style.
   ylog:ylog, $                     ; A flag for Y logarithmic axis style.
   xstyle:xstyle, $                 ; The setting for the XStyle keyword.
   ystyle:ystyle, $                 ;# Added member (2003/04/24)
   ticklen:ticklen, $               ;# (2003/05/27)
   xmargin:xmargin, $               ;# (2004/04/20)
   ytickformat:ytickformat, $       ;# (2005/10/26)
   xtickformat:xtickformat, $       ;# (2005/11/02)
   xs:0d, $                         ; X static corner of the zoom box.
   ys:0d, $                         ; Y static corner of the zoom box.
   xd:0, $                          ; X dynamic corner of the zoom box.
   yd:0, $                          ; Y dynamic corner of the zoom box.
   x:!X, $                          ; The !X system variable after plot.
   y:!Y, $                          ; The !Y system variable after plot.
   p:!P, $                          ; The !P system variable after plot.
   psym:psym, $                     ;# New Added member (2003/03/27)
   line:line, $                     ;# (2005/03/18)
   dbly:dbly, $                     ;# (2003/04/22)
   filename:filename, $             ;# (2003/06/05)
   extbtn_mode:extbtn_mode, $       ;# To display extra buttons (2005/03/17)
   extraKeywords:extraKeywords }    ; Extra plot keywords pointer.

  ; Store the info structure in the user value of the top-level base.
  Widget_Control, tlb, Set_UValue=info, /No_Copy

  ; Register this program and set up the event loop.
  XManager, 'ZPLOT_ALT', tlb, Cleanup='ZPLOT_Cleanup', Group_Leader=group, /No_Block, $
    Event_Handler='zZPLOT_Resize'

END ; of ZPLOT_ALT ************************************************************************
