;#> error.dc2
; Identifier   error
;
; Purpose      Setting a error or handle the error after the CALL_EXTERNAL
;
; Call	       error [, code, message]
;
; Arguments    Name   I/O  Type:       Description:
;	       ------------------------------------------------------------
;	       code    I    string	Aux code ('O','D','M','W','E','F')
;					for defining the  OK, Debug, Message,
;					Waring, Serious, Fatal status
;	       message I    string	Message string
;
; Returns      none
;
; Description  This routine can work on two differend ways:
;	       1)  When code and message are defined:
;		   The code and message string are displayed on the
;		   screen.
;
;	       2)  When code and message are not defined:
;		   The routine sets the default error levels.
;
;	       The routine returns normaly to the caller i.e. go on, or
;	       returns to the highest IDL level i.e. stop execution.
;
; Comment      This routine can be easy upgraded for:
;		 Debug mode:
;		   If the level is defined as fatal it doesn't return
;		   to the higest level, it stay's in the routine where the error
;		   occurs.
;		   In this envirionment data analysis is possible  (variables
;		   can be read and or changed for debugging) as well as storage
;		   of data before going on.
;		 Redirect of the messages (screen/log file):
;		   (standard logging can be switched on/off in IDL)
;
; Example      EXAMPLE 1: Handle error routine of only IDL routines
;
;	       t=10 & n=0
;	       if (n eq 0 ) then begin
;		 error,'F', ' Error, dividing by zero '
;	       endif else begin
;		 div=t/n
;	       endelse
;
;	       EXAMPLE 2:  Handle error of a non IDL routine
;			   (activated by call_external)
;
;	       mean  = external(/F_VALUE, 'MYN_AVG', FINDGEN(N), n )
;	       error
;
; Category     UTIL
;
; Filename     error
;
; Author       N.J.M. Sijm
;
; Version      3.0
;
; History      1.0  21-06-94 -->/NS  Creation date
;	       1.01 12-07-94	/NS  Change code for display
;	       1.1  04-08-94	/GB  Change call_external for new linking
;					strategy on VAX VMS
;	       1.2  13-09-94	DRB  Change call_external for new definition
;					of SPS_CHECK_ERROR
;	       1.3  13-09-94	DRB  Initialisation of nerror = 0
;	       1.4  14-09-94	DRB  Initialisation of error to a string
;					that is long enough for return values
;	       1.5  15-09-94	DK   IA.A.6 Improve error handling
;	       1.6  22-02-95  ++rh   Adapted to Unix
;	       1.7  14-03-95	HB   Unified Arguments
;	       1.8  15.09.95  ++rh   Patch for correct extension on HP-UX/SunOS
;	       1.9  18-01-96	FL   Adapted for Alpha-OSF
;	       2.0  12-12-00	FL   default lib_ext .so
;	       3.0  19-04-01	FL   remove Fortran
;#<

pro error, code, message

if n_params(0) lt 2 then return

erlev = 'FSWMDOE'	; Fatal SErious Warning Message Debug OK
if ( strtrim( code ) EQ '' ) then return
level = strpos( erlev, strupcase( strmid( code, 0, 1 ) ) )
if ( level EQ 6 ) then level = 1	; fold 'S' on 'E'

lmessage, level, message

return
end
