;#> frin_matrix.dc3
; Identifier	frin_matrix
;
; Purpose	calculate the fringe matrixs
;
; Synopsis	result = frin_matrix( freq, wavenum, wgt [, status=status] )
;
; Arguments	Name	I/O    Type:	Description
;		------------------------------------------------------------
;		d	 I     fltarr	fringe frequencys
;		wavenum  I     fltarr	wave numbers
;		wgt	 I     fltarr	weights
;		status	 I     bool	exit status
;					0: no problems
;					1: error
;
; Returns	result	 O     struct	design matrix
;		 { cp	       fltarr	cos( freq # wavenum )
;		   sp	       fltarr	sin( freq # wavenum )
;		   c2	       fltarr	SUM cos * cos * wgt
;		   s2	       fltarr	SUM sin * sin * wgt
;		   cs }        fltarr	SUM cos * sin * wgt
;
; Description
;
;
;
;
; Comment
;
;
; Example	--
;
; Category	UTIL ( module: fringes )
;
; Filename	frin_matrix.pro
;
; Author	Do Kester
;
; Version	1.2
;
; History	1.0  15-03-2001 DK, first implementation of frin_matrix.pro
;		1.1  05-04-2001 DK, remove compile_opt
;		1.2  22-10-2001 FL  catch memory allocation crash
;#<
;===========================================================================

function frin_matrix, freq, wavenum, wgt, status=status

compile_opt idl2, hidden

;catch, error
error = 0
if error ne 0 then begin
  catch, /Cancel
  help, /Last_Message, Output=theErrorMessage
  print,''
  error,'S','Cannot allocate memory for fringe matrix'
  error,'S','Try to reduce the required size, e.g. by increasing CYSTEP'
  print,''

  status = 1B
  return,0
endif else status = 0B

frwn = freq # ( 2 * !PI * wavenum )	     ; frinfreq # datapoints

awt = make_array( size=size( freq ), value=1.0 ) # wgt

cp = cos( frwn )
sp = sin( frwn )

design = { cp : cp, $
	   sp : sp, $
	   c2 : total( cp * cp * awt, 2 ), $
	   s2 : total( sp * sp * awt, 2 ), $
	   cs : total( cp * sp * awt, 2 ) }

return, design
end

