;#> frin_plot.dc3
; Identifier	frin_plot
;
; Purpose	plot all of the fringes
;
; Synopsis	frin_plot, flist, freq, ac, as, chisq, chilast, frid
;
; Arguments	Name	I/O    Type:	Description
;		------------------------------------------------------------
;		flist	 I     struct	fringe list
;		freq	 I     fltarr	fringe frequencies
;		ac	 I     fltarr	cosine amps
;		as	 I     fltarr	sine amps
;		chisq	 I     fltarr	chi-sq values
;		chilast  I     fltarr	chi-sq values of last iteration
;		frid	 I     struct	fringe identity
;
; Returns	--
;
; Description
;
;
;
;
; Comment
;
;
; Example	--
;
; Category	UTIL ( module: fringes )
;
; Filename	frin_plot.pro
;
; Author	Do Kester
;
; Version	1.0
;
; History	1.0  15-05-2001 DK, first implementation of frin_plot.pro
;#<
;=========================================================================

pro frin_plot, flist, freq0, ac, as, chisq, chilast, frid

; compile_opt idl2, hidden

forward_function frin_title

winset, 1, xsize=600, ysize=400, title='Fringes found'

pltitle = frin_title( frid )

freq = freq0

plot, freq, ac * 100, /nodata, xst=3, title=pltitle, pos=[0.1,0.3,0.9,0.9], $
	xtickname=replicate( ' ', 10 ), ytitle='Amplitude [%]', yst=11
oplot, freq, ac * 100, color=3, ps=3
oplot, freq, as * 100, color=5, ps=3

axis, yaxis=1, ystyle=19, yrange=cliprange( [chisq,chilast] ), color=2, $
      ytitle='!4v!3!u2!n', /save
oplot, freq, chisq, color=2
oplot, freq, chilast, color=8


amp = sqrt( flist.cosamp^2 + flist.sinamp^2 ) * 100.0
maxamp = max( amp )
fr = cliprange( freq )
plot, fr, [0,maxamp * 1.05], xst=3, ytitle='Amplitude [%]', /nodata, $
	pos=[0.1,0.1,0.9,0.3], /noerase, xtitle='Fringe frequency'

for k = 0, n_elements( flist ) - 1 do begin
  oplot, [flist[k].cycle, flist[k].cycle], [0,amp[k]], color=3
  if k lt 5 then begin
    if k eq 0 then str = 'strongest fringes: ' $
    else str = str + ', '
    str = str + string(flist[k].cycle, format='(f4.2)')
  endif
endfor
if n_elements( flist ) gt 0 then xyouts,0.5,0.25,str,/norm

return
end

