; $Id: count_rp_curve.pro,v 1.3 2004/05/21 07:48:48 baba Exp $
;
; Copyright (c) 2003, ASTRO-F Data Reduction Team.  All rights reserved.
;
;+
; NAME:
;	count_rp_curve.pro
; PURPOSE:
;	Counting number of ramps within the data.
; CATEGORY:
;	Function. Libfary for the procedures in ASTRO-F pipeline.
; CALLING SEQUENCE:
;	Result = count_rp_curve(tsd) 
; INPUTS:
;	tsd		Object reference type of TSD
; OUTPUTS:
;	cnt 		Array. Number of ramp curves for each detector
; RETURN:
;	cnt		Array. Number of ramp curves for each detector
;	!FAIL in failure.
; RESTRICTIONS:
;	At this moment, only reset counter is checked.
;	Reset status should be checked in the future.
; PROCEDURE:
;		
; EXAMPLE:
;	rp_cnt = count_rp_curve(tsd, 2)
; REFERENCE:
;	
;
; MODIFICATION HISTORY:
; 	Mar. 2003		Written by A. Kawamura.
;-

FUNCTION count_rp_curve, tsd

;ON_ERROR 2

;;; Check for position parameters ;;;
	IF (N_PARAMS(0) GT 2) THEN BEGIN
	PRINT, 'Calling Sequence: count_rp_curve(tsd)'
	PRINT, 'tsd = TSD object reference'
	PRINT, 'OUTPUT;	Array;number of ramp curves for each detector'
	RETURN,!FAIL
	ENDIF

;;; Get data ;;;
	vdet= tsd->get_value_tsd('fis_obs','det')
;;; number of channels ;;;
	si = SIZE(vdet)
	num_ch = si[1]
	num_data = si[2]

;;; get reset status ;;;
;;; LW ;;;;
IF num_ch EQ 75 THEN BEGIN
    rstct = tsd->get_value_tsd('fis_obs','rstcntwidel')
		diff_rstcnt = rstcnt - SHIFT(rstcnt, +1)
		ind_rstcnt = WHERE(diff_rstcnt NE 0, count)
	
		num_rp[0:44]=count
	PRINT, 'LW detector:WIDEL',COUNT,'ramps'
		rstcnt = tsd->get_value_tsd('fis_obs','rstcntn170')
		diff_rstcnt = rstcnt - SHIFT(rstcnt, +1)
		ind_rstcnt = WHERE(diff_rstcnt NE 0, count)
	
		num_rp[45:74]=count
	PRINT, 'LW detector:N170',COUNT,'ramps'
;;; SW ;;;;
	ENDIF ELSE BEGIN
		rstcnt = tsd->get_value_tsd('fis_obs','rstcntwides')
		diff_rstcnt = rstcnt - SHIFT(rstcnt, +1)
		ind_rstcnt = WHERE(diff_rstcnt NE 0, count)
	
		num_rp[0:59]=count
	PRINT, 'SW detector:WIDES',COUNT,'ramps'
		rstcnt = tsd->get_value_tsd('fis_obs','rstcntn60')
		diff_rstcnt = rstcnt - SHIFT(rstcnt, +1)
		ind_rstcnt = WHERE(diff_rstcnt NE 0, count)
	
		num_rp[60:99]=count
	PRINT, 'SW detector:N60',COUNT,'ramps'
	ENDELSE

	RETURN, num_rp

END



