; $Id: gb_get_name_ver.pro,v 1.5 2006/01/18 06:57:00 baba Exp $
;
; Copyright (c) 2003-2005, ASTRO-F Data Reduction Team.  All rights reserved.
;
;+
; NAME:
;       gb_get_name_ver.pto
; PURPOSE:
;
; CATEGORY:
;       Green Box lib in ASTRO-F pipeline.
; CALLING SEQUENCE:
;       Result = gb_get_name_ver(infeil='infile'
;                [,mod_name=mod_name, ver=ver])
; INPUTS:
;       Name of the function. The function must have
;       been compiled or executed before getting name or ver..
; OUTPUTS:
;       Name and versions
; RETURN:
;       Name and versions. -1 if the name or ver. is not
;       available because of an unexpected format of
;       the header.
; RESTRICTIONS:
;       Functions must contain the name or ver. in the first
;       line of the program. The format is like e.g.,
;
;       ;$Id: gb_get_name_ver.pro, v 1.2 2003/4/1
;
; PROCEDURE:
;
; EXAMPLE:
;        name_ver=gb_get_name_ver(infile='gb_get_name_ver' $
;                  , mod_name=mod_name, ver=ver)
;
;        > print,name_ver
;        > gb_get_name_ver.pro,v 1.2
;        > print,mod_name
;        > gb_get_name_ver.pro
;        > print,ver
;        > v 1.2
;
; REFERENCE:
;
;
; MODIFICATION HISTORY:
;   Nov. 2003     Written by A. Kawamura.
;   Jun. 2005     Last modified by Makiuti
;-

FUNCTION gb_get_name_ver, infile=infile, mod_name=mod_name, ver=ver

;IF KEYWORD_SET(rd) NE 0 THEN BEGIN
;rd='/export/dt1/kawamura/ASTRO-F/reduction/gb/pro/'
;inf=filepath(root_dir=rd,infile)
;ENDIF

dummy = routine_info(infile,/functions,/source)
inf = dummy.path

LMESSAGE, 7, 'Module used...', /CONTINUE
LMESSAGE, 7, inf, /CONTINUE

close,1
;openr,lun,inf,/get_lun
openr,1,inf
tmp = ''
readf,1,tmp
close,1

string_length = STRLEN(tmp)

found = 0
i = 0
j = 0
k = 0

WHILE (found LT 1) DO BEGIN
   dummy = STRMID(tmp,i,3)
   IF i GE string_length THEN BEGIN
      msg = 'Format of the header is unknown.'
      MESSAGE,msg,/CONTINUE
      msg = 'Unable to get name or ver. of the procedure.'
      MESSAGE,msg,/CONTINUE
      return, -1
   ENDIF
   IF dummy EQ 'Id:' THEN found=found+1
   i = i + 1
ENDWHILE

i = i + 3

found = 0

WHILE (found LT 1) DO BEGIN
   dummy=STRMID(tmp,j,2)
   IF i GE string_length THEN BEGIN
      msg = 'Format of the header is unknown.'
      MESSAGE,msg,/CONTINUE
      msg = 'Unable to get name or ver. of the procedure.'
      MESSAGE,msg,/CONTINUE
      return, -1
   ENDIF
   IF dummy EQ 'v ' THEN found=found+1
   j = j + 1
ENDWHILE

found = 0

WHILE (found LT 1) DO BEGIN
   dummy=STRMID(tmp,k,1)
   IF i GE string_length THEN BEGIN
      msg = 'Format of the header is unknown.'
      MESSAGE,msg,/CONTINUE
      msg = 'Unable to get name or ver. of the procedure.'
      MESSAGE,msg,/CONTINUE
      return, -1
   ENDIF
   IF dummy EQ '/' THEN found=found+1
   k = k + 1
ENDWHILE

name_ver = STRMID(tmp,i,k-i-5)
  name_ver = STRTRIM(name_ver,2)
mod_name = STRMID(tmp,i,j-i-2)
  mod_name = STRTRIM(mod_name,2)
ver = STRMID(tmp,j,k-j-5)
  ver = STRTRIM(ver)

RETURN,name_ver

end
