; $Id: gb_set_faritherr_at_nan.pro,v 1.2 2006/01/16 00:01:23 baba Exp $
;
; Copyright (c) 2004, ASTRO-F Data Reduction Team.  All rights reserved.
;
;+
; NAME:
;	gb_set_faritherr_at_nan.pro
; PURPOSE:
;	Set flag, "arith_err" at special values, 
;       such as NaN, Inf.
; CATEGORY:
;	Function. Library for ASTRO-F pipeline. Made for TSD ver3.
; CALLING SEQUENCE:
;	Return = gb_set_faritherr_at_nan(tsd, faritherr)
; INPUTS:
;	tsd		Object reference type of TSD
;
; OUTPUTS:
;       faritherr       Array of flags. 1 for where the data values are
;                       NaN or INFINITY.	
; RETURN:
;       !SUCCEED        for succeed.
;       !FAIL           for failure
; RESTRICTIONS:
;	
; PROCEDURE:
;        
; EXAMPLE:
;       Return = gb_set_faritherr_at_nan (tsd, faritherr)
; REFERENCE:
;
; MODIFICATION HISTORY:
; 	Sept  2004            Written by A. Kawamura.
;-

FUNCTION gb_set_faritherr_at_nan, tsd, faritherr
;ON_ERROR 2
IF N_PARAMS(0) EQ 0 THEN BEGIN
    MESSAGE,'FUNCTION gb_set_faritherr_at_nan, tsd, faritherr',/CONTINUE
    PRINT,'            TSD = TSD'

    RETURN, -1
ENDIF


;;; Reading input file ;;;
;IF KEYWORD_SET(vdet) EQ 1 THEN BEGIN
;	in_vdet=tsd->get_value_tsd('fis_obs','det')
;ENDIF ELSE BEGIN
        flux = tsd->get_value_tsd('fis_obs','flux')

  ;;; number of channels ;;;
	si = SIZE(flux)
	num_ch = si[1]
	num_data = si[2]

faritherr = tsd->get_pix_flag_tsd('fis_obs','arith_err')
help,faritherr
;;; Search for NaN ;;;;
   MESSAGE,'Searching for NaN and INFINITE',/CONTINUE
   ind_nan = WHERE (FINITE(flux, /NAN), count_nan)
   IF count_nan NE 0 THEN faritherr[ind_nan] = 1
   ind_inf = WHERE (FINITE(flux, /INFINITY), count_inf)
   IF count_inf NE 0 THEN faritherr[ind_inf] = 1
   ind = WHERE (faritherr eq 1, cnt)
   IF cnt NE 0 THEN faritherr[ind] = 1
   MESSAGE,'gb_set_faritherr_at_nan is done...',/CONTINUE

    RETURN, !SUCCEED

END
