;
; Copyright (c) 2002, ASTRO-F Data Reduction Team.  All rights reserved.
;
;+
; NAME:
;	mmt_isolate_signals.pro
; PURPOSE:
;       Produce mask array to isolate signals in reconstructed partial TSD
; CATEGORY:
;	Green Box procedure in library in ASTRO-F pipeline.
; CALLING SEQUENCE:
;
; INPUTS:
;	data         input data
;       threshold    minimum value of data to separate signals
;       sep_limit    number of continuous zero point between signals
;  
;
; OUTPUTS:
;       mask         Mask array for isolated signals, which have the
;                    same value for a single isolated signal. The
;                    maximum value of this mask gives the number of
;                    isolated signals in the input data
;
;
;
; RESTRICTIONS:
;	
; PROCEDURE:
;
; EXAMPLE:
;
; REFERENCE:
;
; MODIFICATION HISTORY:
; 	Aug. 2004		Written by T.Takagi
;    
;-

FUNCTION mmt_isolate_signals, data, threshold, sep_limit = sep_limit

if (n_elements(sep_limit eq 0)) then sep_limit = 10

mask = intarr(n_elements(data))

id = where(abs(data) gt threshold, cnt)
if (cnt eq 0) then begin 
;    message, 'Null data', /continue
    return, mask
endif

id0 = id[0] ;; begining of new object
iobj = 1 ;; object id
for i=1L, n_elements(id)-1 do begin 
    sep = id[i]-id[i-1]
    if (sep ge sep_limit) then begin 
        mask[id0:id[i-1]] = iobj
        id0=id[i]
        iobj=iobj+1
    endif
    ;- mask for the last object
    if (i eq n_elements(id)-1) then begin 
        mask[id0:id[i]] = iobj
    endif
endfor

return, mask

END
