;
; Copyright (c) 2006, ASTRO-F Data Reduction Team.  All rights reserved.
;
;+
; NAME:
;	Uniqer
; PURPOSE:
;	lists start indices and lengths of similar items in an array
; CATEGORY:
;	Utility
; CALLING SEQUENCE:
;	nr = uniqer( array, start=start, length=length )
; INPUTS:
;	array		array with number (unsorted, whatsoever)
; OUTPUT:
;	start		list of indices where new items start
;	length		lengths of the items
; RETURNS:
;	nr		number of items in the lists
; EXAMPLE;
;	array = [3,3,3,2,2,5,5,5,3,3,3,6,6,0,3]
;	nr = uniqer( array, start=s, length=len )
;	print, nr
;	     7
;	print, s, len
;	     0	   3	5     8     11	  13	14
;	     3	   2	3     3      2	   1	 1
; HISTORY:
;	May 2006  DK
; REMARK:
;	IDL's uniq almost does the same thing except when the last item is
;	the same as the first. Then it botches up.
;-

function uniqer, array, start=qs, length=length

na = n_elements( array )

qe = uniq( array )
nq = n_elements( qe )
if ( nq EQ 1 ) then qs = 0 else begin
    qs = [0,qe+1]
    if ( array[0] NE array[na-1] ) then qs = qs[0:nq-1] $
    else qe = [qe,na-1]
endelse

length = qe -qs + 1
return, n_elements( qe )

end
