; $Id: gb_run_tsdarr.pro,v 1.3 2006/03/23 05:23:10 baba Exp $
;
; Copyright (c) 2005-2006, ASTRO-F Data Reduction Team.  All rights reserved.
;
;+
; NAME:
;   GB_RUN_TSDARR.pro
;
; PURPOSE:
;   This is a wrapper program for the GB_Run_GB.pro.
;   The purpose of this procedure is to handle an array of
;   TSD object and run GB_Run_GB.
;
; CATEGORY:
;   Green Box
;
; CALLING SEQUENCE:
;   GB_RUN_TSDARR, $
;          tsdarr, $                  ; an array of TSD objects, or 'LDS' to get data from the LDS
;          TIME=time, SPAN=span, FORMAT=format, MODE=mode, $ ; In the case of tsdarr is 'LDS'
;          TO_LDS = to_lds, $         ; Keyword to upload processed TSD to the LDS
;          NO_OUTFILE = no_outfile, $ ; Keyword to suppress file output.
;          GLT_LIST = glt_list, $     ; Keyword to create glitch list files.
;          _EXTRA = extra
;
; INPUTS:
;   tsdarr : an array of TSD objects
;
; OUTPUTS:
;
; EXAMPLE:
;   gb_run_tsdarr, tsdarr, enable=[1,3,4,5], /NO_OUT
;   gb_run_tsdarr, 'LDS', time='2005-10-21 15:49:30', span='60', format='tsd3_sw', mode='Lab', /TO_LDS
;
; REFERENCE:
;
; MODIFICATION HISTORY:
;   Jun. 2005     Written by Makiuti
;   Feb. 2006     Last modified by Makiuti
;-

PRO GB_RUN_TSDARR, $
    tsdarr, $                  ; an array of TSD objects, or 'LDS' to get data from the LDS
    TIME=time, SPAN=span, FORMAT=format, MODE=mode, $ ; In the case of tsdarr is 'LDS'
    TO_LDS = to_lds, $         ; Keyword to upload processed TSD to the LDS
    NO_OUTFILE = no_outfile, $ ; Keyword to suppress file output.
    GLT_LIST = glt_list, $     ; Keyword to create glitch list files.
    _EXTRA = extra

  ; Display usage
  IF n_params() EQ 0 THEN BEGIN
    print, "ex.1) gb_run_tsdarr, tsdarr, enable=[1,3,4,5], /NO_OUT"
    print, "ex.2) gb_run_tsdarr, 'LDS', time='2005-10-21 15:49:30', span='60', format='tsd3_sw', mode='Lab', /TO_LDS"
    Return
  ENDIF

  ; Case of getting data from LDS as an array of TSD objects
  IF (size(tsdarr, /type) EQ 7) THEN BEGIN
    IF (STRMATCH(tsdarr, 'LDS', /FOLD_CASE) EQ 1) THEN BEGIN
      tsdarr = Get_TsdArr_from_LDS(TIME=time, SPAN=span, FORMAT=format, MODE=mode)
    ENDIF ELSE BEGIN
      print, "##USAGE##"
      print, "  ex.) gb_run_tsdarr, 'LDS', time='2005-10-21 15:49:30', span='60', format='tsd3_sw', mode='Lab', /TO_LDS"
      Return
    ENDELSE
  ENDIF

  ; Get a number of elements
  num_tsdarr = n_elements(tsdarr)
  msg = 'Number of TSD objects in the array : ' + strcompress(string(num_tsdarr))
  LMessage, 5, msg, /Continue

  ;---------------
  ; Run GB_Run_GB
  ;---------------
  FOR i = 0, num_tsdarr-1 DO BEGIN

    ; Set output file names
    outfile_name = 'gb_tsd'+strcompress(string(i, format='(i3.3)'), /REMOVE_ALL)+'.fits'
    IF Keyword_Set(NO_OUTFILE) THEN outfile_name = -1

    ;
    IF Keyword_Set(GLT_LIST) THEN BEGIN
      gb_glitch_list_fname = 'gp_glt_list'+strcompress(string(i, format='(i3.3)'), /REMOVE_ALL)+'.txt'

      ret = gb_run_gb(tsdarr[i], outfile=outfile_name, $
                      GlitchList_GP=gb_glitch_list_fname, $ ; for GP  deglitcher
                      Output_Glitch = 1, $                  ; for MMT deglitcher
                      _EXTRA = extra)
    ENDIF ELSE BEGIN
      ret = gb_run_gb(tsdarr[i], outfile=outfile_name, $
                      _EXTRA = extra)
    ENDELSE

  ENDFOR

  ; Upload processed TSD to the LDS
  IF Keyword_Set(TO_LDS) THEN BEGIN
    ret = Write_TsdArr_to_LDS(tsdarr)
  ENDIF

END
