; $Id: im2fits.pro,v 1.4 2006/05/12 07:34:03 do Exp $
;
; Copyright (c) 2005, ASTRO-F Data Reduction Team.  All rights reserved.
;		      Do Kester, SRON.
;+
; NAME:
;	im2fits.pro
; PURPOSE:
;	coadd one detector scan into the mapset struct
; CATEGORY:
;	Function.
; CALLING SEQUENCE:
;	Result = im2fits( image, mapinfo, filename )
;
; INPUTS:
;	image		image array
;	mapinfo 	map information
;	filename	name of fitsfile to be written
; OUTPUTS:
;	-
; RETURN
;	!SUCCEED if function ended successfully.
;	!FAIL in failure.
; RESTRICTIONS:
;
; PROCEDURE:
;	Add flux to all pixels that fall within a beam's distance
;	from the nominal positions of flux in the coadd-map.
;	Increment the same pixels in the count-map and add the square
;	of the fluxes into the pixels of the stdev-map
;
; EXAMPLE:
;
; REFERENCE:
;	Baba et al. 2002 Nov. 21, ``ASTRO-F/FIS Survey Data Structure"
;
; MODIFICATION HISTORY:
;	Mar. 2005		Written by Do Kester
;-

FUNCTION im2fits, image, mapinfo, filename

COMPILE_OPT IDL2

;   ON_ERROR 2
;	     hdr=("COMMENT  This is a comment line to put in the header", $
;		  "MYKEY    = "Some desired keyword value")

    header = im_mkheader( mapinfo )



;    icmkhdr, NAXIS1, NAXIS2, CDELT1, CDELT2, CRVAL1, CRVAL2, 0, header
;    header =[ "SIMPLE   = T", $
;	      "BITPIX   = -8", $
;	      "NAXIS    = 2", $
;	      "NAXIS1   = " + string( mapinfo.pixels[0] ), $
;	      "NAXIS2   = " + string( mapinfo.pixels[1] ), $
;	      "CRPIX1   = " + string( mapinfo.pixels[0] / 2.0 ), $
;	      "CRPIX2   = " + string( mapinfo.pixels[1] / 2.0 ), $
;	      "CDELT1   = " + string(-mapinfo.size[0] / mapinfo.pixels[0] ), $
;	      "CDELT2   = " + string( mapinfo.size[1] / mapinfo.pixels[1] ), $
;	      "CRVAL1   = " + string( mapinfo.center[0] ), $
;	      "CRVAL2   = " + string( mapinfo.center[1] ), $
;	      "CTYPE1   = RA---TAN", $
;	      "CTYPE2   = DEC--TAN" ]

    writefits, filename, image, header

    return, !SUCCEED

END


