;+
; NAME:
;   ss_aftcal_ave
;
; PURPOSE:
;   Make a template of CAL after effect signal and output data table
;
; CALLING SEQUENCE:
;
; MODIFICATION HISTORY:
;   Written by S. Matsuura, 2006/11/14
;
;   2006/12/12 changed notation of the output table from D11.7 to E12.5
;   2006/12/21 I.Yamamura changed window selection by WSET instead of WINDOW
;   2006/12/29 Makiuti, S. Added NO_DISP option.
;   2007/01/28 S.Matsuura, changed simple mean -> weighted mean.
;   2007/01/29 Makiuti, S. changed format code of E12.5 into E13.5 to avoid error on Windows
;   2007/01/30 S.Matsuura, handled blank data with zero value.
;
;-
pro ss_aftcal_ave, outfile, x_ave, coeff, error, cal_flg_tot, n_int, $
            n_pix, plot_pix, start_idx, end_idx, NO_DISP=no_disp

; Check the parameters and initialize
  IF (n_elements(no_disp) EQ 0) THEN no_disp=0

; print input parameter
    print, 'Calculating mean flux ...'
    print, 'Start index:', start_idx, ' End index:', end_idx


; generate index for averaging line_fit data

    mean_idx = where( (x_ave ge start_idx) and (x_ave le end_idx), mean_idx_cnt)
    if (mean_idx_cnt gt 0) then begin
        x_val = x_ave[mean_idx]
        cal_aft = cal_flg_tot[mean_idx]
        data = coeff[*,mean_idx,1]
        err = error[*,mean_idx,1]
    endif


; compile data for the correction of cal after effect

    cal_aft_idx = where(cal_aft ne 0, cal_aft_cnt)
    print, 'cal flag count: ', cal_aft_cnt

    ; template range: 15
    cal_cor = dblarr(15*n_int, n_pix, cal_aft_cnt)
    cal_cor_er = dblarr(15*n_int, n_pix, cal_aft_cnt)
    offset = 5*n_int ; samples before cal

    if(cal_aft_cnt gt 0) then begin
    for i_cal = 0, cal_aft_cnt-1 do begin
        for j = 0, 15*n_int-1 do begin
            cal_cor[j,*,i_cal] = data[*,cal_aft_idx[i_cal]+j-offset]
            cal_cor_er[j,*,i_cal] = err[*,cal_aft_idx[i_cal]+j-offset]
        endfor
    endfor
    endif else begin
        print, 'no cal data!'
        stop
    endelse


; initial offset subtraction

    base0 = dblarr(2,n_pix,cal_aft_cnt)
    weight0 = dblarr(2,n_pix,cal_aft_cnt)
    base_ave0 = dblarr(n_pix,cal_aft_cnt)

    for pix = 0, n_pix-1 do begin
        for i_cal = 0, cal_aft_cnt-1 do begin
        for k = 0, 5*n_int-1 do begin
            if(cal_cor[k,pix,i_cal] ne 0 and cal_cor_er[k,pix,i_cal] gt 0) then begin
                base0[0,pix,i_cal] = base0[0,pix,i_cal] + cal_cor[k,pix,i_cal]/cal_cor_er[k,pix,i_cal]^2
                weight0[0,pix,i_cal] = weight0[0,pix,i_cal] + 1D/cal_cor_er[k,pix,i_cal]^2
	    endif
            if(cal_cor[k+10*n_int,pix,i_cal] ne 0 and cal_cor_er[k+10*n_int,pix,i_cal] gt 0) then begin
                base0[1,pix,i_cal] = base0[1,pix,i_cal] + cal_cor[k+10*n_int,pix,i_cal]/cal_cor_er[k+10*n_int,pix,i_cal]^2
                weight0[1,pix,i_cal] = weight0[1,pix,i_cal] + 1D/cal_cor_er[k+10*n_int,pix,i_cal]^2
            endif
        endfor
        endfor
    endfor

    nz_idx0 = where(weight0 gt 0, nz_idx_cnt0)
    base0[nz_idx0] = base0[nz_idx0]/weight0[nz_idx0]
    base_ave0[*,*] = (base0[0,*,*] + base0[1,*,*])/2D
    for j = 0, 15*n_int-1 do begin
        cal_cor[j,*,*] = cal_cor[j,*,*] - base_ave0[*,*]
    endfor


; averaging data / calculating mean

    corr_mean0 = dblarr(3,15*n_int,n_pix)
    corr_stdev0 = dblarr(15*n_int,n_pix)

    for pix = 0, n_pix-1 do begin
        for j = 0, 15*n_int-1 do begin
        for i_cal = 0, cal_aft_cnt-1 do begin
        if(cal_cor[j,pix,i_cal] ne 0 and cal_cor_er[j,pix,i_cal] gt 0) then begin
            corr_mean0[0,j,pix] = corr_mean0[0,j,pix] + cal_cor[j,pix,i_cal]/cal_cor_er[j,pix,i_cal]^2
            corr_mean0[1,j,pix] = corr_mean0[1,j,pix] + 1D/cal_cor_er[j,pix,i_cal]^2
            corr_mean0[2,j,pix] = corr_mean0[2,j,pix] + 1
        endif
        endfor
            corr_stdev0[j,pix] = stddev(cal_cor[j,pix,*],/double,/NaN)
        endfor
	nz_idx0 = where(corr_mean0[1,*,pix] gt 0, nz_idx_cnt0)
	if (nz_idx_cnt0 gt 0) then begin
    	    corr_mean0[0,nz_idx0,pix] = corr_mean0[0,nz_idx0,pix]/corr_mean0[1,nz_idx0,pix]
    	    corr_mean0[1,nz_idx0,pix] = sqrt(1D/corr_mean0[1,nz_idx0,pix])
	endif
    endfor


; re-calculate mean value with 2-sigma rejection

    corr_mean = dblarr(3,15*n_int,n_pix)
    corr_stdev = dblarr(15*n_int,n_pix)

    for pix = 0, n_pix-1 do begin
        for j = 0, 15*n_int-1 do begin
            nrj_idx = where(abs(cal_cor[j,pix,*]-corr_mean0[0,j,pix]) lt 2*corr_stdev0[j,pix], nrj_cnt)
            if (nrj_cnt gt 0) then begin
                n = n_elements(cal_cor[j,pix,nrj_idx])
            for k = 0, n-1 do begin
	    if(cal_cor[j,pix,nrj_idx[k]] ne 0 and cal_cor_er[j,pix,nrj_idx[k]] gt 0) then begin
                corr_mean[0,j,pix] = corr_mean[0,j,pix] + cal_cor[j,pix,nrj_idx[k]]/cal_cor_er[j,pix,nrj_idx[k]]^2
                corr_mean[1,j,pix] = corr_mean[1,j,pix] + 1D/cal_cor_er[j,pix,nrj_idx[k]]^2
                corr_mean[2,j,pix] = corr_mean[2,j,pix] + 1
            endif
            endfor
                corr_stdev[j,pix] = stddev(cal_cor[j,pix,*],/double,/NaN)
            endif
        endfor
	nz_idx = where(corr_mean[1,*,pix] gt 0, nz_idx_cnt)
	if (nz_idx_cnt gt 0) then begin
    	    corr_mean[0,nz_idx,pix] = corr_mean[0,nz_idx,pix]/corr_mean[1,nz_idx,pix]
    	    corr_mean[1,nz_idx,pix] = sqrt(1D/corr_mean[1,nz_idx,pix])
	endif
    endfor


; offset subtraction after averaging

    base = dblarr(2,n_pix,cal_aft_cnt)
    weight = dblarr(2,n_pix,cal_aft_cnt)
    base_ave = dblarr(n_pix,cal_aft_cnt)

    for pix = 0, n_pix-1 do begin
        for i_cal = 0, cal_aft_cnt-1 do begin
        for k = 0, 5*n_int-1 do begin
            if(cal_cor[k,pix,i_cal] ne 0 and cal_cor_er[k,pix,i_cal] gt 0) then begin
                base[0,pix,i_cal] = base[0,pix,i_cal] + cal_cor[k,pix,i_cal]/cal_cor_er[k,pix,i_cal]^2
                weight[0,pix,i_cal] = weight[0,pix,i_cal] + 1D/cal_cor_er[k,pix,i_cal]^2
	    endif
            if(cal_cor[k+10*n_int,pix,i_cal] ne 0 and cal_cor_er[k+10*n_int,pix,i_cal] gt 0) then begin
                base[1,pix,i_cal] = base[1,pix,i_cal] + cal_cor[k+10*n_int,pix,i_cal]/cal_cor_er[k+10*n_int,pix,i_cal]^2
                weight[1,pix,i_cal] = weight[1,pix,i_cal] + 1D/cal_cor_er[k+10*n_int,pix,i_cal]^2
            endif
        endfor
        endfor
    endfor

    nz_idx = where(weight gt 0, nz_idx_cnt)
    base[nz_idx] = base[nz_idx]/weight[nz_idx]
    base_ave[*,*] = (base[0,*,*] + base[1,*,*])/2D
    for j = 0, 15*n_int-1 do begin
        cal_cor[j,*,*] = cal_cor[j,*,*] - base_ave[*,*]
    endfor


; plot data

  IF (no_disp NE 1) THEN BEGIN ; If /NO_DISP option was not set

;   window, 0
    wset, 0
    plot, corr_mean[0,*,plot_pix-1], title=outfile, $
        xtitle='# of samples', ytitle='output [V/s]', $
        ticklen=1.0, xgridstyle=1, ygridstyle=1, $
        position=[0.1,0.1,0.9,0.9]

    errplot, corr_mean[0,*,plot_pix-1]-corr_mean[1,*,plot_pix-1], $
        corr_mean[0,*,plot_pix-1]+corr_mean[1,*,plot_pix-1]

    window, 1
    plot, cal_cor[*,plot_pix-1,0], title=outfile, $
        xtitle='# of samples', ytitle='output [V/s]', $
        ticklen=1.0, xgridstyle=1, ygridstyle=1, $
        position=[0.1,0.1,0.9,0.9]
    for i = 1, cal_aft_cnt-1 do begin
        oplot, cal_cor[*,plot_pix-1,i]
    endfor

  ENDIF

; make correction table

    openw, unit, outfile, /get_lun

    ; output data only after cal
    if(n_int eq 1) then begin   
    for pix = 0, n_pix-1 do begin
        printf, unit, $

        corr_mean[0,5,pix], corr_mean[0,6,pix], corr_mean[0,7,pix], $
        corr_mean[0,8,pix], corr_mean[0,9,pix], corr_mean[0,10,pix], $
        corr_mean[0,11,pix], corr_mean[0,12,pix], corr_mean[0,13,pix], $
        corr_mean[0,14,pix], $

        corr_mean[1,5,pix], corr_mean[1,6,pix], corr_mean[1,7,pix], $
        corr_mean[1,8,pix], corr_mean[1,9,pix], corr_mean[1,10,pix], $
        corr_mean[1,11,pix], corr_mean[1,12,pix], corr_mean[1,13,pix], $
        corr_mean[1,14,pix], $

        corr_mean[2,5,pix], corr_mean[2,6,pix], corr_mean[2,7,pix], $
        corr_mean[2,8,pix], corr_mean[2,9,pix], corr_mean[2,10,pix], $
        corr_mean[2,11,pix], corr_mean[2,12,pix], corr_mean[2,13,pix], $
        corr_mean[2,14,pix], $

        format = '(30(2X,E13.5))'
    endfor
    endif

    if(n_int eq 2) then begin
    for pix = 0, n_pix-1 do begin
        printf, unit, $

        corr_mean[0,10,pix], corr_mean[0,11,pix], corr_mean[0,12,pix], $
        corr_mean[0,13,pix], corr_mean[0,14,pix], corr_mean[0,15,pix], $
        corr_mean[0,16,pix], corr_mean[0,17,pix], corr_mean[0,18,pix], $
        corr_mean[0,19,pix], corr_mean[0,20,pix], corr_mean[0,21,pix], $
        corr_mean[0,22,pix], corr_mean[0,23,pix], corr_mean[0,24,pix], $
        corr_mean[0,25,pix], corr_mean[0,26,pix], corr_mean[0,27,pix], $
        corr_mean[0,28,pix], corr_mean[0,29,pix], $

        corr_mean[1,10,pix], corr_mean[1,11,pix], corr_mean[1,12,pix], $
        corr_mean[1,13,pix], corr_mean[1,14,pix], corr_mean[1,15,pix], $
        corr_mean[1,16,pix], corr_mean[1,17,pix], corr_mean[1,18,pix], $
        corr_mean[1,19,pix], corr_mean[1,20,pix], corr_mean[1,21,pix], $
        corr_mean[1,22,pix], corr_mean[1,23,pix], corr_mean[1,24,pix], $
        corr_mean[1,25,pix], corr_mean[1,26,pix], corr_mean[1,27,pix], $
        corr_mean[1,28,pix], corr_mean[1,29,pix], $

        corr_mean[2,10,pix], corr_mean[2,11,pix], corr_mean[2,12,pix], $
        corr_mean[2,13,pix], corr_mean[2,14,pix], corr_mean[2,15,pix], $
        corr_mean[2,16,pix], corr_mean[2,17,pix], corr_mean[2,18,pix], $
        corr_mean[2,19,pix], corr_mean[2,20,pix], corr_mean[2,21,pix], $
        corr_mean[2,22,pix], corr_mean[2,23,pix], corr_mean[2,24,pix], $
        corr_mean[2,25,pix], corr_mean[2,26,pix], corr_mean[2,27,pix], $
        corr_mean[2,28,pix], corr_mean[2,29,pix], $

        format = '(60(2X,E13.5))'
    endfor
    endif

    if(n_int eq 4) then begin
    for pix = 0, n_pix-1 do begin
        printf, unit, $

        corr_mean[0,20,pix], corr_mean[0,21,pix], corr_mean[0,22,pix], $
        corr_mean[0,23,pix], corr_mean[0,24,pix], corr_mean[0,25,pix], $
        corr_mean[0,26,pix], corr_mean[0,27,pix], corr_mean[0,28,pix], $
        corr_mean[0,29,pix], corr_mean[0,30,pix], corr_mean[0,31,pix], $
        corr_mean[0,32,pix], corr_mean[0,33,pix], corr_mean[0,34,pix], $
        corr_mean[0,35,pix], corr_mean[0,36,pix], corr_mean[0,37,pix], $
        corr_mean[0,38,pix], corr_mean[0,39,pix], $
        corr_mean[0,40,pix], corr_mean[0,41,pix], corr_mean[0,42,pix], $
        corr_mean[0,43,pix], corr_mean[0,44,pix], corr_mean[0,45,pix], $
        corr_mean[0,46,pix], corr_mean[0,47,pix], corr_mean[0,48,pix], $
        corr_mean[0,49,pix], corr_mean[0,50,pix], corr_mean[0,51,pix], $
        corr_mean[0,52,pix], corr_mean[0,53,pix], corr_mean[0,54,pix], $
        corr_mean[0,55,pix], corr_mean[0,56,pix], corr_mean[0,57,pix], $
        corr_mean[0,58,pix], corr_mean[0,59,pix], $

        corr_mean[1,20,pix], corr_mean[1,21,pix], corr_mean[1,22,pix], $
        corr_mean[1,23,pix], corr_mean[1,24,pix], corr_mean[1,25,pix], $
        corr_mean[1,26,pix], corr_mean[1,27,pix], corr_mean[1,28,pix], $
        corr_mean[1,29,pix], corr_mean[1,30,pix], corr_mean[1,31,pix], $
        corr_mean[1,32,pix], corr_mean[1,33,pix], corr_mean[1,34,pix], $
        corr_mean[1,35,pix], corr_mean[1,36,pix], corr_mean[1,37,pix], $
        corr_mean[1,38,pix], corr_mean[1,39,pix], $
        corr_mean[1,40,pix], corr_mean[1,41,pix], corr_mean[1,42,pix], $
        corr_mean[1,43,pix], corr_mean[1,44,pix], corr_mean[1,45,pix], $
        corr_mean[1,46,pix], corr_mean[1,47,pix], corr_mean[1,48,pix], $
        corr_mean[1,49,pix], corr_mean[1,50,pix], corr_mean[1,51,pix], $
        corr_mean[1,52,pix], corr_mean[1,53,pix], corr_mean[1,54,pix], $
        corr_mean[1,55,pix], corr_mean[1,56,pix], corr_mean[1,57,pix], $
        corr_mean[1,58,pix], corr_mean[1,59,pix], $

        corr_mean[2,20,pix], corr_mean[2,21,pix], corr_mean[2,22,pix], $
        corr_mean[2,23,pix], corr_mean[2,24,pix], corr_mean[2,25,pix], $
        corr_mean[2,26,pix], corr_mean[2,27,pix], corr_mean[2,28,pix], $
        corr_mean[2,29,pix], corr_mean[2,30,pix], corr_mean[2,31,pix], $
        corr_mean[2,32,pix], corr_mean[2,33,pix], corr_mean[2,34,pix], $
        corr_mean[2,35,pix], corr_mean[2,36,pix], corr_mean[2,37,pix], $
        corr_mean[2,38,pix], corr_mean[2,39,pix], $
        corr_mean[2,40,pix], corr_mean[2,41,pix], corr_mean[2,42,pix], $
        corr_mean[2,43,pix], corr_mean[2,44,pix], corr_mean[2,45,pix], $
        corr_mean[2,46,pix], corr_mean[2,47,pix], corr_mean[2,48,pix], $
        corr_mean[2,49,pix], corr_mean[2,50,pix], corr_mean[2,51,pix], $
        corr_mean[2,52,pix], corr_mean[2,53,pix], corr_mean[2,54,pix], $
        corr_mean[2,55,pix], corr_mean[2,56,pix], corr_mean[2,57,pix], $
        corr_mean[2,58,pix], corr_mean[2,59,pix], $

        format = '(120(2X,E13.5))'
    endfor
    endif

    if (n_int ne 1 and n_int ne 2 and n_int ne 4) then begin
    	MESSAGE, "Only N_RAMP_DIV = 1, 2 or 4 is allowed."
    	return
    endif

    free_lun, unit

end
